@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: block_subs.h,v 1.8 2008/03/24 08:58:30 guru Exp $
+ *    $Id: block_subs.h,v 1.10 2009/01/09 04:02:32 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -55,9 +55,9 @@ struct BLOCK_CTRL {	/* All control options for this program (except common args)
 	} Q;
 #endif
 #if defined(BLOCKMEDIAN)
-	struct T {	/* -T<quartile> */
+	struct T {	/* -T<quantile> */
 		BOOLEAN active;
-		double quartile;
+		double quantile;
 	} T;
 #endif
 	struct S {	/* -S[w|z] */
