@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: blockmean.c,v 1.58 2008/04/25 04:00:40 guru Exp $
+ *    $Id: blockmean.c,v 1.62 2009/01/09 04:02:32 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -183,7 +183,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   -Sw reports weight sums instead of data sums.\n");
 		GMT_explain_option ('V');
 		fprintf (stderr, "\t-W sets Weight options.\n");
-		fprintf (stderr, "\t-  -Wi reads Weighted Input (4 cols: x,y,z,w) but writes only (x,y,z[,s,l,h]) Output.\n");
+		fprintf (stderr, "\t   -Wi reads Weighted Input (4 cols: x,y,z,w) but writes only (x,y,z[,s,l,h]) Output.\n");
 		fprintf (stderr, "\t   -Wo reads unWeighted Input (3 cols: x,y,z) but reports sum (x,y,z[,s,l,h],w) Output.\n");
 		fprintf (stderr, "\t   -W with no modifier has both weighted Input and Output; Default is no weights used.\n");
 		GMT_explain_option (':');
@@ -197,6 +197,8 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
+	GMT_check_lattice (&Ctrl->I.xinc, &Ctrl->I.yinc, &Ctrl->F.active, &Ctrl->I.active);
+
 	if (!project_info.region_supplied) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify -R option\n", GMT_program);
 		error++;
@@ -233,7 +235,7 @@ int main (int argc, char **argv)
 	
 	GMT_RI_prepare (&h);	/* Ensure -R -I consistency and set nx, ny */
 
-	n_blocks = ((GMT_LONG)h.nx) * ((GMT_LONG)h.ny);
+	n_blocks = GMT_get_nm (h.nx, h.ny);
 	
 	if ((zw = (struct BLK_PAIR *) GMT_memory (VNULL, n_blocks, sizeof (struct BLK_PAIR), GMT_program)) == NULL) {
 		fprintf (stderr, "%s: ERROR: Unable to allocate memory for %ld blocks [%ld bytes for zw].\n",
