@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: filter1d.c,v 1.50 2008/03/24 08:58:30 guru Exp $
+ *    $Id: filter1d.c,v 1.52 2009/01/09 04:02:32 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -920,14 +920,14 @@ void free_space (struct FILTER1D_INFO *F)
 	GMT_free ((void *)F->n_this_col);
 	if (F->check_asym) GMT_free ((void *)F->n_left);
 	if (F->check_asym) GMT_free ((void *)F->n_right);
-	GMT_free ((void *)F->min_loc);
-	GMT_free ((void *)F->max_loc);
-	GMT_free ((void *)F->last_loc);
-	GMT_free ((void *)F->this_loc);
-	GMT_free ((void *)F->min_scl);
-	GMT_free ((void *)F->max_scl);
-	GMT_free ((void *)F->last_scl);
-	GMT_free ((void *)F->this_scl);
+	if (F->min_loc) GMT_free ((void *)F->min_loc);
+	if (F->max_loc) GMT_free ((void *)F->max_loc);
+	if (F->last_loc) GMT_free ((void *)F->last_loc);
+	if (F->this_loc) GMT_free ((void *)F->this_loc);
+	if (F->min_scl) GMT_free ((void *)F->min_scl);
+	if (F->max_scl) GMT_free ((void *)F->max_scl);
+	if (F->last_scl) GMT_free ((void *)F->last_scl);
+	if (F->this_scl) GMT_free ((void *)F->this_scl);
 	if (F->n_f_wts) GMT_free ((void *)F->f_wt);
 }
 
