@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt2rgb.c,v 1.51 2008/03/24 08:58:30 guru Exp $
+ *	$Id: gmt2rgb.c,v 1.55 2009/01/09 04:02:32 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -58,7 +58,8 @@ struct GMT2RGB_CTRL {
 
 int main (int argc, char **argv)
 {
-	int i, k, k3, nm, error = 0, index, irgb[3], entry, one_or_zero, pos;
+	int i, error = 0, index, irgb[3], entry, one_or_zero, pos;
+	GMT_LONG nm, k, k3;
 	BOOLEAN guess = FALSE;
 	float *z;
 	double w, e, s, n;
@@ -160,7 +161,7 @@ int main (int argc, char **argv)
 		fprintf (stderr,"\t      the default values of dx = dy = 1 and region 1/ncols/1/nrows.\n");
 		fprintf (stderr,"\t  (2) A regular z grid file.  Use -C to provide a cpt file with which\n");
 		fprintf (stderr,"\t      to convert z to r/g/b triplets. -R, -I, and -F are ignored.\n");
-		fprintf (stderr,"\t  (3) A RGB or RGBA raw rasterfile. Since raw rastefiles have no header, you have to\n");
+		fprintf (stderr,"\t  (3) A RGB or RGBA raw rasterfile. Since raw rasterfiles have no header, you have to\n");
 		fprintf (stderr,"\t      give the image dimensions via -W\n");
 		fprintf (stderr,"\t      However, you may take the chance of letting the program try to\n");
 		fprintf (stderr,"\t      guess the image dimensions (slow, via FFT spectrum).\n");
@@ -185,6 +186,8 @@ int main (int argc, char **argv)
 
 	/* Check that the options selected are mutually consistent */
 
+	GMT_check_lattice (&Ctrl->I.xinc, &Ctrl->I.yinc, &Ctrl->F.active, &Ctrl->I.active);
+
 	if (!Ctrl->C.active) {
 		if (!file) {
 			fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify input raster file\n", GMT_program);
@@ -239,7 +242,8 @@ int main (int argc, char **argv)
 	if (Ctrl->C.active) {
 		GMT_read_cpt (Ctrl->C.file);
 		GMT_err_fail (GMT_read_grd_info (file, &grd), file);
-		nm = grd.nx * grd.ny;
+		nm = GMT_get_nm (grd.nx, grd.ny);
+		
 		z = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 		for (i = 0; i < 3; i++) {	/* Do the r, g, and b channels */
 			if (Ctrl->L.active && Ctrl->L.layer != rgb[i]) continue;
@@ -312,7 +316,7 @@ int main (int argc, char **argv)
 		grd.x_min = w;	grd.x_max = e;
 		grd.y_min = s;	grd.y_max = n;
 		grd.x_inc = Ctrl->I.xinc;	grd.y_inc = Ctrl->I.yinc;
-		nm = grd.nx * grd.ny;
+		nm = GMT_get_nm (grd.nx, grd.ny);
 
 		GMT_err_fail (GMT_grd_RI_verify (&grd, 1), Ctrl->G.name);
 
@@ -347,7 +351,6 @@ int main (int argc, char **argv)
 	exit (EXIT_SUCCESS);
 }
 
-
 unsigned char *loadraw (char *file, struct imageinfo *header, int byte_per_pixel, int nx, int ny) {
 	/* loadraw reads a raw binary grb or rgba rasterfile of depth 24, or 32 into memory */
 
