@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_globals.h,v 1.33 2008/04/15 15:55:29 remko Exp $
+ *	$Id: gmt_globals.h,v 1.37 2009/02/15 19:18:29 remko Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -83,7 +83,7 @@ struct GMT_DEFAULTS gmtdefs = {		/* Initial default values */
 	1,			/* OBLIQUE_ANNOTATION */
 	{255, 255, 255},	/* PAGE_COLOR */
 	FALSE,			/* PORTRAIT */
-	{612, 792},		/* PAPER_MEDIA (US Letter) */
+	{612.0, 792.0},		/* PAPER_MEDIA (US Letter) */
 	{85.0, 90.0},		/* POLAR_CAP (controls gridlines near poles) */
 	0,			/* PS_COLOR (2 = HSV, 1 = CMYK, 0 = RGB) */
 	0,			/* PS_IMAGE_COMPRESS (0 = NONE, 1 = RLE, 2 = LZW) */
@@ -119,7 +119,7 @@ struct GMT_DEFAULTS gmtdefs = {		/* Initial default values */
 	"+D",			/* OUTPUT_DEGREE_FORMAT */
 	"hh:mm:ss",		/* PLOT_CLOCK_FORMAT */
 	"yyyy-mm-dd",		/* PLOT_DATE_FORMAT */
-	"+ddd:mm:ss",		/* PLOT_DEGREE_FORMAT */
+	"ddd:mm:ss",		/* PLOT_DEGREE_FORMAT */
 	{ "full", "full" },	/* TIME_FORMAT_PRIMARY, TIME_FORMAT_SECONDARY */
 	FALSE,			/* TIME_IS_INTERVAL */
 	0.5,			/* TIME_INTERVAL_FRACTION */
@@ -281,6 +281,7 @@ char **GMT_file_suffix;
 double GMT_data[BUFSIZ];
 int GMT_pad[4] = {0, 0, 0, 0};
 int GMT_inc_code[2] = {0, 0};
+struct GMT_GRD_INFO GMT_grd_info;
 
 /*--------------------------------------------------------------------*/
 /*	For misc purposes */
