@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_grdio.c,v 1.116 2008/04/07 18:48:05 remko Exp $
+ *	$Id: gmt_grdio.c,v 1.119 2009/01/09 04:02:32 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -251,14 +251,14 @@ int GMT_grd_get_format (char *file, struct GRD_HEADER *header, BOOLEAN magic)
 		header->name[j] = 0;
 		sscanf (header->name, "%[^?]?%s", tmp, header->varname);    /* Strip off variable name */
 		if (magic) {	/* Reading: possibly prepend a path from GMT_[GRID|DATA|IMG]DIR */
-			if (!GMT_getdatapath (tmp, header->name)) return (GMT_GRDIO_FILE_NOT_FOUND);	/* Reading: possily prepended a path from GMT_[GRID|DATA|IMG]DIR */
+			if (!GMT_getdatapath (tmp, header->name)) return (GMT_GRDIO_FILE_NOT_FOUND);	/* Reading: possibly prepended a path from GMT_[GRID|DATA|IMG]DIR */
 		}
 		else		/* Writing: store truncated pathname */
 			strcpy (header->name, tmp);
 	}
 	else if (magic) {	/* Reading: determine file format automatically based on grid content */
 		sscanf (header->name, "%[^?]?%s", tmp, header->varname);    /* Strip off variable name */
-		if (!GMT_getdatapath (tmp, header->name)) return (GMT_GRDIO_FILE_NOT_FOUND);	/* Possily prepended a path from GMT_[GRID|DATA|IMG]DIR */
+		if (!GMT_getdatapath (tmp, header->name)) return (GMT_GRDIO_FILE_NOT_FOUND);	/* Possibly prepended a path from GMT_[GRID|DATA|IMG]DIR */
 		/* First check if we have a netCDF grid. This MUST be first, because ?var needs to be stripped off. */
 		if ((val = GMT_is_nc_grid (header)) >= 0) return (GMT_NOERROR);
 		/* Continue only when file was a pipe or when nc_open didn't like the file. */
@@ -777,7 +777,7 @@ void GMT_grd_shift (struct GRD_HEADER *header, float *grd, double shift)
 		header->x_max -= 360.0;
 	}
 
-	if (n_warn) fprintf (stderr, "%s: Gridline-registered global grid has inconsistant values at repeated node for %ld rows\n", GMT_program, n_warn);
+	if (n_warn) fprintf (stderr, "%s: Gridline-registered global grid has inconsistent values at repeated node for %ld rows\n", GMT_program, n_warn);
 
 	GMT_free ((void *) tmp);
 }
@@ -939,7 +939,7 @@ int GMT_adjust_loose_wesn (double *w, double *e, double *s, double *n, struct GR
 			break;
 	}
 	global = GMT_grd_is_global (header);
-	if (GMT_io.in_col_type[0] != GMT_IS_LON || GMT_360_RANGE (*w, *e)) {	/* Do this unless a 360 longitude wrap */
+	if (!(GMT_io.in_col_type[0] == GMT_IS_LON && GMT_360_RANGE (*w, *e))) {    /* Do this unless a 360 longitude wrap */
 		small = GMT_SMALL * header->x_inc;
 		start = (GMT_io.in_col_type[0] == GMT_IS_LON && GMT_360_RANGE (*w, header->x_min)) ? *w : header->x_min;
 
