@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_init.h,v 1.75 2008/03/24 08:58:30 guru Exp $
+ *	$Id: gmt_init.h,v 1.78 2009/01/09 04:02:32 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -49,6 +49,8 @@ EXTERN_MSC void GMT_cont_syntax (int indent, int kind);
 EXTERN_MSC void GMT_default_error (char option);
 EXTERN_MSC void GMT_end (int argc, char **argv);
 EXTERN_MSC void GMT_explain_option (char option);
+EXTERN_MSC void GMT_mapscale_syntax (char option, char *string);
+EXTERN_MSC void GMT_maprose_syntax (char option, char *string);
 EXTERN_MSC void GMT_fill_syntax (char option, char *string);
 EXTERN_MSC void GMT_getdefaults (char *this_file);
 EXTERN_MSC void GMT_putdefaults (char *this_file);
@@ -68,5 +70,6 @@ EXTERN_MSC int GMT_getdefpath (int get, char **path);
 EXTERN_MSC int GMT_parse_symbol_option (char *text, struct GMT_SYMBOL *p, int mode, BOOLEAN cmd);
 EXTERN_MSC void GMT_extract_label (char *line, char *label);
 EXTERN_MSC int GMT_setparameter(char *keyword, char *value);
+EXTERN_MSC void GMT_check_lattice (double *x_inc, double *y_inc, BOOLEAN *pixel, BOOLEAN *active);
 
 #endif /* GMT_INIT_H */
