@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_notunix.h,v 1.19 2008/05/02 00:44:42 guru Exp $
+ *	$Id: gmt_notunix.h,v 1.25 2009/01/16 01:03:31 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -109,7 +109,7 @@
 #define strdup(s) _strdup(s)
 #define STAT _stat
 
-typedef int mode_t;		/* mdoe_t not defined under Windows; assumed a signed 4-byte integer */
+typedef int mode_t;		/* mode_t not defined under Windows; assumed a signed 4-byte integer */
 #ifdef _WIN64
 typedef __int64 GMT_LONG;		/* A signed 8-byte integer; otherwise set in gmt.h */
 #endif
@@ -135,6 +135,7 @@ typedef __int64 GMT_LONG;		/* A signed 8-byte integer; otherwise set in gmt.h */
 #define DIR_DELIM '\\'	/* Backslash as directory delimiter */
 
 #include <io.h>
+#include <direct.h>
 
 /* GMT normally gets these macros from unistd.h */
 
@@ -154,26 +155,41 @@ struct passwd {
 };
 
 /* These two functions prototypes are normally in pwd.h & unistd.h;
- * Here, they are defined as dummies at the bottom of gmt_init.c */
+ * Here, they are defined as dummies at the bottom of gmt_init.c
+ * since there are no equivalents under Windows. */
 
 EXTERN_MSC struct passwd *getpwuid (const int uid);
 EXTERN_MSC int getuid (void);
 
 /* getcwd is usually in unistd.h; we use a macro here
- * since the same function under WIN32 is prefixed with _ */
+ * since the same function under WIN32 is prefixed with _;
+ * it is defined in direct.h */
 
-extern char *_getcwd (const char *path, int len);
 #define getcwd(path, len) _getcwd(path, len)
 
 /* access is usually in unistd.h; we use a macro here
- * since the same function under WIN32 is prefixed with _ */
+ * since the same function under WIN32 is prefixed with _
+ * and defined in io.h */
 
-extern int _access (const char *path, int mode);
 #define access(path, mode) _access(path, mode)
 
-/* fileno and setmode have leading _ under WIN32 */
+/* mkdir is usually in sys/stat.h; we use a macro here
+ * since the same function under WIN32 is prefixed with _
+ * and furthermore does not pass the mode argument;
+ * it is defined in direct.h */
+
+#define mkdir(path,mode) _mkdir(path)
+
+/* fileno is usually in stdio.h; we use a macro here
+ * since the same function under WIN32 is prefixed with _
+ * and defined in stdio.h */
 
 #define fileno(stream) _fileno(stream)
+
+/* setmode is usually in unistd.h; we use a macro here
+ * since the same function under WIN32 is prefixed with _
+ * and defined in io.h */
+
 #define setmode(fd,mode) _setmode(fd,mode)
 
 EXTERN_MSC void GMT_setmode (int i_or_o);
