@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_project.h,v 1.64 2008/04/29 19:57:06 guru Exp $
+ *	$Id: gmt_project.h,v 1.68 2009/02/05 21:54:42 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -287,6 +287,7 @@ struct GMT_MAP_PROJECTIONS {
 #define GMT_IS_PLAIN	0	/* Plain baseframe */
 #define GMT_IS_FANCY	1	/* Fancy baseframe */
 #define GMT_IS_ROUNDED	2	/* Rounded, fancy baseframe */
+#define GMT_IS_INSIDE	3	/* Draws frame ticks/annotations on the inside of boundary */
 
 /* Define the 6 axis items that each axis can have (some are mutually exclusive: only one ANNOT/INTV for upper and lower) */
 
@@ -345,6 +346,9 @@ struct GMT_THREE_D {
 	double cos_az, sin_az, cos_el, sin_el;
 	double corner_x[4], corner_y[4];
 	double xmin, xmax, ymin, ymax;
+	double world_x, world_y, world_z;	/* Users coordinates of fixed point */
+	double view_x, view_y;			/* Desired projected 2-D coordinates of fixed point */
+	double x_off, y_off;			/* Offsets to the final projected coordinates */
 	double phi[3];		/* Angle each axis makes with horizontal */
 	double xshrink[3];	/* Shrinkage in x-dir due to projection */
 	double yshrink[3];	/* Same for y-dir */
@@ -355,6 +359,9 @@ struct GMT_THREE_D {
 	int k;			/* For drawing-axis. 0 = plot in x dir, 1 in y */
 	int face[3];		/* Tells if this facet has normal in pos direction */
 	int draw[4];		/* axes to draw */
+	BOOLEAN fixed;		/* TRUE if we want a given point to be fixed in the projection [for animations] */
+	BOOLEAN world_given;	/* TRUE if a fixed world point was given in -E ..+glon/lat/z */
+	BOOLEAN view_given;	/* TRUE if a fixed projected point was given in -E ..+cx0/y0 */
 };
 
 struct GMT_DATUM {	/* Main parameter for a particular datum */
