@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_support.h,v 1.34 2008/04/15 15:44:44 remko Exp $
+ *	$Id: gmt_support.h,v 1.37 2009/01/09 04:02:33 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -87,6 +87,7 @@ EXTERN_MSC void GMT_str_toupper (char *string);
 EXTERN_MSC char *GMT_convertpen (struct GMT_PEN *pen, int *width, int *offset, int rgb[]);
 EXTERN_MSC void GMT_fourt (float *data, GMT_LONG *nn, int ndim, int ksign, int iform, float *work);
 EXTERN_MSC int GMT_get_coordinate_label (char *string, struct GMT_PLOT_CALCLOCK *P, char *format, struct GMT_PLOT_AXIS_ITEM *T, double coord);
+EXTERN_MSC int GMT_get_proj3D (char *line, double *az, double *el);
 #ifdef DEBUG
 EXTERN_MSC void *GMT_memory_func (void *prev_addr, size_t nelem, size_t size, char *progname, char *fname, int line);
 EXTERN_MSC void GMT_free_func (void *addr, char *fname, int line);
@@ -94,6 +95,10 @@ EXTERN_MSC void GMT_free_func (void *addr, char *fname, int line);
 EXTERN_MSC void *GMT_memory (void *prev_addr, size_t nelem, size_t size, char *progname);
 EXTERN_MSC void GMT_free (void *addr);
 #endif
+#ifdef GMT_QSORT
+/* Need to replace OS X's qsort with one that works for 64-bit data */
+EXTERN_MSC void GMT_qsort(void *a, size_t n, size_t es, int (*cmp) (const void *, const void *));
+#endif
 
 /* Backwards macro for MB-system support */
 #define GMT_get_rgb24(z,rgb) GMT_get_rgb_from_z(z,rgb)
