@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_vector.c,v 1.20 2008/03/24 08:58:31 guru Exp $
+ *	$Id: gmt_vector.c,v 1.25 2009/02/06 23:00:08 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -279,6 +279,7 @@ int	GMT_jacobi (double *a, GMT_LONG *n, GMT_LONG *m, double *d, double *v, doubl
 	return(0);
 }
 
+#ifdef OBSOLETE
 int	GMT_jacobi_old (double *a, int *n, int *m, double *d, double *v, double *b, double *z, int *nrots)
 /*
  *
@@ -467,6 +468,148 @@ int	GMT_jacobi_old (double *a, int *n, int *m, double *d, double *v, double *b,
 	}
 	return(0);
 }
+#endif
+
+void GMT_gauss (double *a, double *vec, int n_in, int nstore_in, double test, int *ierror, int itriag)
+{
+ 
+/* subroutine gauss, by william menke */
+/* july 1978 (modified feb 1983, nov 85) */
+ 
+/* a subroutine to solve a system of n linear equations in n unknowns*/
+/* gaussian reduction with partial pivoting is used */
+/*      a               (sent, destroyed)       n by n matrix           */
+/*      vec             (sent, overwritten)     n vector, replaced w/ solution*/
+/*      nstore          (sent)                  dimension of a  */
+/*      test            (sent)                  div by zero check number*/
+/*      ierror          (returned)              zero on no error*/
+/*      itriag          (sent)                  matrix triangularized only*/
+/*                                               on TRUE useful when solving*/
+/*                                               multiple systems with same a */
+        static int l1;
+        GMT_LONG *line, *isub, iet, ieb, i = 0, j, k, l, j2, n, nstore;
+        double big, testa, b, sum;
+
+        iet=0;  /* initial error flags, one for triagularization*/
+        ieb=0;  /* one for backsolving */
+	n = (GMT_LONG)n_in;
+	nstore = (GMT_LONG)nstore_in;
+	line = (GMT_LONG *) GMT_memory (VNULL, (size_t)n, sizeof (GMT_LONG), "GMT_gauss");
+	isub = (GMT_LONG *) GMT_memory (VNULL, (size_t)n, sizeof (GMT_LONG), "GMT_gauss");
+
+/* triangularize the matrix a*/
+/* replacing the zero elements of the triangularized matrix */
+/* with the coefficients needed to transform the vector vec */
+
+        if (itriag) {   /* triangularize matrix */
+ 
+                for( j=0; j<n; j++ ) {      /*line is an array of flags*/
+                        line[j]=0; 
+                        /* elements of a are not moved during pivoting*/
+                        /* line=0 flags unused lines */
+                        }    /*end for j*/
+                        
+                for( j=0; j<n-1; j++ ) {
+                        /*  triangularize matrix by partial pivoting */
+                       big = 0.0; /* find biggest element in j-th column*/
+                                  /* of unused portion of matrix*/
+                       for( l1=0; l1<n; l1++ ) {
+                               if( line[l1]==0 ) {
+                                       testa=(double) fabs((double) (*(a+l1*nstore+j)));
+                                       if (testa>big) {
+                                                i=l1;
+                                                big=testa;
+                                                } /*end if*/
+                                        } /*end if*/
+                                } /*end for l1*/
+                       if( big<=test) {   /* test for div by 0 */
+                               iet=1;
+                               } /*end if*/
+ 
+                       line[i]=1;  /* selected unused line becomes used line */
+                       isub[j]=i;  /* isub points to j-th row of tri. matrix */
+ 
+                       sum=1.0/(*(a+i*nstore+j)); 
+                                /*reduce matrix towards triangle */
+                       for( k=0; k<n; k++ ) {
+                                if( line[k]==0 ) {
+                                        b=(*(a+k*nstore+j))*sum;
+                                        for( l=j+1; l<n; l++ ) {
+                                               *(a+k*nstore+l)= (*(a+k*nstore+l)) -b*(*(a+i*nstore+l));
+                                               } /*end for l*/
+                                       *(a+k*nstore+j)=b;
+                                        } /*end if*/
+                                } /*end for k*/
+                        } /*end for j*/
+ 
+               for( j=0; j<n; j++ ) {
+                        /*find last unused row and set its pointer*/
+                        /*  this row contains the apex of the triangle*/
+                        if( line[j]==0) {
+                                l1=j;   /*apex of triangle*/
+                                isub[n-1]=j;
+                                break;
+                                } /*end if*/
+                        } /*end for j*/
+ 
+                } /*end if itriag true*/
+                
+        /*start backsolving*/
+        
+        for( i=0; i<n; i++ ) {  /* invert pointers. line(i) now gives*/
+                                /* row no in triang matrix of i-th row*/
+                                /* of actual matrix */
+                line[isub[i]] = i;
+                } /*end for i*/
+ 
+        for( j=0; j<n-1; j++) { /*transform the vector to match triang. matrix*/
+               b=vec[isub[j]];
+               for( k=0; k<n; k++ ) {
+                      if (line[k]>j) {  /* skip elements outside of triangle*/
+                                vec[k]=vec[k]-(*(a+k*nstore+j))*b;
+                                } /*end if*/
+                        } /*end for k*/
+                } /*end for j*/
+ 
+      b = *(a+l1*nstore+(n-1));   /*apex of triangle*/
+      if( ((double)fabs( (double) b))<=test) {
+                /*check for div by zero in backsolving*/
+                ieb=2;
+                } /*end if*/
+      vec[isub[n-1]]=vec[isub[n-1]]/b;
+ 
+      for( j=n-2; j>=0; j-- ) { /* backsolve rest of triangle*/
+                sum=vec[isub[j]];
+                for( j2=j+1; j2<n; j2++ ) {
+                        sum = sum - vec[isub[j2]] * (*(a+isub[j]*nstore+j2));
+                        } /*end for j2*/
+                        b = *(a+isub[j]*nstore+j);
+               if( ((double)fabs((double)b))<=test) {
+                        /* test for div by 0 in backsolving */
+                        ieb=2;
+                        } /*end if*/
+                vec[isub[j]]=sum/b;   /*solution returned in vec*/
+                } /*end for j*/
+
+/*put the solution vector into the proper order*/
+
+      for( i=0; i<n; i++ ) {    /* reorder solution */
+                for( k=i; k<n; k++ ) {  /* search for i-th solution element */
+                        if( line[k]==i ) {
+                                j=k;
+                                break;
+                                } /*end if*/
+                        } /*end for k*/
+               b = vec[j];       /* swap solution and pointer elements*/
+               vec[j] = vec[i];
+               vec[i] = b;
+               line[j] = line[i];
+                } /*end for i*/
+ 
+		GMT_free ((void *)isub);
+		GMT_free ((void *)line);
+      *ierror = iet + ieb;   /* set final error flag*/
+}
 
 /*  cartesian_stuff.c  --  bits and pieces for doing spherical trig
  *  in terms of dot and cross products.
@@ -555,6 +698,7 @@ GMT_LONG GMT_fix_up_path (double **a_lon, double **a_lat, GMT_LONG n, double ste
 	 */
       
 	GMT_LONG i, j, n_tmp, n_step = 0, n_alloc;
+	BOOLEAN meridian;
 	double *lon_tmp, *lat_tmp, *old;
 	double a[3], b[3], x[3], *lon, *lat;
 	double c, d, fraction, theta, minlon, maxlon;
@@ -642,6 +786,7 @@ GMT_LONG GMT_fix_up_path (double **a_lon, double **a_lat, GMT_LONG n, double ste
 			fraction = 1.0 / (float) n_step;
 			minlon = MIN(lon[i-1],lon[i]);
 			maxlon = MAX(lon[i-1],lon[i]);
+			meridian = GMT_IS_ZERO (maxlon - minlon);	/* A meridian; make a gap so tests below will give right range */
 			for (j = 1; j < n_step; j++) {
 				c = j * fraction;
 				d = 1 - c;
@@ -650,7 +795,9 @@ GMT_LONG GMT_fix_up_path (double **a_lon, double **a_lat, GMT_LONG n, double ste
 				x[2] = a[2] * d + b[2] * c;
 				GMT_normalize3v (x);
 				GMT_cart_to_geo (&lat_tmp[n_tmp], &lon_tmp[n_tmp], x, FALSE);
-				if (lon_tmp[n_tmp] < minlon)
+				if (meridian)
+					lon_tmp[n_tmp] = minlon;
+				else if (lon_tmp[n_tmp] < minlon)
 					lon_tmp[n_tmp] += TWO_PI;
 				else if (lon_tmp[n_tmp] > maxlon)
 					lon_tmp[n_tmp] -= TWO_PI;
