@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtconvert.c,v 1.52 2008/03/24 08:58:31 guru Exp $
+ *	$Id: gmtconvert.c,v 1.54 2009/01/09 04:02:33 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -122,7 +122,7 @@ int main (int argc, char **argv)
 				case 'F':
 					pos = 0;
 					Ctrl->F.active = TRUE;
-					while ((GMT_strtok (&argv[i][2], ",", &pos, ptr))) {	/* Proces all tokens */
+					while ((GMT_strtok (&argv[i][2], ",", &pos, ptr))) {	/* Process all tokens */
 						if (strchr (ptr, '-'))	/* Range of columns given. e.g., 7-9 */
 							sscanf (ptr, "%d-%d", &start, &stop);
 						else if (isdigit ((int)ptr[0]))	/* Just a single column, e.g., 13 */
@@ -293,7 +293,7 @@ int main (int argc, char **argv)
 			}
 		}
 		n_total_read ++;
-		if (all_set == 1) {	/* Means we know how many total colums and can now allocate memory */
+		if (all_set == 1) {	/* Means we know how many total columns and can now allocate memory */
 			all_set = 2;
 			if (n_out == 0) {	/* No cut action, just paste and return all columns */
 				n_out = n_tot_cols;
@@ -346,7 +346,7 @@ int main (int argc, char **argv)
 				n_total_read ++;
 			}
 
-			if (all_set == 1) {	/* Well, we still havent allocated space etc */
+			if (all_set == 1) {	/* Well, we still have not allocated space etc */
 				all_set = 2;
 				if (n_out == 0) {	/* No cut action, just paste */
 					n_out = n_tot_cols;
