@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtselect.c,v 1.92 2008/05/06 23:53:53 guru Exp $
+ *	$Id: gmtselect.c,v 1.95 2009/01/16 21:43:11 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -77,6 +77,7 @@ struct GMTSELECT_CTRL {	/* All control options for this program (except common a
 	} C;
 	struct D {	/* -D<resolution> */
 		BOOLEAN active;
+		BOOLEAN force;	/* if TRUE, select next highest level if current set is not avaialble */
 		char set;	/* One of f, h, i, l, c */
 	} D;
 	struct L {	/* -L[p][<dist>/<lfile>] */
@@ -182,6 +183,7 @@ int main (int argc, char **argv)
 				case 'D':
 					Ctrl->D.active = TRUE;
 					Ctrl->D.set = argv[i][2];
+					if (argv[i][3] == '+') Ctrl->D.force = TRUE;
 					break;
 				case 'L':
 					if (argv[i][2]) {	/* Set line options */
@@ -296,7 +298,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "gmtselect %s - Select data subsets based on multiple spatial criteria\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: gmtselect <infiles> [-A<min_area>[/<min_level>/<max_level>]] [-C[f]<dist>/<ptfile>]\n");
-		fprintf (stderr, "\t[-D<resolution>] [-F<polygon>] [%s] [-L[p]<dist>/<lfile>] [%s] [-I[cflrsz]\n", GMT_J_OPT, GMT_H_OPT);
+		fprintf (stderr, "\t[-D<resolution>][+] [-F<polygon>] [%s] [-L[p]<dist>/<lfile>] [%s] [-I[cflrsz]\n", GMT_J_OPT, GMT_H_OPT);
 		fprintf (stderr, "\t[%s] [-N<maskvalues>[o]] [%s] [-V[l]]\n\t[%s] [-Z<min>/<max>] [-%s] [%s]\n\n", GMT_M_OPT, GMT_Rgeo_OPT, GMT_t_OPT, GMT_b_OPT, GMT_f_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
@@ -318,6 +320,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   i - intermediate resolution\n");
 		fprintf (stderr, "\t   l - low resolution [Default]\n");
 		fprintf (stderr, "\t   c - crude resolution, for tasks that need crude continent outlines only\n");
+		fprintf (stderr, "\t   Append + to use a lower resolution should the chosen one not be available [abort].\n");
 		fprintf (stderr, "\t-L Pass locations that are within <dist> of any line in ASCII <linefile>\n");
 		fprintf (stderr, "\t   Give distance as 0 if 2nd column of segment headers have individual distances.\n");
 		fprintf (stderr, "\t   Distances are Cartesian and in user units [or spherical in km if -fg is used].\n");
@@ -398,7 +401,7 @@ int main (int argc, char **argv)
 		GMT_io.in_col_type[1] = GMT_IS_LAT;
 	}
 	if (project_info.region_supplied) {	/* -R was set directly or indirectly; hence must set -J if not supplied */
-		if (project_info.projection == GMT_NO_PROJ) {	/* -J not specifed, set one implicitly */
+		if (project_info.projection == GMT_NO_PROJ) {	/* -J not specified, set one implicitly */
 			if (GMT_io.in_col_type[0] == GMT_IS_LON) {	/* We know we have geographic data (either via -f or -N) */
 				project_info.degree[0] = project_info.degree[1] = TRUE;
 			}
@@ -422,6 +425,7 @@ int main (int argc, char **argv)
 	if (do_project && gmtdefs.verbose) fprintf (stderr, "%s: Warning: -J means all data will be projected before tests are applied\n", GMT_program);
 	 
 	if (Ctrl->N.active) {
+		if (Ctrl->D.force) Ctrl->D.set = GMT_shore_adjust_res (Ctrl->D.set);
 		if (Ctrl->D.active) base = GMT_set_resolution (&Ctrl->D.set, 'D');
 		if (dry_wet_only) {	/* Post-process -N choice */
 			Ctrl->N.mask[3] = Ctrl->N.mask[1];
