@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grd2cpt.c,v 1.49 2008/03/24 08:58:31 guru Exp $
+ *	$Id: grd2cpt.c,v 1.54 2009/01/09 04:02:33 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -88,17 +88,19 @@ int main (int argc, char **argv)
 {
 	BOOLEAN error = FALSE, global = FALSE;
 
-	char *grdfile = CNULL, CPT_lis[BUFSIZ], CPT_file[BUFSIZ], format[BUFSIZ], kind;
+#define mgrd 1000
 
-	int j, nx, ny;
+	char *grdfile[mgrd], CPT_lis[BUFSIZ], CPT_file[BUFSIZ], format[BUFSIZ], kind;
+
+	int j, ngrd = 0;
 	
-	GMT_LONG i, nxy, nfound, ngood;
+	GMT_LONG i, nxy, nxyg, nfound, ngood;
 
 	float	*zdata;
 
 	double *z, mean, sd, w, e, s, n;
 
-	struct GRD_HEADER grd;
+	struct GRD_HEADER grd, new;
 	struct CDF_CPT {
 		double	z;	/* Data value  */
 		double	f;	/* Cumulative distribution function f(z)  */
@@ -226,19 +228,35 @@ int main (int argc, char **argv)
 			}
 		}
 		else {
-			grdfile = argv[i];
-			if (GMT_err_pass (GMT_read_grd_info (grdfile, &grd), grdfile)) error++;
+			if (ngrd > mgrd) {
+				fprintf (stderr, "%s: GMT USAGE ERROR:  Cannot handle more than %i grids\n", GMT_program, mgrd);
+				exit(EXIT_FAILURE);
+			}
+
+			grdfile[ngrd] = argv[i];
+
+			if (ngrd == 0) {
+				if (GMT_err_pass (GMT_read_grd_info (grdfile[0], &grd), grdfile[0])) error++;
+			}
+			else {
+				if (GMT_err_pass (GMT_read_grd_info (grdfile[ngrd], &new), grdfile[ngrd])) error++;
+				if (new.x_min != grd.x_min || new.x_max != grd.x_max || new.y_min != grd.y_min || new.y_max != grd.y_max || new.nx != grd.nx || new.ny != grd.ny) {
+					fprintf (stderr, "%s: GMT USAGE ERROR:  Grid %s does not have the same dimensions and size as grid %s\n", GMT_program, grdfile[ngrd], grdfile[0]);
+					exit (EXIT_FAILURE);
+				}
+			}
+			ngrd++;
 		}
 	}
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
-		fprintf (stderr, "grd2cpt %s - Make a a linear or histogram-equalized color palette table from a grdfile\n\n", GMT_VERSION);
-		fprintf (stderr, "usage: grd2cpt <grdfile> [-C<table>] [-D] [-E<nlevels> [-I] [-L<min_limit>/<max_limit>]\n");
+		fprintf (stderr, "grd2cpt %s - Make a linear or histogram-equalized color palette table from a grdfile\n\n", GMT_VERSION);
+		fprintf (stderr, "usage: grd2cpt <grdfiles> [-C<table>] [-D] [-E<nlevels> [-I] [-L<min_limit>/<max_limit>]\n");
 		fprintf (stderr, "\t[-M] [-N] [-Q[i|o]] [%s] [-S<z_start>/<z_stop>/<z_inc>] [-T<-|+|=|_>] [-V] [-Z]\n", GMT_Rgeo_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
-		fprintf (stderr, "\t<grdfile> is the name of the 2-D binary data set\n");
+		fprintf (stderr, "\t<grdfiles> names of one or more 2-D binary data sets\n");
 		fprintf (stderr, "\n\tOPTIONS:\n");
 		fprintf (stderr, "\t-C  Specify a colortable [Default is rainbow]:\n");
 		fprintf (stderr, "\t   [Original z-range is given in brackets]\n");
@@ -279,6 +297,10 @@ int main (int argc, char **argv)
 
 	error += GMT_set_cpt_path (CPT_file, Ctrl->C.file);
 
+	if (ngrd < 1) {
+		fprintf(stderr,"%s: GMT USAGE ERROR:  No grid name(s) specified.\n", GMT_program);
+		error++;
+	}
 	if (Ctrl->L.active && Ctrl->L.min >= Ctrl->L.max) {
 		fprintf(stderr,"%s: GMT SYNTAX ERROR -L option:  min_limit must be less than max_limit.\n", GMT_program);
 		error++;
@@ -308,19 +330,18 @@ int main (int argc, char **argv)
 			fprintf (stderr, "%s: GMT ERROR: Subset exceeds data domain!\n", GMT_program);
 			exit (EXIT_FAILURE);
 		}
-		nx = GMT_get_n (w, e, grd.x_inc, grd.node_offset);
-		ny = GMT_get_n (s, n, grd.y_inc, grd.node_offset);
-		nxy = ((size_t)nx) * ((size_t)ny);
-
-		zdata = (float *) GMT_memory (VNULL, (size_t) nxy, sizeof (float), GMT_program);
-
-		GMT_err_fail (GMT_read_grd (grdfile, &grd, zdata, w, e, s, n, GMT_pad, FALSE), grdfile);
+		nxy = GMT_get_nm (GMT_get_n (w, e, grd.x_inc, grd.node_offset), GMT_get_n (s, n, grd.y_inc, grd.node_offset));
 	}
-	else {
-		nxy = ((size_t)grd.nx) * ((size_t)grd.ny);
-		zdata = (float *) GMT_memory (VNULL, (size_t) nxy, sizeof (float), GMT_program);
+	else
+		nxy = GMT_get_nm (grd.nx, grd.ny);
 
-		GMT_err_fail (GMT_read_grd (grdfile, &grd, zdata, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), grdfile);
+	nxyg = GMT_get_nm (nxy, ngrd);
+
+	zdata = (float *) GMT_memory (VNULL, (size_t) nxyg, sizeof (float), GMT_program);
+
+	for (i = 0; i < ngrd; i++) {
+		GMT_err_fail (GMT_read_grd_info (grdfile[i], &grd), grdfile[i]);
+		GMT_err_fail (GMT_read_grd (grdfile[i], &grd, &(zdata[i*nxy]), w, e, s, n, GMT_pad, FALSE), grdfile[i]);
 	}
 
 	/* Loop over the file and find NaNs.  If set limits, may create more NaNs  */
@@ -331,7 +352,7 @@ int main (int argc, char **argv)
 
 		grd.z_min = Ctrl->L.min;
 		grd.z_max = Ctrl->L.max;
-		for (i = 0; i < nxy; i++) {
+		for (i = 0; i < nxyg; i++) {
 			if (GMT_is_fnan (zdata[i]))
 				nfound++;
 			else {
@@ -349,7 +370,7 @@ int main (int argc, char **argv)
 	else {
 		Ctrl->L.min = grd.z_max;	/* This is just to double check grd.z_min, grd.z_max  */
 		Ctrl->L.max = grd.z_min;
-		for (i = 0; i < nxy; i++) {
+		for (i = 0; i < nxyg; i++) {
 			if (GMT_is_fnan (zdata[i]))
 				nfound++;
 			else {
@@ -362,7 +383,7 @@ int main (int argc, char **argv)
 		grd.z_min = Ctrl->L.min;
 		grd.z_max = Ctrl->L.max;
 	}
-	ngood = nxy - nfound;	/* This is the number of non-NaN points for the cdf function  */
+	ngood = nxyg - nfound;	/* This is the number of non-NaN points for the cdf function  */
 	mean /= ngood;
 	sd /= ngood;
 	sd = sqrt(sd - mean*mean);
@@ -459,7 +480,7 @@ int main (int argc, char **argv)
 			cdf_cpt[j].f = 1.0;
 		else {
 			nfound = 0;
-			for (i = 0; i < nxy; i++) {
+			for (i = 0; i < nxyg; i++) {
 				if (!GMT_is_fnan (zdata[i]) && zdata[i] <= cdf_cpt[j].z) nfound++;
 			}
 			cdf_cpt[j].f = (double)(nfound-1)/(double)(ngood-1);
