@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdcontour.c,v 1.131 2008/05/01 03:00:38 guru Exp $
+ *	$Id: grdcontour.c,v 1.135 2009/01/09 04:02:33 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -206,7 +206,7 @@ int main (int argc, char **argv)
 					break;
 				case 'E':
 					Ctrl->E.active = TRUE;
-					sscanf (&argv[i][2], "%lf/%lf", &Ctrl->E.azimuth, &Ctrl->E.elevation);
+					error += GMT_get_proj3D (&argv[i][2], &Ctrl->E.azimuth, &Ctrl->E.elevation);
 					break;
 				case 'F':
 					Ctrl->F.active = TRUE;
@@ -312,7 +312,7 @@ int main (int argc, char **argv)
 							GMT_pen_syntax ('W', " ");
 							error++;
 						}
-						if (j == k) Ctrl->W.pen[1] = Ctrl->W.pen[0];	/* Must copy since it wasnt -Wc or -Wa after all */
+						if (j == k) Ctrl->W.pen[1] = Ctrl->W.pen[0];	/* Must copy since it was not -Wc nor -Wa after all */
 					}
 					break;
 				case 'Z':
@@ -333,7 +333,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr,"grdcontour %s - Contouring of 2-D gridded data sets\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: grdcontour <grdfile> -C<cont_int> %s\n", GMT_J_OPT);
-		fprintf (stderr, "\t[-A[-|<annot_int>][<labelinfo>] [%s] [-D<dumpfile>] [-Eazimuth/elevation] [-F[l|r]] [%s]\n", GMT_B_OPT, GMT_CONTG);
+		fprintf (stderr, "\t[-A[-|<annot_int>][<labelinfo>] [%s] [-D<dumpfile>] [%s] [-F[l|r]] [%s]\n", GMT_B_OPT, GMT_E_OPT, GMT_CONTG);
 		fprintf (stderr, "\t[-K] [-L<Low/high>] [%s] [-O] [-P] [-Q<cut>] [%s] [-S<smooth>]\n", GMT_Mo_OPT, GMT_Rgeo_OPT);
 		fprintf (stderr, "\t[-T[+|-][<gap>[c|i|m|p]/<length>[c|i|m|p]][:LH]] [%s] [-V] [-W[+]<type><pen>]\n", GMT_U_OPT);
 		fprintf (stderr, "\t[%s] [%s] [-Z[<fact>[/shift>]][p]] [%s] [%s]\n\n", GMT_X_OPT, GMT_Y_OPT, GMT_bo_OPT, GMT_c_OPT);
@@ -360,7 +360,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   where <cont> is the contour value and # is a segment counter.\n");
 		fprintf (stderr, "\t   _i is inserted for interior (closed) contours, with xyz (ascii) or b (binary) as extension.\n");
 		fprintf (stderr, "\t   However, if -D- is given then files are C#_e or C#_i plus extension, where # is a running number.\n");
-		fprintf (stderr, "\t-E set azimuth and elevation of viewpoint for 3-D perspective [180/90]\n");
+		GMT_explain_option ('E');
 		fprintf (stderr, "\t-F force dumped contours to be oriented so that the higher z-values are to the left (-Fl [Default])\n");
 		fprintf (stderr, "\t   or right (-Fr) as we move along the contour [Default is not oriented]\n");
 		fprintf (stderr, "\t-G Controls placement of labels along contours.  Choose among five algorithms:\n");
@@ -378,7 +378,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   at approximately gridsize/<smooth> intervals\n");
 		fprintf (stderr, "\t-T will embellish innermost, closed contours with ticks pointing in the downward direction\n");
 		fprintf (stderr, "\t   User may specify to tick only highs (-T+) or lows (-T-) [-T means both]\n");
-		fprintf (stderr, "\t   Append spacing/ticklength (apppend units) to change defaults [%g/%g %s]\n",
+		fprintf (stderr, "\t   Append spacing/ticklength (append units) to change defaults [%g/%g %s]\n",
 			Ctrl->T.spacing*GMT_u2u[GMT_INCH][gmtdefs.measure_unit], Ctrl->T.length*GMT_u2u[GMT_INCH][gmtdefs.measure_unit], GMT_unit_names[gmtdefs.measure_unit]);
 		fprintf (stderr, "\t   Append :LH to plot the characters L and H in the center of closed contours\n");
 		fprintf (stderr, "\t   for local Lows and Highs (e.g, give :-+ to plot - and + signs)\n");
@@ -507,7 +507,8 @@ int main (int argc, char **argv)
 
 	nx = GMT_get_n (data_west, data_east, header.x_inc, header.node_offset);
 	ny = GMT_get_n (data_south, data_north, header.y_inc, header.node_offset);
-	nm = ((size_t)nx) * ((size_t)ny);
+	nm = GMT_get_nm (nx, ny);
+	
 	grd_original = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 	GMT_err_fail (GMT_read_grd (grdfile, &header, grd_original, data_west, data_east, data_south, data_north, GMT_pad, FALSE), grdfile);
 
@@ -860,8 +861,8 @@ void sort_and_plot_ticks (struct SAVE *save, int n, struct GRD_HEADER *h, float
 		if (iy == h->ny) iy--;	/* Check to make sure we don't exceed array bounds in next line. However, iy may thus be wrong */ 
 		save[i].high = (grd[iy*h->nx+ix] > save[i].cval);
 
-		if (save[i].high && !tick_high) continue;	/* Dont tick highs */
-		if (!save[i].high && !tick_low) continue;	/* Dont tick lows */
+		if (save[i].high && !tick_high) continue;	/* Do not tick highs */
+		if (!save[i].high && !tick_low) continue;	/* Do not tick lows */
 
 		if (tick_label) {
 			x_mean = save[i].x[0];
