@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdcut.c,v 1.34 2008/03/24 08:58:31 guru Exp $
+ *	$Id: grdcut.c,v 1.37 2009/01/09 04:02:33 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -40,7 +40,7 @@ int main (int argc, char **argv)
 
 	int	i, nx_old, ny_old, nx_new, ny_new, one_or_zero;
 	
-	size_t	nm;
+	GMT_LONG	nm;
 
 	char *grd_in, format[BUFSIZ];
 
@@ -147,6 +147,8 @@ int main (int argc, char **argv)
 
 	/* Make sure output grid is kosher */
 
+	GMT_adjust_loose_wesn (&w_new, &e_new, &s_new, &n_new, &header);
+
 	test_header.x_min = w_new;	test_header.x_max = e_new;	test_header.x_inc = header.x_inc;
 	test_header.y_min = s_new;	test_header.y_max = n_new;	test_header.y_inc = header.y_inc;
 	GMT_err_fail (GMT_grd_RI_verify (&test_header, 1), Ctrl->G.file);
@@ -179,8 +181,9 @@ int main (int argc, char **argv)
 	nx_new = irint ((e_new - w_new) / header.x_inc) + one_or_zero;
 	ny_new = irint ((n_new - s_new) / header.y_inc) + one_or_zero;
 
-	nm = ((size_t)nx_new) * ((size_t)ny_new);
-	grd = (float *) GMT_memory (VNULL, nm, sizeof (float), GMT_program);
+	nm = GMT_get_nm (nx_new, ny_new);
+	
+	grd = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 	GMT_err_fail (GMT_read_grd (grd_in, &header, grd, w_new, e_new, s_new, n_new, GMT_pad, FALSE), grd_in);
 
 	if (gmtdefs.verbose) {
