@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdfilter.c,v 1.60 2008/03/24 08:58:31 guru Exp $
+ *	$Id: grdfilter.c,v 1.69 2009/01/09 04:02:33 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -64,6 +64,10 @@ struct GRDFILTER_CTRL {
 		BOOLEAN active;
 		double xinc, yinc;
 	} I;
+	struct N {	/* -Np|i|r */
+		BOOLEAN active;
+		int mode;	/* 0 is default (i), 1 is replace (r), 2 is preserve (p) */
+	} N;
 	struct T {	/* -T */
 		BOOLEAN active;
 	} T;
@@ -80,6 +84,10 @@ struct GRDFILTER_CTRL {
 
 #define GRDFILTER_N_FILTERS	9
 
+#define NAN_IGNORE	0
+#define NAN_REPLACE	1
+#define NAN_PRESERVE	2
+
 struct FILTER_INFO {
 	GMT_LONG nx;			/* The max number of filter weights in x-direction */
 	GMT_LONG ny;			/* The max number of filter weights in y-direction */
@@ -96,14 +104,14 @@ struct FILTER_INFO {
 int main (int argc, char **argv)
 {
 	GMT_LONG	nx_out, ny_out, n_in_median, n_nan = 0, i_west, i_east, j_s_pole, j_n_pole;
-	GMT_LONG	j_origin, i_out, j_out, half_nx, i_orig = 0;
+	GMT_LONG	j_origin, i_out, j_out, half_nx, i_orig = 0, n_bad = 0, nm;
 	GMT_LONG	i_in, j_in, ii, jj, i, j, ij_in, ij_out, ij_wt, effort_level;
 	int	filter_type, one_or_zero = 1, GMT_n_multiples = 0;
 	
 	int *i_origin;
 
 
-	BOOLEAN	error, new_range, fast_way, slow = FALSE;
+	BOOLEAN	error, new_range, fast_way, slow = FALSE, same_grid = FALSE;
 	BOOLEAN wrap_case_x = FALSE, wrap_case_y = FALSE, pole_check = FALSE;
 	BOOLEAN full_360, full_180, duplicate_check, i_west_used, i_east_used, row_ok;
 
@@ -186,8 +194,27 @@ int main (int argc, char **argv)
 						error = TRUE;
 					}
 					break;
-				case 'N':	/* Pixel registration OBSOLETE but BACKWARD COMPATIBLE */
-					one_or_zero = 0;
+				case 'N':
+					if (!argv[i][2]) {	/* Pixel registration OBSOLETE but BACKWARD COMPATIBLE for now */
+						one_or_zero = 0;
+					}
+					else {	/* Treatment of NaNs */
+						Ctrl->N.active = TRUE;
+						switch (argv[i][2]) {
+							case 'i':
+								Ctrl->N.mode = NAN_IGNORE;	/* Default */
+								break;
+							case 'r':
+								Ctrl->N.mode = NAN_REPLACE;	/* Replace */
+								break;
+							case 'p':
+								Ctrl->N.mode = NAN_PRESERVE;	/* Preserve */
+								break;
+							default:
+								fprintf (stderr, "%s: GMT SYNTAX ERROR -N option.  Correct syntax: -Ni|p|r\n", GMT_program);
+								break;
+						}
+					}
 					break;
 				case 'T':	/* Toggle registration */
 					Ctrl->T.active = TRUE;
@@ -205,7 +232,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "grdfilter %s - Filter a 2-D grid file in the space (or time) domain\n\n", GMT_VERSION);
 		fprintf(stderr,"usage: grdfilter input_file -D<distance_flag> -F<type>[-]<filter_width>[<mode>]\n");
-		fprintf(stderr,"\t-G<output_file> [%s] [%s] [-T] [-V] [%s]\n", GMT_I_OPT, GMT_Rgeo_OPT, GMT_f_OPT);
+		fprintf(stderr,"\t-G<output_file> [%s] [-Ni|p|r] [%s] [-T] [-V] [%s]\n", GMT_I_OPT, GMT_Rgeo_OPT, GMT_f_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -239,6 +266,11 @@ int main (int argc, char **argv)
 		fprintf(stderr, "\n\tOPTIONS:\n");
 		GMT_inc_syntax ('I', 0);
 		fprintf(stderr,"\t   The new xinc and yinc should be divisible by the old ones (new lattice is subset of old).\n");
+		fprintf(stderr, "\t-N specifies how NaNs in the input grid should be treated.  There are three options:\n");
+		fprintf(stderr, "\t   -Ni skips all NaN values and returns a filtered value unless all are NaN [Default]\n");
+		fprintf(stderr, "\t   -Np sets filtered output to NaN is any NaNs are found inside filter circle.\n");
+		fprintf(stderr, "\t   -Nr sets filtered output to NaN if the corresponding input node was NaN.\n");
+		fprintf(stderr, "\t      (only possible if the input and output grids are coregistered).\n");
 		fprintf(stderr, "\t-T Toggles between grid and pixel registration for output grid [Default is same as input registration]\n");
 		fprintf(stderr, "\t-R for new Range of output grid; enter <WESN> (xmin, xmax, ymin, ymax) separated by slashes.\n");
 		GMT_explain_option ('V');
@@ -247,6 +279,8 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
+	GMT_check_lattice (&Ctrl->I.xinc, &Ctrl->I.yinc, &Ctrl->T.active, &Ctrl->I.active);
+
 	if (!Ctrl->G.file) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -G option:  Must specify output file\n", GMT_program);
 		error++;
@@ -282,7 +316,7 @@ int main (int argc, char **argv)
 	
 	if (error) exit (EXIT_FAILURE);
 
-	/* Assing filter_type number */
+	/* Assign filter_type number */
 	
 	for (filter_type = 0; filter_type < GRDFILTER_N_FILTERS && filter_code[filter_type] != Ctrl->F.filter; filter_type++);
 	
@@ -299,9 +333,13 @@ int main (int argc, char **argv)
 
 	/* Read the input grid file and close it  */
 
-	input = (float *) GMT_memory (VNULL, (size_t)(h.nx * h.ny), sizeof(float), GMT_program);
+	nm = GMT_get_nm (h.nx, h.ny);
+	input = (float *) GMT_memory (VNULL, (size_t)nm, sizeof(float), GMT_program);
 
 	GMT_err_fail (GMT_read_grd (fin, &h, input, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), fin);
+	
+	full_360 = (Ctrl->D.mode && GMT_360_RANGE (h.x_max, h.x_min));	/* Periodic geographic grid */
+	full_180 = (Ctrl->D.mode && GMT_180_RANGE (h.y_min, h.y_max));	/* Full latitude range for geographic grid */
 
 	last_median = 0.5 * (h.z_min + h.z_max);
 
@@ -318,8 +356,10 @@ int main (int argc, char **argv)
 		Ctrl->I.yinc = h.y_inc;
 	}
 
-	if (west_new < h.x_min) error = TRUE;
-	if (east_new > h.x_max) error = TRUE;
+	if (!full_360) {
+		if (west_new < h.x_min) error = TRUE;
+		if (east_new > h.x_max) error = TRUE;
+	}
 	if (south_new < h.y_min) error = TRUE;
 	if (north_new > h.y_max) error = TRUE;
 	if (Ctrl->I.xinc <= 0.0) error = TRUE;
@@ -339,13 +379,12 @@ int main (int argc, char **argv)
 	/* Copy back in case test_h were changed */
 	west_new  = test_h.x_min;	east_new  = test_h.x_max;	Ctrl->I.xinc = test_h.x_inc;
 	south_new = test_h.y_min;	north_new = test_h.y_max;	Ctrl->I.yinc = test_h.y_inc;
-	
 
 	/* We can save time by computing a weight matrix once [or once pr scanline] only
 	   if new grid spacing is a multiple of old spacing */
 
 	fast_way = (fabs (fmod (Ctrl->I.xinc / h.x_inc, 1.0)) < GMT_SMALL && fabs (fmod (Ctrl->I.yinc / h.y_inc, 1.0)) < GMT_SMALL);
-
+	same_grid = !(new_range  || Ctrl->I.active || h.node_offset == one_or_zero);
 	if (!fast_way && gmtdefs.verbose) {
 		fprintf (stderr, "%s: Warning - Your output grid spacing is such that filter-weights must\n", GMT_program);
 		fprintf (stderr, "be recomputed for every output node, so expect this run to be slow.  Calculations\n");
@@ -353,11 +392,15 @@ int main (int argc, char **argv)
 		fprintf (stderr, "of the input grid spacing.  If the odd output grid is necessary, consider using\n");
 		fprintf (stderr, "a \'fast\' grid for filtering and then resample onto your desired grid with grdsample.\n");
 	}
-
+	if (Ctrl->N.mode == NAN_REPLACE && !same_grid) {
+		fprintf (stderr, "%s: Warning: -Nr requires co-registered input/output grids, option is ignored\n", GMT_program);
+		Ctrl->N.mode = NAN_IGNORE;
+	}
 	nx_out = one_or_zero + irint ( (east_new - west_new) / Ctrl->I.xinc);
 	ny_out = one_or_zero + irint ( (north_new - south_new) / Ctrl->I.yinc);
 
-	output = (float *) GMT_memory (VNULL, (size_t)(nx_out*ny_out), sizeof(float), GMT_program);
+	nm = GMT_get_nm (nx_out, ny_out);
+	output = (float *) GMT_memory (VNULL, (size_t)nm, sizeof(float), GMT_program);
 	i_origin = (int *) GMT_memory (VNULL, (size_t)nx_out, sizeof(int), GMT_program);
 	if (!fast_way) x_shift = (double *) GMT_memory (VNULL, (size_t)nx_out, sizeof(double), GMT_program);
 
@@ -370,8 +413,6 @@ int main (int argc, char **argv)
 		x_fix = 0.5 * h.x_inc;
 		y_fix = 0.5 * h.y_inc;
 	}
-	full_360 = (Ctrl->D.mode && GMT_360_RANGE (h.x_max, h.x_min));	/* Periodic geographic grid */
-	full_180 = (Ctrl->D.mode && GMT_180_RANGE (h.y_min, h.y_max));	/* Full latitude range for geographic grid */
 
 	/* Set up the distance scalings for lon and lat, and assign pointer to distance function  */
 
@@ -402,11 +443,10 @@ int main (int argc, char **argv)
 			if (full_180) wrap_case_y = wrap_case_x;	/* For spherical filtering */
 			break;
 		case 5:	/* Great circle distances with Mercator coordinates */
-			x_scale = 0.0;
 			/* Get the max |lat| extent of the grid */
 			max_lat = IMG2LAT (MAX (fabs (h.y_min), fabs (h.y_max)));
 			merc_range = LAT2IMG (max_lat + (0.5 * Ctrl->F.width / project_info.KM_PR_DEG)) - LAT2IMG (max_lat);
-			y_scale = 0.5 * Ctrl->F.width / merc_range;
+			x_scale = y_scale = 0.5 * Ctrl->F.width / merc_range;
 			F.radius_func = SphericalRadius;
 			if (full_360) wrap_case_x = TRUE;		/* For spherical filtering */
 			break;
@@ -491,7 +531,7 @@ int main (int argc, char **argv)
 	half_nx = (h.node_offset) ? h.nx / 2 : (h.nx - 1) / 2;
 	pole_weight = 0.25 * M_PI * (h.y_inc / h.x_inc);	/* This is the weight of the pole point for gridregistered grids */
 	pole_check = (Ctrl->D.mode && !h.node_offset);		/* Must check to make sure we only use the N and S pole value once */
-	duplicate_check = (full_360 && !h.node_offset);		/* Must avoid using the duplicated Greenwhich node twice */
+	duplicate_check = (full_360 && !h.node_offset);		/* Must avoid using the duplicated Greenwich node twice */
 	j_s_pole = (h.y_min == -90.0) ? h.ny - 1 : INT_MIN;	/* row number of S pole (if in the grid)*/
 	j_n_pole = (h.y_max == 90.0) ? 0 : INT_MIN;		/* row number of N pole (if in the grid)*/
 	i_west = 0;		/* column number of western edge */
@@ -518,8 +558,9 @@ int main (int argc, char **argv)
 
 			if (effort_level == 3) set_weight_matrix (&F, weight, y_out, par, x_shift[i_out], y_shift);
 			wt_sum = value = 0.0;
-			n_in_median = 0;
+			n_in_median = n_bad = 0;
 			ij_out = j_out * nx_out + i_out;
+			if (Ctrl->N.mode == NAN_REPLACE && GMT_is_fnan (input[ij_out])) continue;	/* Since output will be NaN we bypass the filter loop */
 
 			/* Now loop over the filter domain and collect those points that should be considered by the filter operation */
 			
@@ -543,7 +584,10 @@ int main (int argc, char **argv)
 					if (pole_check && (j_in == j_n_pole || j_in == j_s_pole)) {	/* N or S pole on gridline grid */
 						row_ok = FALSE;	/* Only use one point from this row since we are at a pole */
 						ij_in = j_in*h.nx;	/* All points on pole rows are the same; pick the first one */
-						if (GMT_is_fnan (input[ij_in])) continue;	/* Whaddaya know; the pole is NaN */
+						if (GMT_is_fnan (input[ij_in])) {	/* Whaddaya know; the pole is NaN */
+							n_bad++;
+							continue;
+						}
 						/* Get here when pole value is usable  */
 						if (slow) {
 							work_array[n_in_median] = input[ij_in];
@@ -569,7 +613,10 @@ int main (int argc, char **argv)
 					if (weight[ij_wt] <= 0.0) continue;
 
 					ij_in = j_in*h.nx + i_in;
-					if (GMT_is_fnan (input[ij_in])) continue;
+					if (GMT_is_fnan (input[ij_in])) {
+						n_bad++;
+						continue;
+					}
 
 					/* Get here when point is usable  */
 					if (slow) {
@@ -585,7 +632,15 @@ int main (int argc, char **argv)
 
 			/* Now we have done the convolution and we can get the value  */
 
-			if (slow) {
+			if (Ctrl->N.mode == NAN_REPLACE && GMT_is_fnan (input[ij_out])) {
+				output[ij_out] = GMT_f_NaN;
+				n_nan++;
+			}
+			else if (Ctrl->N.mode == NAN_PRESERVE && n_bad) {	/* -Np in effect and there were NaNs inside circle */
+				output[ij_out] = GMT_f_NaN;
+				n_nan++;
+			}
+			else if (slow) {
 				if (n_in_median) {
 					switch (filter_type) {
 						case 3:	/* Median */
@@ -617,8 +672,8 @@ int main (int argc, char **argv)
 			}
 			else {
 				if (wt_sum == 0.0) {	/* Assign value = GMT_f_NaN */
-					n_nan++;
 					output[ij_out] = GMT_f_NaN;
+					n_nan++;
 				}
 				else
 					output[ij_out] = (float)(value / wt_sum);
