@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdgradient.c,v 1.39 2008/03/24 08:58:31 guru Exp $
+ *	$Id: grdgradient.c,v 1.42 2009/01/09 04:02:33 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -166,7 +166,7 @@ int main (int argc, char **argv)
 						case 'p':	/* Peucker */
 							Ctrl->E.mode = 1;
 							break;
-						case 's':	/* "simple" Lmbertian case */
+						case 's':	/* "simple" Lambertian case */
 							Ctrl->E.mode = 2;
 							if (sscanf(&argv[i][3], "%lf/%lf", &Ctrl->E.azimuth, &Ctrl->E.elevation) != 2) {
 								fprintf(stderr,"%s: GMT SYNTAX ERROR -Es option: Must append azimuth/elevation\n", GMT_program);
@@ -269,7 +269,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t    Specify '=' to get the default value (e.g. -E60/30/=/0.5)\n");
 		fprintf (stderr, "\t   Append s to use a simpler Lambertian algorithm (note that with this form\n");
 		fprintf (stderr, "\t   you only have to provide the azimuth and elevation parameters)\n");
-		fprintf (stderr, "\t   Append p to use the Peucker picewise linear aproximation (simpler but faster algorithm)\n");
+		fprintf (stderr, "\t   Append p to use the Peucker piecewise linear approximation (simpler but faster algorithm)\n");
 		fprintf (stderr, "\t   Note that in this case the azimuth and elevation are hardwired to 315 and 45 degrees.\n");
 		fprintf (stderr, "\t   This means that even if you provide other values they will be ignored.\n");
 		fprintf (stderr, "\t-G output file for results from -A or -D\n");
@@ -360,10 +360,10 @@ int main (int argc, char **argv)
 	GMT_boundcond_param_prep (&header, &edgeinfo);
 
 	GMT_grd_init (&header, argc, argv, TRUE);
-	nm = header.nx * header.ny;
+	nm = GMT_get_nm (header.nx, header.ny);
 	mx = header.nx + 4;
 	my = header.ny + 4;
-	nm2 = mx * my;
+	nm2 = GMT_get_nm (mx, my);
 	data = (float *) GMT_memory (VNULL, (size_t)nm2, sizeof (float), GMT_program);
 	GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 2;
 	if (Ctrl->S.active) slp = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
