@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdimage.c,v 1.79 2008/05/01 03:00:38 guru Exp $
+ *	$Id: grdimage.c,v 1.82 2009/01/09 04:02:33 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -369,11 +369,11 @@ int main (int argc, char **argv)
 
 	need_to_project = (project_info.projection != GMT_LINEAR || project_info.xyz_projection[0] == GMT_LOG10 || project_info.xyz_projection[0] == GMT_POW || project_info.xyz_projection[1] == GMT_LOG10 || project_info.xyz_projection[1] == GMT_POW);
 	if (Ctrl->E.dpi > 0 || need_to_project) {
-		nm = ((size_t)(4 + nx)) * ((size_t)(4 + ny));
+		nm = GMT_get_nm (4 + nx, 4 + ny);
 		GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 2;
 	}
 	else
-		nm = ((size_t)nx) * ((size_t)ny);
+		nm = GMT_get_nm (nx, ny);
 
 	for (i = 0; i < n_grids; i++) {
 		tmp1[i] = (float *) GMT_memory (VNULL, nm, sizeof (float), GMT_program);
@@ -613,17 +613,16 @@ void GMT_set_proj_limits (struct GRD_HEADER *r, struct GRD_HEADER *g)
 		return;
 	}
 
-	if (GMT_IS_AZIMUTHAL) {	/* Applies only to Azimuthal projections */
+	if (GMT_IS_MAPPING) {
 		all_lats = GMT_180_RANGE (g->y_max, g->y_min);
 		all_lons = GMT_360_RANGE (g->x_max, g->x_min);
-
-		if (all_lons && all_lats) {	/* Whole globe, get square box */
+		if (all_lons && all_lats) {	/* Whole globe, get rectangular box */
 			r->x_min = project_info.xmin;	r->x_max = project_info.xmax;
 			r->y_min = project_info.ymin;	r->y_max = project_info.ymax;
 			return;
 		}
 	}
-
+	
 	/* Must search for extent along perimeter */
 
 	r->x_min = r->y_min = +DBL_MAX;
