@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdinfo.c,v 1.55 2008/04/04 21:06:19 guru Exp $
+ *	$Id: grdinfo.c,v 1.57 2009/01/09 04:02:33 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -213,7 +213,7 @@ int main (int argc, char **argv)
 
 		if (slow) {	/* Must determine the location of global min and max values */
 
-			nm = ((size_t)grd.nx) * ((size_t)grd.ny);
+		 	nm= GMT_get_nm (grd.nx, grd.ny);
 			a = (float *) GMT_memory ((void *)a, nm, sizeof (float), GMT_program);
 			if (GMT_err_pass (GMT_read_grd (argv[k], &grd, a, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), grd.name)) continue;
 
