@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdlandmask.c,v 1.45 2008/05/01 03:00:38 guru Exp $
+ *	$Id: grdlandmask.c,v 1.49 2009/01/16 21:43:11 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -44,6 +44,7 @@ struct GRDLANDMASK_CTRL {	/* All control options for this program (except common
 	} A;
 	struct D {	/* -D<resolution> */
 		BOOLEAN active;
+		BOOLEAN force;	/* if TRUE, select next highest level if current set is not avaialble */
 		char set;	/* One of f, h, i, l, c */
 	} D;
 	struct F {	/* -F */
@@ -120,6 +121,7 @@ int main (int argc, char **argv)
 				case 'D':
 					Ctrl->D.active = TRUE;
 					Ctrl->D.set = argv[i][2];
+					if (argv[i][3] == '+') Ctrl->D.force = TRUE;
 					break;
 				case 'N':
 					Ctrl->N.active = TRUE;
@@ -164,7 +166,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "grdlandmask %s - Create \"wet-dry\" mask grid file from shoreline data base\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: grdlandmask -G<mask_grd_file> %s %s\n", GMT_I_OPT, GMT_Rgeo_OPT);
-		fprintf (stderr, "\t[-A<min_area>[/<min_level>/<max_level>]] [-D<resolution>] [-F] [-N<maskvalues>[o]] [-V]\n\n");
+		fprintf (stderr, "\t[-A<min_area>[/<min_level>/<max_level>]] [-D<resolution>][+] [-F] [-N<maskvalues>[o]] [-V]\n\n");
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -180,6 +182,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   i - intermediate resolution\n");
 		fprintf (stderr, "\t   l - low resolution [Default]\n");
 		fprintf (stderr, "\t   c - crude resolution, for tasks that need crude continent outlines only\n");
+		fprintf (stderr, "\t   Append + to use a lower resolution should the chosen one not be available [abort].\n");
 		fprintf (stderr, "\t-F Force pixel registration for output grid [Default is gridline orientation]\n");
 		fprintf (stderr, "\t-N gives values to use if a node is outside or inside a feature.\n");
 		fprintf (stderr, "\t   Append o to let feature boundary be considered outside [Default is inside].\n");
@@ -191,6 +194,8 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
+	GMT_check_lattice (&Ctrl->I.xinc, &Ctrl->I.yinc, &Ctrl->F.active, &Ctrl->I.active);
+
 	if (!project_info.region_supplied) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify -R option\n", GMT_program);
 		error++;
@@ -220,6 +225,7 @@ int main (int argc, char **argv)
 
 	GMT_err_fail (GMT_grd_RI_verify (&header, 1), Ctrl->G.file);
 
+	if (Ctrl->D.force) Ctrl->D.set = GMT_shore_adjust_res (Ctrl->D.set);
 	base = GMT_set_resolution (&Ctrl->D.set, 'D');
 	
 	is_inside = (Ctrl->N.edge) ? 2 : 1;		/* Whether of not being exactly on an edge is outside */
@@ -256,7 +262,7 @@ int main (int argc, char **argv)
 	i_dx = 1.0 / header.x_inc;
 	i_dy = 1.0 / header.y_inc;
 	del_off = (header.node_offset) ? 0.5 : 0.0;
-	nm = header.nx * header.ny;
+	nm = GMT_get_nm (header.nx, header.ny);
 	data = (float *) GMT_memory (VNULL, (size_t)nm, sizeof(float), GMT_program);
 	/* All data nodes are thus initialized to 0 */
 	x = (double *) GMT_memory (VNULL, (size_t)header.nx, sizeof(double), GMT_program);
