@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdmask.c,v 1.68 2008/05/01 03:00:38 guru Exp $
+ *	$Id: grdmask.c,v 1.71 2009/01/09 04:02:33 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -212,6 +212,8 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
+	GMT_check_lattice (&Ctrl->I.xinc, &Ctrl->I.yinc, &Ctrl->F.active, &Ctrl->I.active);
+
 	if (!project_info.region_supplied) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify -R option\n", GMT_program);
 		error++;
@@ -256,7 +258,7 @@ int main (int argc, char **argv)
 	header.xy_off = 0.5 * header.node_offset;
 	idx = 1.0 / header.x_inc;
 	idy = 1.0 / header.y_inc;
-	nm = ((size_t)header.nx) * ((size_t)header.ny);
+	nm = GMT_get_nm (header.nx, header.ny);
 	data = (float *) GMT_memory (VNULL, (size_t)nm, sizeof(float), GMT_program);
 	x = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(double), GMT_program);
 	y = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(double), GMT_program);
