@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdvector.c,v 1.48 2008/03/24 08:58:31 guru Exp $
+ *	$Id: grdvector.c,v 1.52 2009/01/09 04:02:34 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -266,6 +266,8 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
+	GMT_check_lattice (&Ctrl->I.xinc, &Ctrl->I.yinc, NULL, &Ctrl->I.active);
+
 	if (Ctrl->I.active && (Ctrl->I.xinc <= 0.0 || Ctrl->I.yinc <= 0.0)) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -I option:  Must specify positive increments\n", GMT_program);
 		error++;
@@ -312,8 +314,10 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	GMT_err_fail (GMT_read_grd_info (file[0], &h[0]), file[0]);
-	GMT_err_fail (GMT_read_grd_info (file[1], &h[1]), file[1]);
+	for (i = 0; i < 2; i++) {
+		GMT_grd_init (&h[i], argc, argv, FALSE);
+		GMT_err_fail (GMT_read_grd_info (file[i], &h[i]), file[i]);
+	}
 
 	if (!(h[0].nx == h[1].nx && h[0].ny == h[1].ny && h[0].x_min == h[1].x_min && h[0].y_min == h[1].y_min 
 		&& h[0].x_inc == h[1].x_inc && h[0].y_inc == h[1].y_inc)) {
@@ -346,7 +350,7 @@ int main (int argc, char **argv)
 
 	nx = GMT_get_n (data_west, data_east, h[0].x_inc, h[0].node_offset);
 	ny = GMT_get_n (data_south, data_north, h[0].y_inc, h[0].node_offset);
-	nm = ((GMT_LONG)nx) * ((GMT_LONG)ny);
+	nm = GMT_get_nm (nx, ny);
 	r = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 	theta = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 	GMT_err_fail (GMT_read_grd (file[0], &h[0], r, data_west, data_east, data_south, data_north, GMT_pad, FALSE), file[0]);
