@@ -1,6 +1,6 @@
-/* $Id: img2mercgrd.c,v 1.28 2008/03/24 08:58:32 guru Exp $
+/* $Id: img2mercgrd.c,v 1.30 2009/01/09 04:02:35 guru Exp $
  *
- * Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ * Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  * See COPYING file for copying and redistribution conditions.
  *
  * img2mercgrd.c
@@ -390,7 +390,7 @@ int main (int argc, char **argv)
 
 	row = (short int *) GMT_memory (VNULL, (size_t)(navg * imgcoord.nxcol), sizeof (short int), GMT_program);
 	ix = (int *) GMT_memory (VNULL, (size_t)(navgsq * h.nx), sizeof (int), GMT_program);
-	nm = ((size_t)h.nx) * ((size_t)h.ny);
+	nm = GMT_get_nm (h.nx, h.ny);
 	a = (float *) GMT_memory (VNULL, nm, sizeof (float), GMT_program);
 
 	/* Load ix with the index to the correct column, for each output desired.  This helps for Greenwich, 
