@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: makecpt.c,v 1.45 2008/03/24 08:58:31 guru Exp $
+ *	$Id: makecpt.c,v 1.47 2009/01/09 04:02:34 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -155,7 +155,7 @@ int main(int argc, char **argv)
 		fprintf (stderr, "\t-Q Assign a logarithmic colortable [Default is linear]\n");
 		fprintf (stderr, "\t   -Qi: z-values are actually log10(z). Assign colors and write z. [Default]\n");
 		fprintf (stderr, "\t   -Qo: z-values are z, but take log10(z), assign colors and write z.\n");
-		fprintf (stderr, "\t        If -T<z0/z1/dz> is given, dz is 1, 2, or 3 (as in logarithmic anotations)\n");
+		fprintf (stderr, "\t        If -T<z0/z1/dz> is given, dz is 1, 2, or 3 (as in logarithmic annotations)\n");
 		fprintf (stderr, "\t-T Give start, stop, and increment for colorscale in z-units, or filename with custom z-values\n");
 		fprintf (stderr, "\t   If not given, the range in the master cptfile is used\n");
 		GMT_explain_option ('V');
