@@ -1,49 +1,50 @@
 /*--------------------------------------------------------------------
- *	$Id: mapproject.c,v 1.92 2008/04/21 21:49:19 guru Exp $
- *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
- *
- *	This program is free software; you can redistribute it and/or modify
- *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
- *
- *	This program is distributed in the hope that it will be useful,
- *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *	GNU General Public License for more details.
- *
- *	Contact info: gmt.soest.hawaii.edu
- *--------------------------------------------------------------------*/
+*	$Id: mapproject.c,v 1.95 2009/01/09 04:02:34 guru Exp $
+*
+*	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+*	See COPYING file for copying and redistribution conditions.
+*
+*	This program is free software; you can redistribute it and/or modify
+*	it under the terms of the GNU General Public License as published by
+*	the Free Software Foundation; version 2 of the License.
+*
+*	This program is distributed in the hope that it will be useful,
+*	but WITHOUT ANY WARRANTY; without even the implied warranty of
+*	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*	GNU General Public License for more details.
+*
+*	Contact info: gmt.soest.hawaii.edu
+*--------------------------------------------------------------------*/
 /*
- * mapproject reads a pair of coordinates [+ optional data fields] from
- * standard input or file(s) and transforms the coordinates according to the
- * map projection selected. See the man page for projections currently supported.
- *
- * The default is to expect longitude, latitude, [and optional datavalues],
- * and return x, y, [ and optional datavalues], but if the -I option is used,
- * the reverse is true.  Specifying -C means that the origin of projected coordinates
- * should be set to origin of projection  [Default origin is lower left corner of "map"].
- * If your data is lat lon instead of lon lat [Default], use -: to toggle x/y -> y/x.
- * Note that only unprojected values are affected by the -: switch.  True x,y values are
- * always printed out as x,y.  Option -G allows calculation of distances along track or
- * to a fixed point, while -L calculates shortest distances to a line.
- * Finally, datum conversions can also be done, alone or in series with a
- * map projection.
- *
- *
- * Author:	Paul Wessel
- * Date:	1-MAR-1990
- * Version:	4
- *
- */
- 
+* mapproject reads a pair of coordinates [+ optional data fields] from
+* standard input or file(s) and transforms the coordinates according to the
+* map projection selected. See the man page for projections currently supported.
+*
+* The default is to expect longitude, latitude, [and optional datavalues],
+* and return x, y, [ and optional datavalues], but if the -I option is used,
+* the reverse is true.  Specifying -C means that the origin of projected coordinates
+* should be set to origin of projection  [Default origin is lower left corner of "map"].
+* If your data is lat lon instead of lon lat [Default], use -: to toggle x/y -> y/x.
+* Note that only unprojected values are affected by the -: switch.  True x,y values are
+* always printed out as x,y.  Option -G allows calculation of distances along track or
+* to a fixed point, while -L calculates shortest distances to a line.
+* Finally, datum conversions can also be done, alone or in series with a
+* map projection.
+*
+*
+* Author:	Paul Wessel
+* Date:	1-MAR-1990
+* Version:	4
+*
+*/
+
 #include "gmt.h"
 
 struct MAPPROJECT_CTRL {	/* All control options for this program (except common args) */
 	/* active is TRUE if the option has been activated */
 	struct A {	/* -Ab|B|f|F<lon0>/<lat0> */
 		BOOLEAN active;
+		BOOLEAN azims;
 		BOOLEAN reverse;	/* TRUE if we want back-azimuths instead of regular azimuths */
 		BOOLEAN geodesic;	/* TRUE if we want geodesic azimuths [Default is great circle azimuths] */
 		double lon, lat;	/* Fixed point of reference */
@@ -114,7 +115,7 @@ int main (int argc, char **argv)
 	double xmin, xmax, ymin, ymax, *in, *out, fwd_scale, inv_scale, xtmp, ytmp;
 	double x_in_min, x_in_max, y_in_min, y_in_max, inch_to_unit, unit_to_inch;
 	double x_out_min, x_out_max, y_out_min, y_out_max, u_scale, d_scale;
-	double xnear, ynear;
+	double xnear, ynear, lon_prev = 0, lat_prev = 0;
 
 	char line[BUFSIZ], format[BUFSIZ], unit_name[GMT_TEXT_LEN], scale_unit_name[GMT_TEXT_LEN];
 	char txt_a[GMT_LONG_TEXT], txt_b[GMT_LONG_TEXT], p[BUFSIZ], c;
@@ -159,9 +160,9 @@ int main (int argc, char **argv)
 
 				case 'A':
 					Ctrl->A.active = TRUE;
-	 				n = sscanf (&argv[i][2], "%c%[^/]/%s", &c, txt_a, txt_b);
-					if (n < 3) {
-						fprintf (stderr, "%s: GMT SYNTAX ERROR.  Expected -Ab|B|f|F<lon0>/<lat0>\n", GMT_program);
+					n = sscanf (&argv[i][2], "%c%[^/]/%s", &c, txt_a, txt_b);
+					if (n < 1) {
+						fprintf (stderr, "%s: GMT SYNTAX ERROR.  Expected -Ab|B|f|F[<lon0>/<lat0]>\n", GMT_program);
 						error++;
 					}
 					else {
@@ -176,18 +177,22 @@ int main (int argc, char **argv)
 							case 'f':
 								break;
 							default:
-								fprintf (stderr, "%s: GMT SYNTAX ERROR.  Expected -Ab|B|f|F<lon0>/<lat0>\n", GMT_program);
+								fprintf (stderr, "%s: GMT SYNTAX ERROR.  Expected -Ab|B|f|F[<lon0>/<lat0>]\n", GMT_program);
 								error++;
 								break;
 						}
-						error += GMT_verify_expectations (GMT_io.in_col_type[0], GMT_scanf_arg (txt_a, GMT_io.in_col_type[0], &Ctrl->A.lon), txt_a);
-						error += GMT_verify_expectations (GMT_io.in_col_type[1], GMT_scanf_arg (txt_b, GMT_io.in_col_type[1], &Ctrl->A.lat), txt_b);
+						if (n == 3) {
+							error += GMT_verify_expectations (GMT_io.in_col_type[0], GMT_scanf_arg (txt_a, GMT_io.in_col_type[0], &Ctrl->A.lon), txt_a);
+							error += GMT_verify_expectations (GMT_io.in_col_type[1], GMT_scanf_arg (txt_b, GMT_io.in_col_type[1], &Ctrl->A.lat), txt_b);
+						}
+						else
+							Ctrl->A.azims = TRUE;
 					}
 					break;
 				case 'C':
 					Ctrl->C.active = TRUE;
 					if (argv[i][2]) {	/* Also gave shifts */
-	 					n = sscanf (&argv[i][2], "%lf/%lf", &Ctrl->C.easting, &Ctrl->C.northing);
+						n = sscanf (&argv[i][2], "%lf/%lf", &Ctrl->C.easting, &Ctrl->C.northing);
 						if (n != 2) {
 							fprintf (stderr, "%s: GMT SYNTAX ERROR.  Expected -C[<false_easting>/<false_northing>]\n", GMT_program);
 							error++;
@@ -212,7 +217,7 @@ int main (int argc, char **argv)
 					for (n_slash = 0, k = 2; argv[i][k]; k++) if (argv[i][k] == '/') n_slash++;
 					if (n_slash == 2 || n_slash == 1) {	/* Got -Glon0/lat0[/units] */
 						Ctrl->G.mode = 1;
-	 					n = sscanf (&argv[i][2], "%[^/]/%[^/]/%c", txt_a, txt_b, &c);
+						n = sscanf (&argv[i][2], "%[^/]/%[^/]/%c", txt_a, txt_b, &c);
 						if (n < 2) {
 							fprintf (stderr, "%s: GMT SYNTAX ERROR.  Expected -G<lon0>/<lat0>[/e|E|k|K|m|M|n|N|c|C|d|D]\n", GMT_program);
 							error++;
@@ -239,7 +244,7 @@ int main (int argc, char **argv)
 					break;
 				case 'L':
 					Ctrl->L.active = TRUE;
-	 				Ctrl->L.file = strdup (&argv[i][2]);
+					Ctrl->L.file = strdup (&argv[i][2]);
 					k = strlen (Ctrl->L.file) - 1;
 					if (Ctrl->L.file[k] == '+') {	/* Flag to get point number instead of coordinates at nearest point on line */
 						Ctrl->L.mode = 3;
@@ -297,7 +302,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "mapproject %s - Forward and Inverse map transformations and geodesy\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: mapproject <infiles> %s %s [-C[<dx/dy>]]\n", GMT_J_OPT, GMT_Rgeo_OPT);
-		fprintf (stderr, "\t[-Ab|B|f|F<lon0/lat0>] [-Dc|i|m|p] [-E[<datum>]] [-F[k|m|n|i|c|p]] [-G[<lon0/lat0>/][+|-][<unit>]\n");
+		fprintf (stderr, "\t[-Ab|B|f|F[<lon0/lat0>]] [-Dc|i|m|p] [-E[<datum>]] [-F[k|m|n|i|c|p]] [-G[<lon0/lat0>/][+|-][<unit>]\n");
 		fprintf (stderr, "\t[%s] [-I] [-L<line.xy>[/<unit>]] [%s] [-Q[e|d]] [-S] [-T[h]<from>[/<to>]\n", GMT_H_OPT, GMT_M_OPT);
 		fprintf (stderr, "\t[-V[l]] [%s] [%s] [%s]\n\n", GMT_t_OPT, GMT_b_OPT, GMT_f_OPT);
 
@@ -308,8 +313,9 @@ int main (int argc, char **argv)
 		GMT_explain_option ('R');
 		fprintf (stderr, "\t   If UTM and -C are used then -R is optional (automatically set to match UTM zone)\n");
 		fprintf (stderr, "\n\tOPTIONS:\n");
-		fprintf (stderr, "\t-A Calculate azimuths from specified point to each input data point with -Af.\n");
-		fprintf (stderr, "\t   Use -Ab to calculate backazimuths from data to specified point.\n");
+		fprintf (stderr, "\t-A Calculate azimuths from previous point in the input data with -Af. If a specified\n");
+		fprintf (stderr, "\t   point is provided, all azimuths are computed with respect to that point.\n");
+		fprintf (stderr, "\t   Use -Ab to calculate backazimuths from data to previous or the specified point.\n");
 		fprintf (stderr, "\t   Upper case B or F gives azimuths of geodesics using current ellipsoid.\n");
 		fprintf (stderr, "\t-C returns x/y relative to projection center [Default is relative to lower left corner]\n");
 		fprintf (stderr, "\t   Optionally append dx/dy to add (or subtract if -I) (i.e., false easting & northing) [0/0]\n");
@@ -418,17 +424,17 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data cannot have header -H\n", GMT_program);
 		error++;
 	}
- 	if ((Ctrl->D.active + Ctrl->F.active) == 2) {
+	if ((Ctrl->D.active + Ctrl->F.active) == 2) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Can specify only one of -D and -F\n", GMT_program);
 		error++;
 	}
 	if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] == 0) GMT_io.ncol[GMT_IN] = 2;
-        if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] < 2) {
-                fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data (-bi) must have at least 2 columns\n", GMT_program);
+	if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] < 2) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data (-bi) must have at least 2 columns\n", GMT_program);
 		error++;
 	}
-        if (((Ctrl->T.active && GMT_datum.h_given) || Ctrl->E.active) && GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] < 3) {
-                fprintf (stderr, "%s: GMT SYNTAX ERROR.  For -E or -T, binary input data (-bi) must have at least 3 columns\n", GMT_program);
+	if (((Ctrl->T.active && GMT_datum.h_given) || Ctrl->E.active) && GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] < 3) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR.  For -E or -T, binary input data (-bi) must have at least 3 columns\n", GMT_program);
 		error++;
 	}
 
@@ -495,7 +501,7 @@ int main (int argc, char **argv)
 	GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 
 	azimuth_func = (GMT_IS_SPHERICAL || !Ctrl->A.geodesic) ? GMT_az_backaz_sphere : GMT_az_backaz_geodesic;
-	 
+	
 	if (Ctrl->G.mode && proj_type < 2) {	/* Ensure we use the selected output coordinates */
 		GMT_io.out_col_type[0] = save[0];
 		GMT_io.out_col_type[1] = save[1];
@@ -718,11 +724,11 @@ int main (int argc, char **argv)
 
 				if (pure_ascii && n_expected_fields > 2) {
 					/* Special case: ASCII i/o and at least 3 columns:
-					   Columns beyond first two could be text strings */
+					  Columns beyond first two could be text strings */
 
 					/* We will use GMT_strtok to step past the first 2 [or 3] columns.  The remainder
-					 * will then be the user text that we want to preserve.  Since strtok places
-					 * 0 to indicate start of next token we count our way to the start of the text. */
+					* will then be the user text that we want to preserve.  Since strtok places
+					* 0 to indicate start of next token we count our way to the start of the text. */
 
 					strcpy (line, GMT_io.current_record);
 					GMT_chop (line);
@@ -853,16 +859,26 @@ int main (int argc, char **argv)
 							(void) near_a_line (in[0], in[1], xyline, Ctrl->L.mode, &d, &xnear, &ynear);
 						d *= d_scale;
 					}
-					else {	/* Azimuths */
+					else if (Ctrl->A.azims) {	/* Azimuth from previous point */
+						if (n_read == 1) {	/* First point has undefined azimuth since there is no previous point */
+							d = GMT_d_NaN;
+						}
+						else {
+							d = (*azimuth_func) (lon_prev, lat_prev, in[0], in[1], Ctrl->A.reverse);
+						}
+						lon_prev = in[0];
+						lat_prev = in[1];
+					}
+					else {	/* Azimuths with respect to a fixed point */
 						d = (*azimuth_func) (Ctrl->A.lon, Ctrl->A.lat, in[0], in[1], Ctrl->A.reverse);
 					}
 					if (pure_ascii && n_expected_fields > 2) {
 						/* Special case: Ascii input and at least 3 columns:
-					 	  Columns beyond first two could be text strings */
+						 Columns beyond first two could be text strings */
 
 						/* We will use GMT_strtok to step past the first 2 [or 3] columns.  The remainder
-						 * will then be the user text that we want to preserve.  Since strtok places
-						 * 0 to indicate start of next token we count our way to the start of the text. */
+						* will then be the user text that we want to preserve.  Since strtok places
+						* 0 to indicate start of next token we count our way to the start of the text. */
 
 						strcpy (line, GMT_io.current_record);
 						GMT_chop (line);
@@ -905,11 +921,11 @@ int main (int argc, char **argv)
 					}
 					if (pure_ascii && n_expected_fields > 2) {
 						/* Special case: Ascii input and at least 3 columns:
-						   Columns beyond first two could be text strings */
+						  Columns beyond first two could be text strings */
 
 						/* We will use GMT_strtok to step past the first 2 [or 3] columns.  The remainder
-						 * will then be the user text that we want to preserve.  Since strtok places
-						 * 0 to indicate start of next token we count our way to the start of the text. */
+						* will then be the user text that we want to preserve.  Since strtok places
+						* 0 to indicate start of next token we count our way to the start of the text. */
 
 						strcpy (line, GMT_io.current_record);
 						GMT_chop (line);
