@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: psmeca.c,v 1.40 2008/03/24 08:58:32 guru Exp $
+ *    $Id: psmeca.c,v 1.46 2009/02/07 00:25:45 jluis Exp $
  *
- *    Copyright (c) 1996-2008 by G. Patau
+ *    Copyright (c) 1996-2009 by G. Patau
  *    Distributed under the GNU Public Licence
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
@@ -40,7 +40,7 @@ PostScript code is written to stdout.
 int main (int argc, char **argv)
 {
 
-    int     i, symbol = 0, n, ix = 0, iy = 1, n_files = 0, fno;
+    int     i, symbol = 0, n, ix = 0, iy = 1, n_files = 0, fno, last = 0;
     int     n_args;
     GMT_LONG     n_rec = 0;
 
@@ -50,7 +50,7 @@ int main (int argc, char **argv)
     BOOLEAN    read_cmt = FALSE, read_aki = FALSE, read_planes = FALSE;
     BOOLEAN    read_tensor = FALSE, plot_dc = FALSE, plot_zerotrace = FALSE;
     BOOLEAN    read_axis = FALSE;
-    BOOLEAN    read_change_position = FALSE, write_change_position = FALSE;
+    BOOLEAN    read_change_position = FALSE;
     BOOLEAN    transparence = FALSE, one_size = FALSE, no_label = FALSE;
     BOOLEAN    plot_axis = FALSE, tr_zerotrace = FALSE;
     BOOLEAN    skip_if_outside = TRUE;
@@ -78,7 +78,6 @@ int main (int argc, char **argv)
     struct GMT_FILL fill, efill, nofill;
     struct GMT_FILL pfill, tfill, bfill;
 
-    struct nodal_plane NP1, NP2;
     st_me meca;
     struct MOMENT moment;
     struct M_TENSOR mt;
@@ -91,7 +90,7 @@ int main (int argc, char **argv)
 
     double default_fontsize = 9.0;
     double fontsize = default_fontsize;
-    double default_offset = gmtdefs.measure_unit == 0 ? 0.1 : 0.04;
+    double default_offset = (gmtdefs.measure_unit == GMT_CM ? 0.1 : 0.04);
     double default_pointsize = 0.005;
     double pointsize = default_pointsize, offset = default_offset, angle = 0.0;
     double fault, depth, depmin = 0.0, depmax = 900.0;
@@ -151,7 +150,7 @@ int main (int argc, char **argv)
                 case 'C':   /* Change position [set line attributes] */
                     read_change_position = TRUE;
                     if (strlen(argv[i]) > 2) {
-                        if(strchr(argv[i], 'P')) {
+                        if (strchr(argv[i], 'P')) {
                             strcpy(txt_a, strchr(argv[i]+1, 'P')+1);
                             pointsize = GMT_convert_units (txt_a, GMT_INCH);
                         }
@@ -199,22 +198,21 @@ int main (int argc, char **argv)
                     break;
                 case 'r':    /* draw box around text */
                     draw_box = TRUE;
-                    if(strlen(argv[i]) > 2 ) {
-                       GMT_getfill (&argv[i][2], &bfill);
-                    }
+                    if (strlen(argv[i]) > 2 ) GMT_getfill (&argv[i][2], &bfill);
                     break;
                 case 'S':    /* Get symbol [and size] */
                     symbol_type = argv[i][2];
                     strcpy(txt_a, &argv[i][3]);
-                    n=0; while (txt_a[n] && txt_a[n] != '/') n++; txt_a[n]=0;
+                    n=0;
+		    while (txt_a[n] && txt_a[n] != '/') n++;
+		    txt_a[n]=0;
                     scale = GMT_convert_units (txt_a, GMT_INCH);
 
-                    if(strstr(argv[i], "/") != NULL) {
-                        sscanf(strstr(argv[i], "/"), "/%lf/%lf",
-                           &fontsize, &offset);
-                        if (fontsize == 0.0) fontsize = default_fontsize;
+                    if (strstr(argv[i], "/") != NULL) {
+                        sscanf(strstr(argv[i], "/"), "/%lf/%lf", &fontsize, &offset);
+                        if (GMT_IS_ZERO (fontsize)) fontsize = default_fontsize;
                         if (fontsize < 0.0) no_label = TRUE;
-                        if (offset == 0.0) offset = default_offset;
+                        if (GMT_IS_ZERO (offset)) offset = default_offset;
                         if (argv[i][strlen(argv[i]) - 1] == 'u') justify = 10;
                     }
 
@@ -232,23 +230,19 @@ int main (int argc, char **argv)
                             read_axis = TRUE;
                             break;
                         case 'y':
-                            read_axis = TRUE;
-                            plot_dc = TRUE;
+                            read_axis = plot_dc = TRUE;
                             break;
                         case 't':
-                            read_axis = TRUE;
-                            plot_zerotrace = TRUE;
+                            read_axis = plot_zerotrace = TRUE;
                             break;
                         case 'm':
                             read_tensor = TRUE;
                             break;
                         case 'd':
-                            read_tensor = TRUE;
-                            plot_dc = TRUE;
+                            read_tensor = plot_dc = TRUE;
                             break;
                         case 'z':
-                            read_tensor = TRUE;
-                            plot_zerotrace = TRUE;
+                            read_tensor = plot_zerotrace = TRUE;
                             break;
                         default:
                             error = TRUE;
@@ -258,7 +252,7 @@ int main (int argc, char **argv)
                 case 'T':
                     transparence = TRUE;
                     sscanf (&argv[i][2], "%d",&n_plane);
-                    if(strlen(argv[i]) > 4) { /* Set transparent attributes */
+                    if (strlen(argv[i]) > 4) { /* Set transparent attributes */
                         def_tr_pen = TRUE;
                         if (GMT_getpen (&argv[i][4], &tr_pen)) {
                             GMT_pen_syntax ('T', " ");
@@ -268,10 +262,10 @@ int main (int argc, char **argv)
                     break;
                 case 'z': /* overlay zerotrace moment tensor */
                     tr_zerotrace = TRUE;
-                    if(strlen(argv[i]) > 2) { /* Set transparent attributes */
+                    if (strlen(argv[i]) > 2) { /* Set transparent attributes */
                         def_tz_pen = TRUE;
                         if (GMT_getpen (&argv[i][2], &tz_pen)) {
-                        GMT_pen_syntax ('z', " ");
+                            GMT_pen_syntax ('z', " ");
                             error++;
                         }
                     }
@@ -288,7 +282,7 @@ int main (int argc, char **argv)
                     break;
                 case 'a':    /* plot axis */
                     plot_axis = TRUE;
-                    if(strlen(argv[i]) == 2) {
+                    if (strlen(argv[i]) == 2) {
                         strcpy(txt_a,"0.08i");
                         P_sym_type = 'c';
                         T_sym_type = 'c';
@@ -296,10 +290,12 @@ int main (int argc, char **argv)
                     else {
                         a_size = GMT_convert_units (txt_a, GMT_INCH);
                         strcpy(txt_a, &argv[i][3]);
-                        n=0; while (txt_a[n] && txt_a[n] != '/') n++; txt_a[n]=0;
+                        n=0;
+			while (txt_a[n] && txt_a[n] != '/') n++;
+			txt_a[n]=0;
                         a_size = GMT_convert_units (txt_a, GMT_INCH);
 
-                        if(strstr(argv[i], "/") != NULL) {
+                        if (strstr(argv[i], "/") != NULL) {
                             strcpy(txt_a,strstr(argv[i], "/"));
                             switch (strlen(txt_a)) {
                                 case 1:
@@ -390,7 +386,7 @@ int main (int argc, char **argv)
                     break;
                 case 'p':    /* Draw outline of P axis symbol [set outline attributes] */
                     p_outline = TRUE;
-                    if(strlen(argv[i]) > 2) {
+                    if (strlen(argv[i]) > 2) {
                         def_ppen = TRUE;
                         if (GMT_getpen (&argv[i][2], &ppen)) {
                             GMT_pen_syntax ('p', " ");
@@ -400,7 +396,7 @@ int main (int argc, char **argv)
                     break;
                 case 't':    /* Draw outline of T axis symbol [set outline attributes] */
                     t_outline = TRUE;
-                    if(strlen(argv[i]) > 2){
+                    if (strlen(argv[i]) > 2){
                         def_tpen = TRUE;
                         if (GMT_getpen (&argv[i][2], &tpen)) {
                             GMT_pen_syntax ('t', " ");
@@ -442,7 +438,7 @@ int main (int argc, char **argv)
     if (no_size_needed > 1) error++;    
     if (!no_size_needed && (symbol > 1 && scale <= 0.0)) error++;
 
-    if(get_rgb && !new) error++;
+    if (get_rgb && !new) error++;
 
     if (argc == 1 || GMT_give_synopsis_and_exit || error) {   /* Display usage */
         fprintf (stderr,"psmeca %s - Plot seismological symbols on maps\n\n", GMT_VERSION);
@@ -535,14 +531,14 @@ int main (int argc, char **argv)
         exit (EXIT_FAILURE);
     }
 
-    if(!def_lpen) lpen = pen;
-    if(!def_cpen) cpen = pen;
-    if(!def_ppen) ppen = pen;
-    if(!def_tpen) tpen = pen;
-    if(!def_tr_pen) tr_pen = pen;
-    if(!def_tz_pen) tz_pen = pen;
-    if(!def_pfill) pfill = fill;
-    if(!def_tfill) tfill = efill;
+    if (!def_lpen) lpen = pen;
+    if (!def_cpen) cpen = pen;
+    if (!def_ppen) ppen = pen;
+    if (!def_tpen) tpen = pen;
+    if (!def_tr_pen) tr_pen = pen;
+    if (!def_tz_pen) tz_pen = pen;
+    if (!def_pfill) pfill = fill;
+    if (!def_tfill) tfill = efill;
 
     if (get_rgb) GMT_read_cpt (cpt);
 
@@ -561,7 +557,8 @@ int main (int argc, char **argv)
     
     if (skip_if_outside) GMT_map_clip_on (GMT_no_rgb, 3);
     
-    ix = (gmtdefs.xy_toggle[0]);    iy = 1 - ix;
+    ix = (gmtdefs.xy_toggle[0]);
+    iy = 1 - ix;
 
     done = FALSE;
 
@@ -591,27 +588,35 @@ int main (int argc, char **argv)
                 sscanf (line, "%s %s %s %s %s %s %s %s %s %s %s %s %[^\n]\n",
                     col[0], col[1], col[2], col[3], col[4], col[5], col[6], 
                     col[7], col[8], col[9], col[10], col[11], string); 
+	    	last = 11;
             }
             else if (read_aki) {
                 sscanf (line, "%s %s %s %s %s %s %s %s %[^\n]\n",
                     col[0], col[1], col[2], col[3], col[4], col[5], col[6], 
                     col[7], string);
+	    	last = 7;
             }
             else if (read_planes) {
                 sscanf (line, "%s %s %s %s %s %s %s %s %s %[^\n]\n",
                     col[0], col[1], col[2], col[3], col[4], col[5], col[6], 
                     col[7], col[8], string);
+	    	last = 8;
             }
             else if (read_axis) {
                 sscanf (line, "%s %s %s %s %s %s %s %s %s %s %s %s %s %s %[^\n]\n", 
                     col[0], col[1], col[2], col[3], col[4], col[5], col[6], col[7], 
                     col[8], col[9], col[10], col[11], col[12], col[13], string);
+	    	last = 13;
             }
             else if (read_tensor) {
                 sscanf (line, "%s %s %s %s %s %s %s %s %s %s %s %[^\n]\n", 
                     col[0], col[1], col[2], col[3], col[4], col[5], col[6], col[7], 
                     col[8], col[9], col[10], string);
+	    	last = 10;
             }
+
+	    /* Immediately skip locations outside of the map area */
+
             xy[ix] = atof (col[0]);
             xy[iy] = atof (col[1]);
             
@@ -620,18 +625,21 @@ int main (int argc, char **argv)
                 if ( abs (GMT_x_status_new) > 1 || abs (GMT_y_status_new) > 1) continue;
             }
 
-            if(new) {
+	    /* In new (psmeca) input format, third column is depth.
+	       Skip record when depth is out of range. Also read an extra column. */
+
+            if (new) {
                 depth = atof (col[2]);
-                if((depth - depmin) * (depth - depmax) > 0.) continue;
-                if (get_rgb) {
-                    GMT_get_rgb_from_z (depth, fill.rgb);
-                }
-                sscanf (string, "%s %[^\n]\n", txt_a, event_title);
+		if (depth < depmin || depth > depmax) continue;
+                if (get_rgb) GMT_get_rgb_from_z (depth, fill.rgb);
+                sscanf (string, "%s %[^\n]\n", col[last+1], event_title);
             }
             else 
                 strcpy(event_title, string);
             if (strlen(event_title) <= 0) sprintf(event_title,"\n");
 
+	    /* Gather and transform the input records, depending on type */
+
             if (read_cmt) {
                 meca.NP1.str = atof(col[2+new]);
                 meca.NP1.dip = atof(col[3+new]);
@@ -641,44 +649,20 @@ int main (int argc, char **argv)
                 meca.NP2.rake = atof(col[7+new]);
                 meca.moment.mant = atof(col[8+new]);
                 meca.moment.exponent = atoi(col[9+new]);
-                if(meca.moment.exponent == 0)
-                meca.magms = atof(col[8+new]);
-
-                if(read_change_position) {
-                    xynew[ix] = atof(col[10+new]);
-                    if(new) xynew[iy] = atof(txt_a);
-                    else xynew[iy] = atof(col[11]);
-                    if(fabs(xynew[ix]) > EPSIL || fabs(xynew[iy]) > EPSIL)
-                        write_change_position = TRUE;
-                    else
-                        write_change_position = FALSE;
-                }
-            } else if(read_aki) {
-                NP1.str = atof(col[2+new]);
-                NP1.dip = atof(col[3+new]);
-                NP1.rake = atof(col[4+new]);
+                if (meca.moment.exponent == 0) meca.magms = atof(col[8+new]);
+            }
+	    
+	    else if (read_aki) {
+                meca.NP1.str = atof(col[2+new]);
+                meca.NP1.dip = atof(col[3+new]);
+                meca.NP1.rake = atof(col[4+new]);
                 meca.magms = atof(col[5+new]);    
 
                 meca.moment.exponent = 0;
-                define_second_plane(NP1, &NP2);
-
-                meca.NP1.str = NP1.str;
-                meca.NP1.dip = NP1.dip;
-                meca.NP1.rake = NP1.rake;
-                meca.NP2.str = NP2.str;
-                meca.NP2.dip = NP2.dip;
-                meca.NP2.rake = NP2.rake;
-
-                if(read_change_position) {
-                    xynew[ix] = atof(col[6+new]);
-                    if(new) xynew[iy] = atof(txt_a);
-                    else xynew[iy] = atof(col[7]);
-                    if(fabs(xynew[ix]) > EPSIL || fabs(xynew[iy]) > EPSIL)
-                        write_change_position = TRUE;
-                    else
-                        write_change_position = FALSE;
-                }
-            } else if(read_planes) {
+                define_second_plane(meca.NP1, &meca.NP2);
+            }
+	    
+	    else if (read_planes) {
                 meca.NP1.str = atof(col[2+new]);
                 meca.NP1.dip = atof(col[3+new]);
                 meca.NP2.str = atof(col[4+new]);
@@ -687,32 +671,22 @@ int main (int argc, char **argv)
 
                 meca.moment.exponent = 0;
                 meca.NP2.dip = computed_dip2(meca.NP1.str, meca.NP1.dip, meca.NP2.str);
-                if(meca.NP2.dip == 1000.) {
+                if (meca.NP2.dip == 1000.) {
                     not_defined = TRUE;
                     transparence_old = transparence;
                     n_plane_old = n_plane;
                     transparence = TRUE;
                     n_plane = 1;
                     meca.NP1.rake = 1000.;
-                    if(gmtdefs.verbose) {
+                    if (gmtdefs.verbose)
                         fprintf(stderr, "WARNING : second plane is not defined for event %s only first plane is plotted.\n", line);
-                    }
                 }
-                else {
+                else
                     meca.NP1.rake = computed_rake2(meca.NP2.str, meca.NP2.dip, meca.NP1.str, meca.NP1.dip, fault);
-                }
                 meca.NP2.rake = computed_rake2(meca.NP1.str, meca.NP1.dip, meca.NP2.str, meca.NP2.dip, fault);
-
-                if(read_change_position) {
-                    xynew[ix] = atof(col[7+new]);
-                    if(new) xynew[iy] = atof(txt_a);
-                    else xynew[iy] = atof(col[8]);
-                    if(fabs(xynew[ix]) > EPSIL || fabs(xynew[iy]) > EPSIL)
-                        write_change_position = TRUE;
-                    else
-                        write_change_position = FALSE;
-                }
-            } else if(read_axis) {
+            }
+	    
+	    else if (read_axis) {
                 T.val = atof(col[2+new]);
                 T.str = atof(col[3+new]);
                 T.dip = atof(col[4+new]);
@@ -727,9 +701,8 @@ int main (int argc, char **argv)
                 P.str = atof(col[9+new]);
                 P.dip = atof(col[10+new]);
                 P.e = atoi(col[11+new]);
-
 /*
-F. A. Dahlen and Jeoren Trom, Theoretical Seismology, Princeton, 1998, p.167.
+F. A. Dahlen and Jeroen Tromp, Theoretical Seismology, Princeton, 1998, p.167.
 Definition of scalar moment.
 */
                 meca.moment.exponent = T.e;
@@ -741,31 +714,14 @@ Definition of scalar moment.
                 N.val /= meca.moment.mant;
                 P.val /= meca.moment.mant;
 
-                if(transparence || plot_dc) {
-                    axe2dc(T, P, &NP1, &NP2);
-                    meca.NP1.str = NP1.str;
-                    meca.NP1.dip = NP1.dip;
-                    meca.NP1.rake = NP1.rake;
-                    meca.NP2.str = NP2.str;
-                    meca.NP2.dip = NP2.dip;
-                    meca.NP2.rake = NP2.rake;
-                }
+                if (transparence || plot_dc) axe2dc(T, P, &meca.NP1, &meca.NP2);
+            }
 
-                if(read_change_position) {
-                    xynew[ix] = atof(col[12+new]);
-                    if(new) xynew[iy] = atof(txt_a);
-                    else xynew[iy] = atof(col[13]);
-                    if(fabs(xynew[ix]) > EPSIL || fabs(xynew[iy]) > EPSIL)
-                        write_change_position = TRUE;
-                    else
-                        write_change_position = FALSE;
-                }
-            } else if(read_tensor) {
-                for((i=2+new,n=0);i<8+new;(i++,n++)) mt.f[n] = atof(col[i]);
+	    else if (read_tensor) {
+                for (i=2+new, n=0; i<8+new; i++, n++) mt.f[n] = atof(col[i]);
                 mt.expo = atoi(col[i]);
-
 /*
-F. A. Dahlen and Jeoren Trom, Theoretical Seismology, Princeton, 1998, p.167.
+F. A. Dahlen and Jeroen Tromp, Theoretical Seismology, Princeton, 1998, p.167.
 Definition of scalar moment.
 */
                 meca.moment.mant = sqrt(squared(mt.f[0]) + squared(mt.f[1]) + squared(mt.f[2]) + 2.*(squared(mt.f[3]) + squared(mt.f[4]) + squared(mt.f[5]))) / M_SQRT2;
@@ -775,42 +731,32 @@ Definition of scalar moment.
 /* normalization by M0 */
                 for(i=0;i<=5;i++) mt.f[i] /= meca.moment.mant;
 
-                momten2axe(mt, &T, &N, &P);
+                GMT_momten2axe(mt, &T, &N, &P);
 
-                if(transparence || plot_dc) {
-                    axe2dc(T, P, &NP1, &NP2);
-                    meca.NP1.str = NP1.str;
-                    meca.NP1.dip = NP1.dip;
-                    meca.NP1.rake = NP1.rake;
-                    meca.NP2.str = NP2.str;
-                    meca.NP2.dip = NP2.dip;
-                    meca.NP2.rake = NP2.rake;
-                }
-
-                if(read_change_position) {
-                    xynew[ix] = atof(col[9+new]);
-                    if(new) xynew[iy] = atof(txt_a);
-                    else xynew[iy] = atof(col[10]);
-                    if(fabs(xynew[ix]) > EPSIL || fabs(xynew[iy]) > EPSIL)
-                        write_change_position = TRUE;
-                    else
-                        write_change_position = FALSE;
-                }
+                if (transparence || plot_dc) axe2dc(T, P, &meca.NP1, &meca.NP2);
             }
 
+	    /* Common to all input types ... */
+
             GMT_geo_to_xy (xy[0], xy[1], &plot_x, &plot_y);
-                
-            if(write_change_position) {
-                GMT_setpen(&cpen);
-                GMT_geo_to_xy(xynew[0], xynew[1], &plot_xnew, &plot_ynew);
-                ps_circle(plot_x, plot_y, pointsize, fill.rgb, 1);
-                ps_plot(plot_x, plot_y, 3);
-                ps_plot(plot_xnew, plot_ynew, 2);
-                plot_x = plot_xnew;
-                plot_y = plot_ynew;
+
+	    /* If option -C is used, read the new position */
+
+            if (read_change_position) {
+                xynew[ix] = atof(col[last-1+new]);
+                xynew[iy] = atof(col[last+new]);
+                if (fabs(xynew[ix]) > EPSIL || fabs(xynew[iy]) > EPSIL) {
+                    GMT_setpen(&cpen);
+                    GMT_geo_to_xy(xynew[0], xynew[1], &plot_xnew, &plot_ynew);
+                    ps_circle(plot_x, plot_y, pointsize, fill.rgb, 1);
+                    ps_plot(plot_x, plot_y, 3);
+                    ps_plot(plot_xnew, plot_ynew, 2);
+                    plot_x = plot_xnew;
+                    plot_y = plot_ynew;
+	    	}
             }
 
-            if(one_size) {
+            if (one_size) {
                 meca.moment.mant = 4.;
                 meca.moment.exponent = 23;
             }
@@ -822,34 +768,27 @@ Definition of scalar moment.
             get_trans(xy[0], xy[1], &t11, &t12, &t21, &t22);
             delaz = atan2(t12,t11) / D2R;
 
-            if((read_axis || read_tensor) && !plot_dc) {
+            if ((read_axis || read_tensor) && !plot_dc) {
 
                 T.str = zero_360(T.str + delaz);
                 N.str = zero_360(N.str + delaz);
                 P.str = zero_360(P.str + delaz);
 
                 GMT_setpen(&lpen);
-                if(fabs(N.val) < EPSIL && fabs(T.val + P.val) < EPSIL) {
-                    axe2dc(T, P, &NP1, &NP2);
-                    meca.NP1.str = NP1.str;
-                    meca.NP1.dip = NP1.dip;
-                    meca.NP1.rake = NP1.rake;
-                    meca.NP2.str = NP2.str;
-                    meca.NP2.dip = NP2.dip;
-                    meca.NP2.rake = NP2.rake;
+                if (fabs(N.val) < EPSIL && fabs(T.val + P.val) < EPSIL) {
+                    axe2dc(T, P, &meca.NP1, &meca.NP2);
                     ps_mechanism(plot_x,plot_y,meca,size,fill.rgb,efill.rgb,outline);
                 }
-                else {
+                else
                     ps_tensor(plot_x,plot_y,size,T,N,P,fill.rgb,efill.rgb,outline,plot_zerotrace);
-                }
             }
 
-            if(tr_zerotrace) {
+            if (tr_zerotrace) {
                 GMT_setpen(&tz_pen);
                 ps_tensor(plot_x,plot_y,size,T,N,P,nofill.rgb,nofill.rgb,tr_zerotrace,tr_zerotrace);
             }
 
-            if(transparence) {
+            if (transparence) {
                 meca.NP1.str = zero_360(meca.NP1.str + delaz);
                 meca.NP2.str = zero_360(meca.NP2.str + delaz);
                 GMT_setpen(&tr_pen);
@@ -861,44 +800,41 @@ Definition of scalar moment.
                         ps_plan(plot_x, plot_y, meca, size, n_plane);
                         break;
                 }
-                if(not_defined) {
+                if (not_defined) {
                     not_defined = FALSE;
                     transparence = transparence_old;
                     n_plane = n_plane_old;
                 }
-            } else if(read_aki || read_cmt || read_planes || plot_dc) {
+            } else if (read_aki || read_cmt || read_planes || plot_dc) {
                 meca.NP1.str = zero_360(meca.NP1.str + delaz);
                 meca.NP2.str = zero_360(meca.NP2.str + delaz);
                 GMT_setpen(&lpen);
                 ps_mechanism(plot_x,plot_y,meca,size,fill.rgb,efill.rgb,outline);
             }                                        
 
-            if(! no_label) {
+            if (!no_label) {
                 GMT_setpen(&pen);
                 switch (justify) {
                     case 2 :
-                        if(draw_box) {
+                        if (draw_box)
                             ps_rect(plot_x - size * 0.5, plot_y + size * 0.5 + offset + (fontsize / 72.0), plot_x + size * 0.5, plot_y + size * 0.5 + offset, bfill.rgb, FALSE);
-                        }
                         ps_text(plot_x, plot_y + size * 0.5 + offset, fontsize, event_title, angle, justify, form);
                         ps_plot(plot_x, plot_y + size * 0.5 + offset, 3);
                         break;
                     case 10 :
-                        if(draw_box) {
+                        if (draw_box)
                             ps_rect(plot_x - size * 0.5, plot_y - size * 0.5 - offset - (fontsize / 72.0), plot_x + size * 0.5, plot_y - size * 0.5 - offset, bfill.rgb, FALSE);
-                        }
                         ps_text(plot_x, plot_y - size * 0.5 - offset, fontsize, event_title, angle, justify, form);
                         ps_plot(plot_x, plot_y - size * 0.5 - offset, 3);
                         break;
                 }
             }
 
-            if(plot_axis) {
-                if(read_axis || read_tensor)
+            if (plot_axis) {
+                if (read_axis || read_tensor)
                     axis2xy(plot_x, plot_y, size, P.str, P.dip, T.str, T.dip, &P_x, &P_y, &T_x, &T_y);
-                else {
+                else
                     ps_pt_axis(plot_x, plot_y, meca, size, &P.str, &P.dip, &T.str, &T.dip, &P_x, &P_y, &T_x, &T_y);
-                }
                 GMT_setpen(&ppen);
                 switch (P_sym) {
                     case STAR:
