@@ -1,7 +1,7 @@
 /*-------------------------------------------------------------------------
- *	$Id: mgd77.h,v 1.90 2008/04/22 03:34:38 mtchandl Exp $
+ *	$Id: mgd77.h,v 1.104 2009/02/12 04:45:55 guru Exp $
  * 
- *    Copyright (c) 2005-2008 by P. Wessel
+ *    Copyright (c) 2005-2009 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *
  *  File:	mgd77.h
@@ -9,7 +9,7 @@
  *  Include file for programs that plan to read/write MGD77[+] files
  *
  *  Authors:    Paul Wessel, Primary Investigator, SOEST, U. of Hawaii
- *		Michael Chandler, Master's Candidate, SOEST, U. of Hawaii
+ *				Michael Chandler, Ph.D. Student, SOEST, U. of Hawaii
  *		
  *  Version:	1.3
  *  Revised:	15-MAR-2006
@@ -34,6 +34,7 @@
 #define MGD77_N_NUMBER_FIELDS	24		/* Original 24 numerical data columns in MGD77 */
 #define MGD77_N_STRING_FIELDS	3		/* Original 3 text data columns in MGD77 */
 #define MGD77_N_HEADER_ITEMS	66		/* Number of individual header items in the MGD77 header */
+#define MGD77_N_MAG_RF		18		/* Number of different Mag ref fields so far in MGD77 docs */
 /* The 28 MGD77 standard types (27 original + 1 conglomerate (time)) */
 #define MGD77_RECTYPE		0
 #define MGD77_TZ		1
@@ -103,6 +104,8 @@
 #define MGD77_IGF_1967		3
 #define MGD77_IGF_1980		4
 
+#define MGD77_IGRF_LAST_ID	20	/* IGRF fields IDs in MGD77 are 3,4,11-MGD77_IGRF_LAST_ID.  Update when more fields are added */
+
 #define TWT_PDR_WRAP	10.0						/* The 10 second PDR wrap-around we see in SIO cruises */
 #define TWT_PDR_WRAP_TRIGGER	0.5 * TWT_PDR_WRAP	/* Any jump in TWT that exceeds this triggers a wrap */
 
@@ -142,6 +145,10 @@
 #define NCPOS_TIME	0
 #define NCPOS_LAT	3
 #define NCPOS_LON	4
+#define NCPOS_TWT	6
+#define NCPOS_MTF1	10
+#define NCPOS_GOBS	16
+#define NCPOS_EOT	21
 
 /* We will use bit flags to keep track of which data column we are referring to.
  * field 0 is rightmost bit (1), field 1 is the next bit (2), field 2 is 4 and
@@ -174,7 +181,6 @@
 #define MGD77_BIT		6
 #define MGD77_NEQ		8
 
-#define N_AUX	15		/* Number of auxilliary columns in mgd77list */
 
 typedef char byte;	/* Used to indicate 1-byte long integer */
 typedef char* Text;	/* Used to indicate character strings */
@@ -190,6 +196,12 @@ typedef char* Text;	/* Used to indicate character strings */
 #define MGD77_COL_UNIT_LEN	64
 #define MGD77_COL_COMMENT_LEN	128
 
+#define MGD77_COL_ADJ_TWT	1	/* Undo twt PDR wraps given PDR_wrap value */
+#define MGD77_COL_ADJ_DEPTH	2	/* Compute Carter depth from twt */
+#define MGD77_COL_ADJ_MAG	3	/* Compute mag from mtf1 - igrf */
+#define MGD77_COL_ADJ_FAA	4	/* Compute faa from gobs - igf */
+#define MGD77_COL_ADJ_FAA_EOT	5	/* Compute faa from gobs - igf + eot */
+
 struct MGD77_COLINFO {
 	char *abbrev;		/* Short name that identifies this column */
 	char *name;		/* Longer, descriptive name for column */
@@ -204,6 +216,7 @@ struct MGD77_COLINFO {
 	nc_type type;		/* Type of representation of this data in the netCDF file (NC_SHORT, NC_INT, NC_BYTE, etc) */
 	char text;		/* length if this is a text string, else 0 */
 	int var_id;		/* netCDF variable ID */
+	int adjust;		/* Column needs some sort of adjustment before data is returned [0 means as is] */
 	BOOLEAN constant;	/* TRUE if column is constant and only 1 row is/should be stored */
 	BOOLEAN present;	/* TRUE if column is present in the file (NaN or otherwise) */
 };
@@ -221,6 +234,7 @@ struct MGD77_META {	/* Information about a cruise as derived from navigation dat
 	int Departure[3];	/* yyyy, mm, dd of departure */
 	int Arrival[3];		/* yyyy, mm, dd of arrival */
 	signed char ten_box[20][38];	/* Set to 1 for each box visited */
+	double G1980_1930;	/* Average difference between 1980 and 1930 gravity reference field for this cruise */
 };
 
 struct MGD77_HEADER {	
@@ -233,10 +247,49 @@ struct MGD77_HEADER {
 	int n_fields;					/* Number of columns returned */
 	int errors[3];					/* Number of total errors, (warnings, errors) found when reading this header */
 	BOOLEAN no_time;				/* TRUE for those few cruises that have no time values */
+	double PDR_wrap;				/* Non-zero if we must undo PDR wrapping */
 	struct MGD77_DATA_INFO info[MGD77_N_SETS];	/* Info regarding [0] standard MGD77 columns and [1] any extra columns (max 32 each) */
 };
 
 
+/* We may want to output columns that themselves are not stored in the MGD77[+] files but
+ * rather are computed based on data that are stored in the file.  We consider such information
+ * as AUXILLARY columns and insert them between the observed columns when needed.  The following
+ * structures are used to facilitate this process. */
+
+#define N_MGD77_AUX	15		/* Number of auxilliary derived columns for MGD77 data */
+#define N_GENERIC_AUX	3		/* Number of auxilliary derived columns for general files (dist, azim, vel) */
+
+#define MGD77_AUX_DS	0
+#define MGD77_AUX_AZ	1
+#define MGD77_AUX_SP	2
+#define MGD77_AUX_YR	3
+#define MGD77_AUX_MO	4
+#define MGD77_AUX_DY	5
+#define MGD77_AUX_HR	6
+#define MGD77_AUX_MI	7
+#define MGD77_AUX_SC	8
+#define MGD77_AUX_WT	9
+#define MGD77_AUX_RT	10
+#define MGD77_AUX_MG	11
+#define MGD77_AUX_CT	12
+#define MGD77_AUX_GR	13
+#define MGD77_AUX_ID	14
+
+struct MGD77_AUXLIST {
+	char name[MGD77_COL_ABBREV_LEN];
+	GMT_LONG type;
+	GMT_LONG text;
+	GMT_LONG requested;
+	char header[GMT_TEXT_LEN];
+};
+
+struct MGD77_AUX_INFO {
+	GMT_LONG type;
+	GMT_LONG text;
+	GMT_LONG pos;
+};
+
 /* The data records in the MGD77 file consist of records that are 120 characters.
  * This information can be read and stored internally in the structure MGD77_DATA_RECORD.
  * The two i/o functions MGD77_read_record and MGD77_write_record will do exactly what they say.
@@ -252,7 +305,7 @@ struct MGD77_DATA_RECORD {	/* See MGD77 Documentation from NGDC for details */
 };
 
 struct MGD77_DATASET {	/* Info for an entire MGD77+ data set */
-	int n_fields;				/* Number of active colums in the values table */
+	int n_fields;				/* Number of active columns in the values table */
 	int errors;				/* Number of errors encountered when writing this data */
 	struct MGD77_HEADER H;			/* The file's header information */
 	void *values[MGD77_MAX_COLS];		/* 2-D table of necessary number of columns and rows (mix of double and char pointers) */
@@ -327,7 +380,7 @@ struct MGD77_CONTROL {
 	int n_constraints;				/* Number of constraints specified */
 	int n_exact;					/* Number of exact columns to match */
 	int n_bit_tests;				/* Number of bit tests to match */
-	int no_checking;				/* TRUE if there are no constraints, extact-tests, or bit-tests to pass */
+	int no_checking;				/* TRUE if there are no constraints, exact-tests, or bit-tests to pass */
 	struct MGD77_CONSTRAINT Constraint[MGD77_MAX_COLS];		/* List of constraints, if any */
 	char desired_column[MGD77_MAX_COLS][MGD77_COL_ABBREV_LEN];	/* List of desired column names in final output order */
 	struct MGD77_PAIR Exact[MGD77_MAX_COLS];	/* List of column names whose values must be !NaN to be output, if any */
@@ -347,7 +400,7 @@ struct MGD77_CARTER {
 	short int carter_correction[N_CARTER_CORRECTIONS];
 };
 
-/* Structures for emphemeral corrections */
+/* Structures for ephemeral corrections */
 
 struct MGD77_CORRECTION {	/* Holds parameters for one term of a correction for one kind of observation */
 	int id;			/* The id - entry to give us the data column to use*/
@@ -418,6 +471,7 @@ extern BOOLEAN MGD77_txt_are_constant (char *txt, GMT_LONG n, int width);
 extern int MGD77_do_scale_offset_before_write (double new[], const double x[], GMT_LONG n, double scale, double offset, int type);
 extern void MGD77_select_high_resolution ();
 extern void MGD77_free_plain_mgd77 (struct MGD77_HEADER *H);
+extern int MGD77_Match_List (char *word, int n_fields, char **list);
 
 /* User functions for direct use of Carter corrections */
 
@@ -432,6 +486,8 @@ extern double MGD77_carter_correction (double lon, double lat, double twt_in_mse
 extern int MGD77_igrf10syn (int isv, double date, int itype, double alt, double lon, double lat, double *out);
 extern double MGD77_Theoretical_Gravity (double lon, double lat, int version);
 extern void MGD77_IGF_text (FILE *fp, int version);
+extern double MGD77_Recalc_Mag_Anomaly (double time, double lon, double lat, double obs, BOOLEAN calc_date);
+extern double MGD77_time_to_fyear (double time);
 
 /* These are called indirectly but remain accessible for specialist programs */
 
@@ -449,9 +505,12 @@ extern BOOLEAN MGD77_format_allowed[MGD77_N_FORMATS];	/* By default we allow ope
 extern double MGD77_Epoch_zero;
 extern int MGD77_pos[MGD77_N_DATA_EXTENDED];
 
-void MGD77_Parse_Corrtable (struct MGD77_CONTROL *F, char *tablefile, char **cruises, int n_cruises, struct MGD77_CORRTABLE ***CORR);
+int MGD77_Scan_Corrtable (char *tablefile, char **cruises, int n_cruises, int n_fields, char **field_names, char ***item_names, int mode);
+void MGD77_Parse_Corrtable (char *tablefile, char **cruises, int n_cruises, int n_fields, char **field_names, int mode, struct MGD77_CORRTABLE ***CORR);
 void MGD77_Init_Correction (struct MGD77_CORRTABLE *CORR, double **value);
 double MGD77_Correction (struct MGD77_CORRECTION *C, double **value, double *aux, GMT_LONG rec);
+double MGD77_Correction_Rec (struct MGD77_CORRECTION *C, double *value, double *aux);
+void MGD77_Free_Correction (struct MGD77_CORRTABLE **CORR, int n);
 
 #include "mgd77_functions.h"	/* These were created by mgd77netcdfhelper.sh */
 
