@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77convert.c,v 1.35 2007/03/12 19:52:26 remko Exp $
+ *	$Id: mgd77convert.c,v 1.43 2009/01/09 04:02:35 guru Exp $
  *
- *    Copyright (c) 2005-2007 by P. Wessel
+ *    Copyright (c) 2005-2009 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -27,7 +27,7 @@ int main (int argc, char **argv)
 {
 	int code_pos, i, in_out, argno, n_cruises = 0, n_paths, format[2] = {MGD77_NOT_SET, MGD77_NOT_SET};
 		
-	BOOLEAN error = FALSE, force = FALSE, high_resolution = FALSE;
+	BOOLEAN error = FALSE, force = FALSE, high_resolution = FALSE, original = FALSE;
 	
 	char file[BUFSIZ], **list, *fcode = "act";
 	char *format_name[MGD77_N_FORMATS] = {"MGD77 ASCII", "MGD77+ netCDF", "ASCII table"};
@@ -39,7 +39,7 @@ int main (int argc, char **argv)
 	
 	/* Initialize MGD77 output order and other parameters*/
 	
-	MGD77_Init (&In, TRUE);			/* Initialize MGD77 Machinery */
+	MGD77_Init (&In);			/* Initialize MGD77 Machinery */
 	
 	for (argno = 1; !error && argno < argc; argno++) {	/* Process input options */
 		if (argv[argno][0] != '-') continue;
@@ -67,15 +67,14 @@ int main (int argc, char **argv)
 			case 'F':
 				switch (argv[argno][code_pos]) {									
 					case 'a':		/* Standard ascii MGD77 file */
-					case 'A':
 						format[in_out] = MGD77_FORMAT_M77;
 						break;
-					case 'c':		/* Enhanced MGD77+ netCDF file */
-					case 'C':
+					case 'C':		/* Enhanced MGD77+ netCDF file */
+						original = TRUE;	/* Overlook revisions */
+					case 'c':
 						format[in_out] = MGD77_FORMAT_CDF;
 						break;
 					case 't':		/* Plain ascii dat table */
-					case 'T':
 						format[in_out] = MGD77_FORMAT_TBL;
 						break;
 					default:
@@ -105,6 +104,7 @@ int main (int argc, char **argv)
 		MGD77_Cruise_Explain ();
 		fprintf (stderr, "	[Files are read from data repositories and written to current directory]\n");
 		fprintf (stderr, "	-F Convert from a file that is either (a) MGD77 ASCII, (c) MGD77+ netCDF, or (t) plain table\n");
+		fprintf (stderr, "	   Use -FC to recover the original MGD77 setting from the MGD77+ file [Default applies E77 corrections]\n");
 		fprintf (stderr, "	-T Convert to a file that is either (a) MGD77 ASCII, (c) MGD77+ netCDF, or (t) plain table\n");
 		fprintf (stderr, "	   By default we will refuse to overwrite existing files.  Prepend + to override this policy.\n");
 		fprintf (stderr, "	OPTIONS:\n\n");
@@ -149,6 +149,8 @@ int main (int argc, char **argv)
 		MGD77_Reset (&In);		/* Reset to start fresh for next file */
 
 		In.format  = format[GMT_IN];	/* Set input file's format and read everything into memory */
+		In.original = original;
+		if (original) In.use_corrections[MGD77_M77_SET] = In.use_corrections[MGD77_CDF_SET] = FALSE;	/* Turn off E77 corrections */
 		for (i = 0; i < MGD77_N_FORMATS; i++) MGD77_format_allowed[i] = (In.format == i) ? TRUE : FALSE;	/* Only allow the specified input format */
 		if (MGD77_Open_File (list[argno], &In, MGD77_READ_MODE)) continue;
 		if (MGD77_Read_Header_Record (list[argno], &In, &D->H)) {
@@ -196,6 +198,7 @@ int main (int argc, char **argv)
 		/* OK, ready to write out converted file */
 		
 		In.format  = format[GMT_OUT];				/* Change the format to the desired output format and write new file in current directory */
+		In.original = TRUE;					/* Always write to original attributes */
 		for (i = 0; i < MGD77_N_FORMATS; i++) MGD77_format_allowed[i] = (In.format == i) ? TRUE : FALSE;	/* Only allow the specified output format */
 		D->H.author = (char *)GMT_memory (VNULL, strlen (In.user)+1, sizeof (char), GMT_program);	/* Allocate space for author */
 		strcpy (D->H.author, In.user);									/* Pass current user login id as author */
@@ -217,5 +220,8 @@ int main (int argc, char **argv)
 	
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Converted %d MGD77 files\n", GMT_program, n_cruises);
 	
+	MGD77_Path_Free (n_paths, list);
+	MGD77_end (&In);
+
 	exit (EXIT_SUCCESS);
 }
