@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: minmax.c,v 1.44 2007/03/24 01:42:07 pwessel Exp $
+ *    $Id: minmax.c,v 1.55 2009/02/02 22:25:51 remko Exp $
  *
- *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -44,23 +44,30 @@ struct MINMAX_CTRL {	/* All control options for this program (except common args
 		int ncol;
 		double inc[BUFSIZ];
 	} I;
-	struct T {	/* -T<dz> */
+	struct S {	/* -S[x|y] */
+		BOOLEAN active;
+		BOOLEAN xbar, ybar;
+	} S;
+	struct T {	/* -T<dz>[/<col>] */
 		BOOLEAN active;
 		double inc;
+		int col;
 	} T;
 };
 
 int main (int argc, char **argv)
 {
 	BOOLEAN  error = FALSE, nofile = TRUE, done = FALSE, got_stuff = FALSE, first, give_r_string = FALSE;
-	BOOLEAN  dateline = FALSE, brackets = FALSE, work_on_abs_value, special = FALSE;
+	BOOLEAN  dateline = FALSE, brackets = FALSE, work_on_abs_value, special = FALSE, quad[4] = {FALSE, FALSE, FALSE, FALSE};
 
 	char line[BUFSIZ], file[BUFSIZ], chosen[BUFSIZ];
 
-	int n, i, j, ncol, n_files = 0, fno, n_args, n_fields, n_expected_fields;
+	int i, j, ncol, n_files = 0, fno, n_args, n_fields, n_expected_fields, quad_no;
 
+	GMT_LONG n;
+	
 	double *xyzmin, *xyzmax, west, east, south, north, low, high, value, e_min = DBL_MAX, e_max = -DBL_MAX, *in;
-	double xmin1 = 360.0, xmin2 = 360.0, xmax1 = -360.0, xmax2 = -360.0, lon_w;
+	double xmin1 = 360.0, xmin2 = 360.0, xmax1 = -360.0, xmax2 = -360.0;
 
 	FILE *fp = NULL;
 
@@ -131,7 +138,18 @@ int main (int argc, char **argv)
 					break;
 				case 'T':
 					Ctrl->T.active = TRUE;
-					Ctrl->T.inc = atof (&argv[i][2]);
+					j = sscanf (&argv[i][2], "%lf/%d", &Ctrl->T.inc, &Ctrl->T.col);
+					if (j == 1) Ctrl->T.col = 0;
+					break;
+				case 'S':
+					Ctrl->S.active = TRUE;
+					j = 2;
+					while (argv[i][j]) {
+						if (argv[i][j] == 'x') Ctrl->S.xbar = TRUE;
+						if (argv[i][j] == 'y') Ctrl->S.ybar = TRUE;
+						j++;
+					}
+					if (j == 2) Ctrl->S.xbar = Ctrl->S.ybar = TRUE;
 					break;
 				default:
 					error = TRUE;
@@ -146,7 +164,7 @@ int main (int argc, char **argv)
 	if (error || GMT_give_synopsis_and_exit) {	/* Because it's ok to give no arguments */
 		fprintf (stderr, "minmax %s - Find extreme values in ASCII tables\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: minmax [files] [-C] [-E<L|l|H|h><col>] [%s] [-I[p]<dx>[/<dy>[/<dz>..]] [%s]\n", GMT_H_OPT, GMT_M_OPT);
-		fprintf (stderr, "\t[-T<dz>] [%s] [%s] [%s]\n", GMT_t_OPT, GMT_bi_OPT, GMT_f_OPT);
+		fprintf (stderr, "\t[-S[x][y]] [-T<dz>[/<col>]] [%s] [%s] [%s]\n", GMT_t_OPT, GMT_bi_OPT, GMT_f_OPT);
              
               	if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
  
@@ -161,8 +179,12 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   If only one increment is given we also use it for the second column (for backwards compatibility).\n");
 		fprintf (stderr, "\t   To override this behaviour, use -Ip<dx>.\n");
 		GMT_explain_option ('M');
+		fprintf (stderr, "\t-S adds extra space for error bars. Useful together with -I.\n");
+		fprintf (stderr, "\t   -Sx leaves space for horizontal error bar using value in third (2) column.\n");
+		fprintf (stderr, "\t   -Sy leaves space for vertical error bar using value in third (2) column.\n");
+		fprintf (stderr, "\t   -S or -Sxy leaves space for both error bars using values in third&fourth (2&3) columns.\n");
 		fprintf (stderr, "\t-T returns textstring -Tzmin/zmax/dz to nearest multiple of the given dz\n");
-		fprintf (stderr, "\t   Calculations are based on the first column only\n");
+		fprintf (stderr, "\t   Calculations are based on the first (0) column only.  Append /<col> to use another column\n");
 		GMT_explain_option (':');
 		GMT_explain_option ('i');
 		GMT_explain_option ('n');
@@ -171,6 +193,8 @@ int main (int argc, char **argv)
 		GMT_explain_option ('.');
 		exit (EXIT_FAILURE);
 	}
+	
+	GMT_check_lattice (&Ctrl->I.inc[0], &Ctrl->I.inc[1], NULL, &Ctrl->I.active);
 	if (Ctrl->I.active && !special && Ctrl->I.ncol == 1) {		/* Special case of dy = dx if not given */
 		Ctrl->I.inc[1] = Ctrl->I.inc[0];
 		Ctrl->I.ncol = 2;
@@ -288,17 +312,27 @@ int main (int argc, char **argv)
 			if ((GMT_io.status & GMT_IO_EOF)) continue;	/* At EOF */
 
 			if (GMT_io.status & GMT_IO_MISMATCH) {
-				fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %d\n", GMT_program, n_fields, n_expected_fields, n);
+				fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n);
 				exit (EXIT_FAILURE);
 			}
 
 			if (first) {	/* First time, allocate # of columns */
 
 				ncol = n_expected_fields;
-				if (Ctrl->E.active && Ctrl->E.col >= ncol) {
-	  				fprintf (stderr, "%s: GMT SYNTAX ERROR -E option: Chosen column exceeds column range\n", GMT_program);
+				if (Ctrl->S.active && 2 + Ctrl->S.xbar + Ctrl->S.ybar > ncol) {
+					fprintf (stderr, "%s: Not enough columns to support the -S option\n", GMT_program);
 					exit (EXIT_FAILURE);
 				}
+				if (Ctrl->E.active && Ctrl->E.col >= ncol) {
+	  				fprintf (stderr, "%s: GMT SYNTAX ERROR -E option: Chosen column exceeds column range (0-%i)\n", GMT_program, ncol-1);
+					exit (EXIT_FAILURE);
+				}
+				if (Ctrl->T.active && Ctrl->T.col >= ncol) {
+					fprintf (stderr, "%s: GMT SYNTAX ERROR -T option: Chosen column exceeds column range (0-%i)\n", GMT_program, ncol-1);
+					exit (EXIT_FAILURE);
+				}
+				if (Ctrl->T.active) ncol = Ctrl->T.col+1;
+				if (give_r_string) ncol = 2;
 
 				/* Now we know # of columns, so allocate memory */
 
@@ -334,16 +368,22 @@ int main (int argc, char **argv)
 				for (i = 0; i < ncol; i++) {
 					if (GMT_is_dnan (in[i])) continue;
 					if (i == 0 && GMT_io.in_col_type[i] == GMT_IS_LON) {
-						lon_w = in[i];
-						if (in[i] < 0.0) in[i] += 360.0;	/* Start off with everything in 0-360 range */
-						if (in[i] < 180.0) {
-							xmin1 = MIN (in[i], xmin1);
-							xmax1 = MAX (in[i], xmax1);
-						}
-						else {
-							xmin2 = MIN (lon_w, xmin2);
-							xmax2 = MAX (lon_w, xmax2);
-						}
+						while (in[i] < 0.0) in[i] += 360.0;	/* Start off with everything in 0-360 range */
+						xmin1 = MIN (in[i], xmin1);
+						xmax1 = MAX (in[i], xmax1);
+						quad_no = (int)floor (in[i]/90.0);	/* Yields quadrants 0-3 */
+						if (quad_no == 4) quad_no = 0;		/* When in[i] == 360.0 */
+						quad[quad_no] = TRUE;
+						while (in[i] > 180.0) in[i] -= 360.0;	/* Switch to -180+/180 range */
+						xmin2 = MIN (in[i], xmin2);
+						xmax2 = MAX (in[i], xmax2);
+					}
+					else if ((i == 0 && Ctrl->S.xbar) || (i == 1 && Ctrl->S.ybar)) {
+						/* Add/subtract value from error bar column */
+						j = (i == 1 && Ctrl->S.xbar) ? 3 : 2;
+						value = fabs(in[j]);
+						if (in[i] - value < xyzmin[i]) xyzmin[i] = in[i] - value;
+						if (in[i] + value > xyzmax[i]) xyzmax[i] = in[i] + value;
 					}
 					else {
 						if (in[i] < xyzmin[i]) xyzmin[i] = in[i];
@@ -361,34 +401,49 @@ int main (int argc, char **argv)
 		if (!got_stuff) got_stuff = (n > 0);	/* We were able to open and read at least 1 record from a file */
 
 		if (GMT_io.in_col_type[0] == GMT_IS_LON) {	/* Now determine longitude range */
-			if (xmin1 == 360.0) {	/* Only negative longitudes found */
+			int n_quad;
+			n_quad = quad[0] + quad[1] + quad[2] + quad[3];	/* How many quadrants had data */
+			if (quad[0] && quad[3]) {	/* Longitudes on either side of Greenwich only, must use -180/+180 notation */
 				xyzmin[0] = xmin2;
 				xyzmax[0] = xmax2;
+				GMT_io.geo.range = 2;	/* Override this setting explicitly */
 			}
-			else if (xmin2 == 360.0) {	/* Only positive longitudes found */
+			else if (quad[1] && quad[2]) {	/* Longitudes on either side of the date line, must user 0/360 notation */
 				xyzmin[0] = xmin1;
 				xyzmax[0] = xmax1;
+				GMT_io.geo.range = 0;	/* Override this setting explicitly */
 			}
-			else if ((xmin1 - xmax2) < 90.0) {	/* Crossed Greenwich */
-				xyzmin[0] = xmin2;
-				xyzmax[0] = xmax1;
+			else if (n_quad == 2 && ((quad[0] && quad[2]) || (quad[1] && quad[3]))) {	/* Funny quadrant gap, pick shortest longitude extent */
+				if ((xmax1 - xmin1) < (xmax2 - xmin2)) {	/* 0/360 more compact */
+					xyzmin[0] = xmin1;
+					xyzmax[0] = xmax1;
+					GMT_io.geo.range = 0;	/* Override this setting explicitly */
+				}
+				else {						/* -180/+180 more compact */
+					xyzmin[0] = xmin2;
+					xyzmax[0] = xmax2;
+					GMT_io.geo.range = 2;	/* Override this setting explicitly */
+				}
 			}
-			else {					/* Crossed Dateline */
+			else {						/* Either will do, use default settings */
 				xyzmin[0] = xmin1;
-				xyzmax[0] = xmax2;
+				xyzmax[0] = xmax1;
 			}
 			if (xyzmin[0] > xyzmax[0]) xyzmin[0] -= 360.0;
 			if (xyzmin[0] < 0.0 && xyzmax[0] < 0.0) xyzmin[0] += 360.0, xyzmax[0] += 360.0;
 		}
 		if (give_r_string && got_stuff) {
-			west  = MIN (west, xyzmin[0]);		east  = MAX (east, xyzmax[0]);
-			south = MIN (south, xyzmin[1]);		north = MAX (north, xyzmax[1]);
+			west  = MIN (west, xyzmin[0]);
+			east  = MAX (east, xyzmax[0]);
+			south = MIN (south, xyzmin[1]);
+			north = MAX (north, xyzmax[1]);
 		}
 		else if (Ctrl->T.active && got_stuff) {
-			west  = MIN (west, xyzmin[0]);		east  = MAX (east, xyzmax[0]);
+			west  = MIN (west, xyzmin[Ctrl->T.col]);
+			east  = MAX (east, xyzmax[Ctrl->T.col]);
 		}
 		else if (!Ctrl->E.active && n > 0) {
-			if (!Ctrl->C.active) fprintf (GMT_stdout, "%s: N = %d\t", file, n);
+			if (!Ctrl->C.active) fprintf (GMT_stdout, "%s: N = %ld\t", file, n);
 			for (i = 0; i < ncol; i++) {
 				if (xyzmin[i] == DBL_MAX) {
 					low = high = GMT_d_NaN;
@@ -413,8 +468,10 @@ int main (int argc, char **argv)
 	}
 	if (got_stuff) {
 		if (give_r_string) {
-			west  = floor (west / Ctrl->I.inc[0]) * Ctrl->I.inc[0];	east  = ceil (east / Ctrl->I.inc[0]) * Ctrl->I.inc[0];
-			south = floor (south / Ctrl->I.inc[1]) * Ctrl->I.inc[1];	north = ceil (north / Ctrl->I.inc[1]) * Ctrl->I.inc[1];
+			west  = floor (west / Ctrl->I.inc[0]) * Ctrl->I.inc[0];
+			east  = ceil (east / Ctrl->I.inc[0]) * Ctrl->I.inc[0];
+			south = floor (south / Ctrl->I.inc[1]) * Ctrl->I.inc[1];
+			north = ceil (north / Ctrl->I.inc[1]) * Ctrl->I.inc[1];
 			if (east < west) east += 360.0;
 			fprintf (GMT_stdout, "-R");
 			strip_blanks_and_output (west, 0);	fputc ('/', GMT_stdout);
@@ -423,7 +480,8 @@ int main (int argc, char **argv)
 			strip_blanks_and_output (north, 1);	fputc ('\n', GMT_stdout);
 		}
 		else if (Ctrl->T.active) {	/* -T option */
-			west  = floor (west / Ctrl->T.inc) * Ctrl->T.inc;	east  = ceil (east / Ctrl->T.inc) * Ctrl->T.inc;
+			west  = floor (west / Ctrl->T.inc) * Ctrl->T.inc;
+			east  = ceil (east / Ctrl->T.inc) * Ctrl->T.inc;
 			fprintf (GMT_stdout, "-T");
 			strip_blanks_and_output (west, 0);	fputc ('/', GMT_stdout);
 			strip_blanks_and_output (east, 0);	fputc ('/', GMT_stdout);
@@ -460,7 +518,7 @@ int strip_blanks_and_output (double x, int col)
 void *New_Minmax_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct MINMAX_CTRL *C;
 	
-	C = (struct MINMAX_CTRL *) GMT_memory (VNULL, 1, sizeof (struct MINMAX_CTRL), "New_Minmax_Ctrl");
+	C = (struct MINMAX_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct MINMAX_CTRL), "New_Minmax_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	
