@@ -1,6 +1,6 @@
 /*
- *	$Id: gmtstitch.c,v 1.29 2008/03/24 08:58:33 guru Exp $
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	$Id: gmtstitch.c,v 1.31 2009/01/09 04:02:35 guru Exp $
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  */
 /* gmtstitch will combine pieces of coastlines or similar segments into a
  * continuous line, polygon, or group of lines/polygons so that the jump
@@ -54,7 +54,8 @@ int main (int argc, char **argv)
 	void Write_This_Segment (FILE *fp, struct GMT_LINE_SEGMENT *line, GMT_LONG start, GMT_LONG end);
 	
 	argc = GMT_begin (argc, argv);
-
+	memset ((void *)format, 0, BUFSIZ);
+	
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
 			switch (argv[i][1]) {
@@ -147,7 +148,7 @@ int main (int argc, char **argv)
 
 	/* Now we are ready to take on some input values */
 
-	if (individual_file && !format) strcpy (format, "gmtstitch_segment_%ld.d");
+	if (individual_file && !format[0]) strcpy (format, "gmtstitch_segment_%ld.d");
 	n_args = (argc > 1) ? argc : 2;
 
 	switch (distance_flag) {	/* Take different action depending on how we want distances calculated */
