@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pscoast.c,v 1.81 2008/04/05 23:22:59 guru Exp $
+ *	$Id: pscoast.c,v 1.87 2009/01/16 21:43:11 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -67,6 +67,7 @@ struct PSCOAST_CTRL {
 	} C;
 	struct D {	/* -D<resolution> */
 		BOOLEAN active;
+		BOOLEAN force;	/* if TRUE, select next highest level if current set is not avaialble */
 		char set;	/* One of f, h, i, l, c */
 	} D;
 	struct E {	/* -Eazim/elev */
@@ -198,10 +199,11 @@ int main (int argc, char **argv)
 				case 'D':
 					Ctrl->D.active = TRUE;
 					Ctrl->D.set = argv[i][2];
+					if (argv[i][3] == '+') Ctrl->D.force = TRUE;
 					break;
 				case 'E':
 					Ctrl->E.active = TRUE;
-					sscanf (&argv[i][2], "%lf/%lf", &Ctrl->E.azimuth, &Ctrl->E.elevation);
+					error += GMT_get_proj3D (&argv[i][2], &Ctrl->E.azimuth, &Ctrl->E.elevation);
 					break;
 				case 'G':		/* Set Gray shade, pattern, or clipping */
 					Ctrl->G.active = TRUE;
@@ -352,7 +354,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || GMT_give_synopsis_and_exit) {	/* Display usage */
 		fprintf (stderr,"pscoast %s - Plot continents, shorelines, rivers, and borders on maps\n\n", GMT_VERSION);
 		fprintf (stderr,"usage: pscoast %s %s\n\t[-A<min_area>[/<min_level>/<max_level>]] [%s] [-C[<fill>]]\n", GMT_B_OPT, GMT_J_OPT, GMT_Rgeoz_OPT);
-		fprintf (stderr, "\t[-D<resolution>] [-Eaz/el] [-G[<fill>]] [-I<feature>[/<pen>]] [%s] [-K]\n", GMT_Jz_OPT);
+		fprintf (stderr, "\t[-D<resolution>][+] [%s] [-G[<fill>]] [-I<feature>[/<pen>]] [%s] [-K]\n", GMT_E_OPT, GMT_Jz_OPT);
 		fprintf (stderr, "\t[%s]\n", GMT_SCALE);
 		fprintf (stderr, "\t[%s] [-N<feature>[/<pen>]] [-O] [-P] [-Q] [-S<fill>]\n", GMT_Mo_OPT);
 		fprintf (stderr, "\t[%s] [%s]\n", GMT_TROSE, GMT_U_OPT);
@@ -374,7 +376,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   i - intermediate resolution\n");
 		fprintf (stderr, "\t   l - low resolution [Default]\n");
 		fprintf (stderr, "\t   c - crude resolution, for busy plots that need crude continent outlines only\n");
-		fprintf (stderr, "\t-E set azimuth and elevation of viewpoint for 3-D perspective [180/90]\n");
+		fprintf (stderr, "\t   Append + to use a lower resolution should the chosen one not be available [abort].\n");
+		GMT_explain_option ('E');
 		GMT_fill_syntax ('G', "Paint or clip \"dry\" areas.");
 		fprintf (stderr, "\t   6) c to issue clip paths for land areas.\n");
 		GMT_pen_syntax ('I', "draws rivers.  Specify feature and optionally append pen [Default is solid line of unit thickness].");
@@ -394,13 +397,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t      i = All intermittent rivers (5-7)\n");
 		fprintf (stderr, "\t      c = All canals (8-10)\n");
 		GMT_explain_option ('K');
-		fprintf (stderr, "\t-L draws a simple map scaLe centered on <lon0>/<lat0>.  Use -Lx to specify Cartesian\n");
-		fprintf (stderr, "\t   coordinates instead.  Scale is calculated at latitude <slat>; optionally give longitude\n");
-		fprintf (stderr, "\t   <slon> [Default is central longitude].  <length> is in km, or [nautical] miles if [n] m\n");
-		fprintf (stderr, "\t   is appended.  -Lf draws a \"fancy\" scale [Default is plain]. By default, the label is set\n");
-		fprintf (stderr, "\t   to the distance unit and placed on top [t].  Use the :label:<just> mechanism to specify another\n");
-		fprintf (stderr, "\t   label (or - to keep the default) and placement (t,b,l,r, and u - to use the label as a unit.\n");
-		fprintf (stderr, "\t   Append +p<pen> and/or +f<fill> to draw/paint a rectangle beneath the scale [no rectangle]\n");
+		GMT_mapscale_syntax ('L', "Draws a simple map scale centered on <lon0>/<lat0>");
 		fprintf (stderr, "\t-M Dump a multisegment ascii (or binary, see -bo) file to standard output.  No plotting occurs\n");
 		fprintf (stderr, "\t   Specify any combination of -W, -I, -N.  Optionally, append 1-char\n");
 		fprintf (stderr, "\t   segment header <flag> [%c]\n", GMT_io.EOF_flag[GMT_OUT]);
@@ -415,16 +412,7 @@ int main (int argc, char **argv)
 		fprintf (stderr,"\t-Q means terminate previously set clip-paths\n");
 		GMT_fill_syntax ('S', "Paint of clip \"wet\" areas.");
 		fprintf (stderr, "\t   6) c to issue clip paths for water areas.\n");
-		fprintf (stderr, "\t-T draws a north-poinTing rose centered on <lon0>/<lat0>.  Use -Tx to specify Cartesian\n");
-		fprintf (stderr, "\t   coordinates instead.  -Tf draws a \"fancy\" rose [Default is plain].  Give rose diameter\n");
-		fprintf (stderr, "\t   <size> and optionally the west, east, south, north labels desired [W,E,S,N].\n");
-		fprintf (stderr, "\t   For fancy rose, specify as <info> the kind you want: 1 draws E-W, N-S directions [Default],\n");
-		fprintf (stderr, "\t   2 adds NW-SE and NE-SW, while 3 adds WNW-ESE, NNW-SSE, NNE-SSW, and ENE-WSW.\n");
-		fprintf (stderr, "\t   For Magnetic compass rose, specify -Tm.  Use the optional <info> = <dec>/<dlabel> (where <dec> is\n");
-		fprintf (stderr, "\t   the magnetic declination and <dlabel> is a label for the magnetic compass needle) to plot\n");
-		fprintf (stderr, "\t   directions to both magnetic and geographic north [Default is just geographic].\n");
-		fprintf (stderr, "\t   If the North label = \'*\' then a north star is plotted instead of the label.\n");
-		fprintf (stderr, "\t   Append +<gints>/<mints> to override default annotation/tick interval(s) [10/5/1/30/5/1].\n");
+		GMT_maprose_syntax ('T', "Draws a north-pointing map rose centered on <lon0>/<lat0>");
 		GMT_explain_option ('U');
 		GMT_explain_option ('V');
 		GMT_pen_syntax ('W', "draw shorelines.  Append pen [Default is solid line of unit thickness].");
@@ -447,13 +435,15 @@ int main (int argc, char **argv)
 
 	dumping = (GMT_io.multi_segments[GMT_IN] || GMT_io.multi_segments[GMT_OUT]);	/* -M was set */
 	clipping = (Ctrl->G.clip || Ctrl->S.clip);
-	if (!(Ctrl->Q.active || project_info.region_supplied)) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify -R option\n", GMT_program);
-		error++;
-	}
-	if (!GMT_IS_MAPPING) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Geographic coastline data require the use of a map projection (use -Jx<scale>d if linear scaling is desired).\n", GMT_program);
-		error++;
+	if (!Ctrl->Q.active) {	/* Need -R -J */
+		if (!project_info.region_supplied) {
+			fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify -R option\n", GMT_program);
+			error++;
+		}
+		if (!GMT_IS_MAPPING) {
+			fprintf (stderr, "%s: GMT SYNTAX ERROR:  Geographic coastline data require the use of a map projection (use -Jx<scale>d if linear scaling is desired).\n", GMT_program);
+			error++;
+		}
 	}
 	if (Ctrl->W.pen.width < 0.0) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -W option:  Pen thickness cannot be negative\n", GMT_program);
@@ -520,6 +510,7 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
+	if (Ctrl->D.force) Ctrl->D.set = GMT_shore_adjust_res (Ctrl->D.set);
 	base = GMT_set_resolution (&Ctrl->D.set, 'D');
 	z_project.view_azimuth = Ctrl->E.azimuth;
 	z_project.view_elevation = Ctrl->E.elevation;
