@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pscontour.c,v 1.101 2008/03/27 07:28:38 guru Exp $
+ *	$Id: pscontour.c,v 1.104 2009/01/09 04:02:34 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -192,7 +192,7 @@ int main(int argc, char **argv)
 					break;
 				case 'E':
 					Ctrl->E.active = TRUE;
-					sscanf (&argv[i][2], "%lf/%lf", &Ctrl->E.azimuth, &Ctrl->E.elevation);
+					error += GMT_get_proj3D (&argv[i][2], &Ctrl->E.azimuth, &Ctrl->E.elevation);
 					break;
 				case 'G':
 					Ctrl->G.active = TRUE;
@@ -247,7 +247,7 @@ int main(int argc, char **argv)
 	if (GMT_give_synopsis_and_exit || argc == 1) {	/* Display usage */
 		fprintf (stderr,"pscontour %s - Contour xyz-data by triangulation [%s]\n\n", GMT_VERSION, algorithm);
 		fprintf (stderr,"usage: pscontour <xyzfile> -C<cpt_file> %s %s\n", GMT_J_OPT, GMT_Rgeoz_OPT);
-		fprintf (stderr, "\t[-A[-|<annot_int>][<labelinfo>] [%s] [-D<dumpfile>] [-E<az>/<el>]\n", GMT_B_OPT);
+		fprintf (stderr, "\t[-A[-|<annot_int>][<labelinfo>] [%s] [-D<dumpfile>] [%s]\n", GMT_B_OPT, GMT_E_OPT);
 		fprintf (stderr, "\t[%s] [%s] [-I] [%s] [-K] [-L<pen>] [%s] [-N] [-O]\n", GMT_CONTG, GMT_H_OPT, GMT_Jz_OPT, GMT_Mo_OPT);
  		fprintf (stderr, "\t[-P] [-S] [-T<indexfile>] [-U] [-V] [-W[+]<pen>] [%s] [%s]\n", GMT_X_OPT, GMT_Y_OPT);
 		fprintf (stderr, "\t[%s] [%s] [%s]\n\n", GMT_c_OPT, GMT_t_OPT, GMT_b_OPT);
@@ -265,7 +265,7 @@ int main(int argc, char **argv)
 		GMT_label_syntax (5, 0);
 		GMT_explain_option ('b');
 		fprintf (stderr, "\t-D to Dump contour lines to individual files (but see -M)\n");
-		fprintf (stderr, "\t-E set azimuth and elevation of viewpoint for 3-D perspective [180/90]\n");
+		GMT_explain_option ('E');
 		fprintf (stderr, "\t-G Controls placement of labels along contours.  Choose among five algorithms:\n");
 		GMT_cont_syntax (3, 0);
 		GMT_explain_option ('H');
@@ -827,7 +827,7 @@ int main(int argc, char **argv)
 	else {
 #ifdef TRIANGLE_D
 #ifdef DEBUG
-	/* Shewchuck's function allocated the memory separately */
+	/* Shewchuk's function allocated the memory separately */
 		GMT_memtrack_off (GMT_mem_keeper);
 #endif
 #endif
