@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pshistogram.c,v 1.62 2008/03/24 08:58:32 guru Exp $
+ *	$Id: pshistogram.c,v 1.65 2009/01/09 04:02:34 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
  * Updated to v3.1 13-Jun-1998 Paul Wessel
  * Updated to v3.3 23-Apr-1999 Paul Wessel
  *		     Now uses two passes to get accurate mean and stdev
- * 27-JAN-2005: Added -T option to select column of interrest
+ * 27-JAN-2005: Added -T option to select column of interest
  * Version:	4.1.2 Free of global variables, and now uses double precision
  *		4.2.1 -C is now -F (-C will still work) and -C<cpt> paints bars
  */
@@ -261,7 +261,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-Q plot a cumulative histogram\n");
 		GMT_explain_option ('r');
 		fprintf (stderr, "\t   If neither -R nor -I are set, w/e/s/n will be based on input data\n");
-		fprintf (stderr, "\t-S Draws a stairs-step diagram instead of histogram.\n");
+		fprintf (stderr, "\t-S Draws a stairs-step diagram [Default is bar histogram].\n");
 		fprintf (stderr, "\t-T Append column to use (0 is first) [0]\n");
 		GMT_explain_option ('U');
 		GMT_explain_option ('V');
