@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psimage.c,v 1.42 2008/04/15 15:44:44 remko Exp $
+ *	$Id: psimage.c,v 1.45 2009/01/09 04:02:34 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -42,10 +42,11 @@ struct PSIMAGE_CTRL {
 		BOOLEAN active;
 		struct GMT_PEN pen;
 	} F;
-	struct G {	/* -G[f|b]<rgb> */
+	struct G {	/* -G[f|b|t]<rgb> */
 		BOOLEAN active;
 		int f_rgb[3];
 		int b_rgb[3];
+		int t_rgb[3];
 	} G;
 	struct I {	/* -I */
 		BOOLEAN active;
@@ -53,11 +54,11 @@ struct PSIMAGE_CTRL {
 	struct M {	/* -M */
 		BOOLEAN active;
 	} M;
-	struct N {	/* -N<nx/ny> */
+	struct N {	/* -N<nx>/<ny> */
 		BOOLEAN active;
 		int nx, ny;
 	} N;
-	struct W {	/* -W[-]<xlength>[/<ylength>] */
+	struct W {	/* -W[-]<width>[/<height>] */
 		BOOLEAN active;
 		BOOLEAN interpolate;
 		double width, height;
@@ -66,7 +67,7 @@ struct PSIMAGE_CTRL {
 
 int main (int argc, char **argv)
 {
-	int i, j, n, justify, PS_interpolate;
+	int i, j, n, justify, PS_interpolate = 1, PS_transparent = 1;
 
 	BOOLEAN error = FALSE;
 
@@ -74,7 +75,7 @@ int main (int argc, char **argv)
 
 	char file[BUFSIZ], txt_a[GMT_LONG_TEXT], txt_b[GMT_LONG_TEXT], letter;
 
-	unsigned char *picture;
+	unsigned char *picture, *buffer;
 
 	struct imageinfo header;
 
@@ -139,6 +140,7 @@ int main (int argc, char **argv)
 					switch (letter) {
 						case 'F':
 						case 'f':
+							/* Set color for foreground pixels */
 							if (argv[i][3] == '-' && argv[i][4] == '\0')
 								Ctrl->G.f_rgb[0] = -1;
 							else if (GMT_getrgb (&argv[i][3], Ctrl->G.f_rgb)) {
@@ -148,6 +150,7 @@ int main (int argc, char **argv)
 							break;
 						case 'B':
 						case 'b':
+							/* Set color for background pixels */
 							if (argv[i][3] == '-' && argv[i][4] == '\0')
 								Ctrl->G.b_rgb[0] = -1;
 							else if (GMT_getrgb (&argv[i][3], Ctrl->G.b_rgb)) {
@@ -155,6 +158,14 @@ int main (int argc, char **argv)
 								error++;
 							}
 							break;
+						case 'T':
+						case 't':
+							/* Set transparent color */
+							if (GMT_getrgb (&argv[i][3], Ctrl->G.t_rgb)) {
+								GMT_rgb_syntax ('G', " ");
+								error++;
+							}
+							break;
 						default:	/* Gave either -G<r/g/b>, -G-, or -G<colorname>; all treated as -Gf */
 							if (argv[i][2] == '-' && argv[i][3] == '\0')
 								Ctrl->G.f_rgb[0] = -1;
@@ -205,28 +216,29 @@ int main (int argc, char **argv)
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr,"psimage %s - To plot image file on maps\n\n", GMT_VERSION);
-		fprintf (stderr,"usage: psimage <imagefile> [-E<dpi> or -W[-]<xlength>[/<ylength>]] [-C<xpos>/<ypos>[/<justify>]]\n");
-		fprintf (stderr, "\t[-F<pen>] [-G[f|b]<color>] [-I] [-K] [-M] [-N<nx[/ny>]] [-O] [-P] [%s]\n", GMT_U_OPT);
+		fprintf (stderr,"usage: psimage <imagefile> [-E<dpi> or -W[-]<width>[/<height>]] [-C<xpos>/<ypos>[/<justify>]]\n");
+		fprintf (stderr, "\t[-F<pen>] [-G[b|f|t]<color>] [-I] [-K] [-M] [-N<nx>[/<ny>]] [-O] [-P] [%s]\n", GMT_U_OPT);
 		fprintf (stderr, "\t[-V] [%s] [%s] [%s]\n\n", GMT_X_OPT, GMT_Y_OPT, GMT_c_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
 		fprintf (stderr,"\t<imagefile> is an EPS file or a 1, 8, 24, or 32-bit Sun rasterfile.\n");
 		fprintf (stderr, "\t-E sets image dpi (dots per inch), OR\n");
-		fprintf (stderr, "\t-W sets the size of the image.  If <ylength> = 0, it is\n");
-		fprintf (stderr, "\t   assumed to be <xlength> * (ny / nx).  If <xlength> < 0\n");
+		fprintf (stderr, "\t-W sets the width (and height) of the image.  If <height> = 0\n");
+		fprintf (stderr, "\t   then the original aspect ratio is maintained.  If <width> < 0\n");
 		fprintf (stderr, "\t   then we use absolute value and interpolate image in PostScript.\n");
 		fprintf (stderr,"\n\tOPTIONS:\n");
 		fprintf (stderr,"\t-C sets the lower left position on the map for raster image [0/0].\n");
 		fprintf (stderr,"\t   Optionally, append justification (see pstext for codes)\n");
 		GMT_pen_syntax ('F', "draws a frame around the image with the given pen.");
-		fprintf (stderr,"\t-Gf and -Gb sets the foreground and background color, respectively,\n");
-		fprintf (stderr,"\t   for 1-bit images to be colorized [Default is black and white]\n");
-		fprintf (stderr,"\t   Set <color> = - for transparency\n");
+		fprintf (stderr,"\t-Gb and -Gf (1-bit images only) sets the background and foreground color,\n");
+		fprintf (stderr,"\t   respectively. Set <color> = - for transparency [Default is black and white]\n");
+		fprintf (stderr,"\t-Gt (not for 1-bit images) indicate which color to be made transparent\n");
+		fprintf (stderr,"\t   [Default no transparency].\n");
 		fprintf (stderr,"\t-I invert 1-bit images (does not affect 8 or 24-bit images).\n");
 		GMT_explain_option ('K');
 		fprintf (stderr,"\t-M Force color -> monochrome image using GMT_YIQ-transformation.\n");
-		fprintf (stderr,"\t-N Replicate image nx by ny times [Default is no replication]\n");
+		fprintf (stderr,"\t-N Replicate image <nx> by <ny> times [Default is no replication]\n");
 		GMT_explain_option ('O');
 		GMT_explain_option ('P');
 		GMT_explain_option ('U');
@@ -278,6 +290,22 @@ int main (int argc, char **argv)
 
 	if (Ctrl->M.active) ps_rgb_to_mono (picture, &header);
 
+	/* Add transparent color at beginning, if requested */
+	if (Ctrl->G.t_rgb[0] < 0)
+		PS_transparent = 1;
+	else if (header.depth >= 8) {
+		PS_transparent = -1;
+		j = header.depth / 8;
+		n = j * (header.width * header.height + 1);
+		buffer = (unsigned char *) ps_memory (VNULL, (size_t)n, sizeof (unsigned char));
+		for (i = 0; i < j; i++) buffer[i] = Ctrl->G.t_rgb[i];
+		memcpy (&(buffer[j]), picture, n);
+		ps_free ((void *)picture);
+		picture = buffer;
+	}
+	else
+		fprintf (stderr, "%s: Can only do transparent color for 8- or 24-bit images. -Gt ignored\n", GMT_program);
+
 	if (!project_info.x_off_supplied && GMT_ps.overlay) GMT_ps.x_origin = 0.0;	/* Since map_setup is not called here */
 	if (!project_info.y_off_supplied && GMT_ps.overlay) GMT_ps.y_origin = 0.0;
 
@@ -300,7 +328,7 @@ int main (int argc, char **argv)
 				/* Invert is opposite from what is expected. This is to match the behaviour of -Gp */
 				ps_bitimage (x, y, Ctrl->W.width, Ctrl->W.height, picture, header.width, header.height, !Ctrl->I.active, Ctrl->G.f_rgb, Ctrl->G.b_rgb);
 			else
-				GMT_color_image (x, y, Ctrl->W.width, Ctrl->W.height, picture, header.width, header.height, PS_interpolate * header.depth);
+				GMT_color_image (x, y, Ctrl->W.width, Ctrl->W.height, picture, PS_transparent * header.width, header.height, PS_interpolate * header.depth);
 		}
 	}
 
@@ -327,7 +355,7 @@ void *New_Psimage_Ctrl () {	/* Allocate and initialize a new control structure *
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	GMT_init_pen (&C->F.pen, GMT_PENWIDTH);
 	strcpy (C->C.justify, "LB");
-	C->G.f_rgb[0] = C->G.b_rgb[0] = -2;
+	C->G.f_rgb[0] = C->G.b_rgb[0] = C->G.t_rgb[0] = -2;
 	C->N.nx = C->N.ny = 1;	
 	return ((void *)C);
 }
