@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pslegend.c,v 1.99 2008/04/15 15:44:43 remko Exp $
+ *	$Id: pslegend.c,v 1.103 2009/01/09 04:02:34 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -78,7 +78,7 @@ int main (int argc, char **argv)
 	char sarg[GMT_LONG_TEXT], sparg[BUFSIZ], *jarg = CNULL, txtcolor[GMT_LONG_TEXT], psxy[GMT_LONG_TEXT], pstext[GMT_LONG_TEXT];
 	char bar_cpt[GMT_LONG_TEXT], bar_gap[GMT_LONG_TEXT], bar_height[GMT_LONG_TEXT], bar_opts[BUFSIZ], mode;
 	
-	int i, k, n, justify = 0, n_columns = 1, error = 0, symbol_number = 0, n_files = 0, colon, n_scan;
+	int i, k, n, justify = 0, n_columns = 1, error = 0, column_number = 0, n_files = 0, colon, n_scan;
 	
 	double x_off, west, east, south, north, x, y, x0, y0, L, off_ss, off_tt, V = 0.0;
 	double half_line_spacing, quarter_line_spacing, one_line_spacing, y_start = 0.0, d_off, y_use;
@@ -339,7 +339,7 @@ int main (int argc, char **argv)
 	one_line_spacing = Ctrl->L.spacing * gmtdefs.annot_font_size[0] / 72.0;
 	half_line_spacing = 0.5 * one_line_spacing;
 	quarter_line_spacing = 0.25 * one_line_spacing;
-	symbol_number = 0;
+	column_number = 0;
 
 	while (GMT_fgets (line, BUFSIZ, fp)) {
 
@@ -361,7 +361,7 @@ int main (int argc, char **argv)
 			case 'B':	/* Color scale Bar */
 				if (flush_paragraph) fprintf (fpo, "%s -M %s\n%s %s\n", pstext, tmptxt, del, tmptxt);
 				flush_paragraph = FALSE;
-				if (n_columns > 1 && symbol_number > 0 && symbol_number%n_columns != 0) y0 += half_line_spacing, symbol_number = 0;	/* Did not end with full column */
+				if (column_number%n_columns != 0) y0 += half_line_spacing, column_number = 0;	/* Did not end with full column */
 				sscanf (&line[2], "%s %s %s %[^\n]", bar_cpt, bar_gap, bar_height, bar_opts);
 				x_off = GMT_convert_units (bar_gap, GMT_INCH);
 				L = GMT_convert_units (bar_height, GMT_INCH) + 2.0 * one_line_spacing;
@@ -371,7 +371,7 @@ int main (int argc, char **argv)
 			case 'H':	/* Header record */
 				if (flush_paragraph) fprintf (fpo, "%s -M %s\n%s %s\n", pstext, tmptxt, del, tmptxt);
 				flush_paragraph = FALSE;
-				if (n_columns > 1 && symbol_number > 0 && symbol_number%n_columns != 0) y0 += half_line_spacing, symbol_number = 0;	/* Did not end with full column */
+				if (column_number%n_columns != 0) y0 += half_line_spacing, column_number = 0;	/* Did not end with full column */
 				sscanf (&line[2], "%s %s %[^\n]", size, font, text);
 				if (size[0] == '-') sprintf (size, "%g", gmtdefs.header_font_size);
 				if (font[0] == '-') sprintf (font, "%d", gmtdefs.header_font);
@@ -382,7 +382,7 @@ int main (int argc, char **argv)
 			case 'I':	/* Image record */
 				if (flush_paragraph) fprintf (fpo, "%s -M %s\n%s %s\n", pstext, tmptxt, del, tmptxt);
 				flush_paragraph = FALSE;
-				if (n_columns > 1 && symbol_number > 0 && symbol_number%n_columns != 0) y0 += half_line_spacing, symbol_number = 0;	/* Did not end with full column */
+				if (column_number%n_columns != 0) y0 += half_line_spacing, column_number = 0;	/* Did not end with full column */
 				sscanf (&line[2], "%s %s %s", image, size, key);
 				(void) ps_load_image (image, &header);
 				justify = GMT_just_decode (key, 12);
@@ -395,20 +395,21 @@ int main (int argc, char **argv)
 			case 'L':	/* Label record */
 				if (flush_paragraph) fprintf (fpo, "%s -M %s\n%s %s\n", pstext, tmptxt, del, tmptxt);
 				flush_paragraph = FALSE;
-				if (n_columns > 1 && symbol_number > 0 && symbol_number%n_columns != 0) y0 += half_line_spacing, symbol_number = 0;	/* Did not end with full column */
+				column_number++;
 				sscanf (&line[2], "%s %s %s %[^\n]", size, font, key, text);
 				if (size[0] == '-') sprintf (size, "%g", gmtdefs.label_font_size);
 				if (font[0] == '-') sprintf (font, "%d", gmtdefs.label_font);
-				y0 += Ctrl->L.spacing * atoi (size) / 72.0;
+				if (n_columns == 1 || column_number%n_columns == 1) y0 += Ctrl->L.spacing * atoi (size) / 72.0;
 				justify = GMT_just_decode (key, 0);
-				x_off = (justify%4 == 1) ? x0 : ((justify%4 == 3) ? Ctrl->D.width - Ctrl->C.dx : 0.5 * Ctrl->D.width);
+				x_off = (Ctrl->D.width / n_columns) * ((column_number - 1) % n_columns);
+				x_off += (justify%4 == 1) ? x0 : ((justify%4 == 3) ? (Ctrl->D.width / n_columns) - Ctrl->C.dx : 0.5 * (Ctrl->D.width / n_columns));
 				fprintf (fpo, "echo %c%g %g %s 0 %s B%s %s%c | %s\n", quote, x_off, y0, size, font, key, text, quote, pstext);
 				break;
 
 			case 'M':	/* Map scale record M lon0|- lat0 length[:label:just] f|p [-R -J] */
 				if (flush_paragraph) fprintf (fpo, "%s -M %s\n%s %s\n", pstext, tmptxt, del, tmptxt);
 				flush_paragraph = FALSE;
-				if (n_columns > 1 && symbol_number > 0 && symbol_number%n_columns != 0) y0 += half_line_spacing, symbol_number = 0;	/* Did not end with full column */
+				if (column_number%n_columns != 0) y0 += half_line_spacing, column_number = 0;	/* Did not end with full column */
 				n_scan = sscanf (&line[2], "%s %s %s %s %s %s", txt_a, txt_b, txt_c, txt_d, txt_e, txt_f);
 				k = (txt_d[0] != 'f') ? 1 : 0;	/* Determines if we start -L with f or not */
 				for (i = colon = 0; txt_c[i] && colon != 2; i++) if (txt_c[i] == ':') colon++;
@@ -448,12 +449,12 @@ int main (int argc, char **argv)
 			case 'S':	/* Symbol record */
 				if (flush_paragraph) fprintf (fpo, "%s -M %s\n%s %s\n", pstext, tmptxt, del, tmptxt);
 				flush_paragraph = FALSE;
-				symbol_number++;
+				column_number++;
 				sscanf (&line[2], "%s %s %s %s %s %s %[^\n]", txt_a, symbol, size, txt_c, txt_d, txt_b, text);
 				off_ss = GMT_convert_units (txt_a, GMT_INCH);
 				off_tt = GMT_convert_units (txt_b, GMT_INCH);
-				if (n_columns == 1 || symbol_number%n_columns == 1) y0 += half_line_spacing;
-				x_off = x0 + (Ctrl->D.width / n_columns) * ((symbol_number - 1) % n_columns);
+				if (n_columns == 1 || column_number%n_columns == 1) y0 += half_line_spacing;
+				x_off = x0 + (Ctrl->D.width / n_columns) * ((column_number - 1) % n_columns);
 				if (symbol[0] == 'f') {	/* Front is different, must plot as a line segment */
 					i = 0;
 					while (size[i] != '/' && size[i]) i++;
@@ -494,6 +495,10 @@ int main (int argc, char **argv)
 						x = GMT_convert_units (size, gmtdefs.measure_unit);
 						sprintf (sarg, "%g %g 0 %g", x_off + off_ss, y0, x);
 					}
+					else if (symbol[0] == 'r') {	/* Rectangle also need more args */
+						x = GMT_convert_units (size, GMT_INCH);
+						sprintf (sarg, "%g %g %g %g", x_off + off_ss, y0, x, 0.65*x);
+					}
 					else if (symbol[0] == 'w') {	/* Wedge also need more args */
 						x = GMT_convert_units (size, GMT_INCH);
 						sprintf (sarg, "%g %g 20 60", x_off + off_ss -0.5*x, y0+0.25*x);
@@ -506,13 +511,13 @@ int main (int argc, char **argv)
 					fprintf (fpo, "\n");
 				}
 				fprintf (fpo, "echo %c%g %g %g 0 %d LM %s%c | %s\n", quote, x_off + off_tt, y0, gmtdefs.annot_font_size[0], gmtdefs.annot_font[0], text, quote, pstext);
-				if (n_columns == 1 || symbol_number%n_columns == 0) y0 += half_line_spacing;
+				if (column_number%n_columns == 0) y0 += half_line_spacing;
 				break;
 
 			case 'D':	/* Delimiter record */
 				if (flush_paragraph) fprintf (fpo, "%s -M %s\n%s %s\n", pstext, tmptxt, del, tmptxt);
 				flush_paragraph = FALSE;
-				if (n_columns > 1 && symbol_number > 0 && symbol_number%n_columns != 0) y0 += half_line_spacing, symbol_number = 0;	/* Did not end with full column */
+				if (column_number%n_columns != 0) y0 += half_line_spacing, column_number = 0;	/* Did not end with full column */
 				sscanf (&line[2], "%s %s", txt_a, txt_b);
 				L = GMT_convert_units (txt_a, GMT_INCH);
 				y0 += quarter_line_spacing;
@@ -524,7 +529,7 @@ int main (int argc, char **argv)
 			case 'G':	/* Gap record */
 				if (flush_paragraph) fprintf (fpo, "%s -M %s\n%s %s\n", pstext, tmptxt, del, tmptxt);
 				flush_paragraph = FALSE;
-				if (n_columns > 1 && symbol_number > 0 && symbol_number%n_columns != 0) y0 += half_line_spacing, symbol_number = 0;	/* Did not end with full column */
+				if (column_number%n_columns != 0) y0 += half_line_spacing, column_number = 0;	/* Did not end with full column */
 				sscanf (&line[2], "%s", txt_a);
 				L = (txt_a[strlen(txt_a)-1] == 'l') ? atoi (txt_a) * one_line_spacing : GMT_convert_units (txt_a, GMT_INCH);
 				y0 += L;
@@ -532,16 +537,16 @@ int main (int argc, char **argv)
 			case 'N':	/* n_columns record */
 				if (flush_paragraph) fprintf (fpo, "%s -M %s\n%s %s\n", pstext, tmptxt, del, tmptxt);
 				flush_paragraph = FALSE;
-				if (n_columns > 1 && symbol_number > 0 && symbol_number%n_columns != 0) y0 += half_line_spacing, symbol_number = 0;	/* Did not end with full column */
+				if (column_number%n_columns != 0) y0 += half_line_spacing, column_number = 0;	/* Did not end with full column */
 				sscanf (&line[2], "%s", txt_a);
 				n_columns = atoi (txt_a);
-				symbol_number = 0;
+				column_number = 0;
 				break;
 
 			case 'V':	/* Vertical line from here to next V */
 				if (flush_paragraph) fprintf (fpo, "%s -M %s\n%s %s\n", pstext, tmptxt, del, tmptxt);
 				flush_paragraph = FALSE;
-				if (n_columns > 1 && symbol_number > 0 && symbol_number%n_columns != 0) y0 += half_line_spacing, symbol_number = 0;	/* Did not end with full column */
+				if (column_number%n_columns != 0) y0 += half_line_spacing, column_number = 0;	/* Did not end with full column */
 				if (draw_vertical_line) {	/* Second time, now draw line */
 					fprintf (fpo, "echo # vertical lines > %s\n", tmptxt);
 					for (i = 1; i < n_columns; i++) {
@@ -600,7 +605,6 @@ int main (int argc, char **argv)
 	fprintf (fpo, "\n");
 
 	if (!Ctrl->S.active) {	/* Add auto-delete command at the end of the script and then execute it */
-		fprintf (fpo, "%s %s\n", del, script);
 		if (fpo != stdout) fclose (fpo);
 		if (gmtdefs.verbose) fprintf (stderr, "%s: Executing and removing legend script\n", GMT_program);
 #ifdef WIN32
@@ -609,6 +613,7 @@ int main (int argc, char **argv)
 		sprintf (sub, "sh %s", script);
 		system (sub);
 #endif
+		remove (script);
 	}
 	else if (fpo != stdout)
 		fclose (fpo);
