@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pslib_inc.h,v 1.42 2008/03/24 08:58:32 guru Exp $
+ *	$Id: pslib_inc.h,v 1.47 2009/01/14 23:11:36 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -31,6 +31,8 @@
 
 #define _POSIX_SOURCE 1
 
+#define PS_LANGUAGE_LEVEL 2
+
 /* Declaration modifiers for DLL support (MSC et al) */
 
 #if defined(DLL_PSL)		/* define when library is a DLL */
@@ -183,8 +185,8 @@ struct PSL {
 			bit 31 : 0 = write no comments, 1 = write PS comments to PS file	*/
 		int unit;			/* 0 = cm, 1 = inch, 2 = meter			*/
 		int copies;			/* Number of copies for this plot		*/
-		int page_rgb[3];		/* RGB color for bacground paper [white]	*/
-		int page_size[2];		/* Width and height of paper used in points	*/
+		int page_rgb[3];		/* RGB color for background paper [white]	*/
+		double page_size[2];		/* Width and height of paper used in points	*/
 		int dpi;			/* Selected dots per inch			*/
 		double magnify[2];		/* Global scale values [1/1]			*/
 		double origin[2];		/* Origin offset [1/1]				*/
@@ -199,6 +201,8 @@ struct PSL {
 		int font_no;			/* Current font number				*/
 		int linewidth;			/* Current pen thickness			*/
 		int rgb[3];			/* Current paint				*/
+		int fill_rgb[3];		/* Current fill					*/
+		int outline;			/* Current outline				*/
 		int offset;			/* Current setdash offset			*/
 	} current;
 	struct INTERNAL {	/* Variables used internally only */
@@ -219,14 +223,10 @@ struct PSL {
 		int line_cap;			/* 0, 1, or 2 for butt, round, or square [butt] */
 		int line_join;			/* 0, 1, or 2 for miter, arc, or bevel [miter] */
 		int miter_limit;		/* Acute angle threshold 0-180; 0 means PS default [0] */
-		PS_LONG bb[4];			/* Boundingbox arguments			*/
+		double bb[4];			/* Boundingbox arguments			*/
 		PS_LONG ix, iy;			/* Absolute coordinates of last point		*/
-		PS_LONG npath;			/* Length of current unstroked path		*/
-		int split;			/* 1 if last ps_line had to split path		*/
-		PS_LONG p_width;			/* Paper width in points, set in plotinit();	*/
-		PS_LONG p_height;			/* Paper height in points, set in plotinit();	*/
-		PS_LONG max_path_length;		/* Maximum path length encountered during execution	*/
-		PS_LONG clip_path_length;		/* Current length of clip path			*/
+		double p_width;			/* Paper width in points, set in plotinit();	*/
+		double p_height;			/* Paper height in points, set in plotinit();	*/
 		PS_LONG length;			/* Image row output byte counter		*/
 		int n_userimages;		/* Number of specified custom patterns		*/
 		double scale;			/* Must be set through plotinit();		*/
