@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psscale.c,v 1.89 2008/04/15 15:44:44 remko Exp $
+ *	$Id: psscale.c,v 1.94 2009/02/05 16:43:14 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -242,7 +242,7 @@ int main(int argc, char **argv)
 		fprintf (stderr, "\t   If a categorical CPT file is given the -Li is set automatically\n");
 		fprintf (stderr, "\t-E add sidebar triangles for back- and foreground colors.\n");
 		fprintf (stderr, "\t   Specify b(ackground) or f(oreground) to get one only [Default is both]\n");
-		fprintf (stderr, "\t   Optionally, append triangle height [Default scales with barwidth]\n");
+		fprintf (stderr, "\t   Optionally, append triangle height [Default is half the barwidth]\n");
 		fprintf (stderr, "\t-I add illumination for +-<max_intens> or <low_i> to <high_i> [-1.0/1.0]\n");
 		fprintf (stderr, "\t   Alternatively, specify <lower>/<upper> intensity values\n");
 		GMT_explain_option ('K');
@@ -270,17 +270,19 @@ int main(int argc, char **argv)
 
 	/* Check that the options selected are mutually consistent */
 
-	if (z_project.view_azimuth > 360.0 || z_project.view_elevation <= 0.0 || z_project.view_elevation > 90.0) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR -E option:  Enter azimuth in 0-360 range, elevation in 0-90 range\n", GMT_program);
+	if (!Ctrl->D.active) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR: -D is required and must be specified\n", GMT_program);
 		error++;
 	}
-	if (fabs (Ctrl->D.length) < GMT_SMALL ) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR -D option: scale length must be nonzero\n", GMT_program);
-		error++;
-	}
-	if (Ctrl->D.width <= 0.0) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR -D option: scale width must be positive\n", GMT_program);
-		error++;
+	else {
+		if (fabs (Ctrl->D.length) < GMT_SMALL ) {
+			fprintf (stderr, "%s: GMT SYNTAX ERROR -D option: scale length must be nonzero\n", GMT_program);
+			error++;
+		}
+		if (Ctrl->D.width <= 0.0) {
+			fprintf (stderr, "%s: GMT SYNTAX ERROR -D option: scale width must be positive\n", GMT_program);
+			error++;
+		}
 	}
 	if (Ctrl->N.dpi < 1) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -N option: dpi must be > 0\n", GMT_program);
@@ -601,6 +603,7 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 					}
 					GMT_color_image (x0 + gap, 0.0, z_width[ii] - 2*gap, width, tmp, 1, ny, depth);
 					GMT_free ((void *)tmp);
+					ps_rect (x0+gap, 0.0, x1-gap, width, GMT_no_rgb, center);
 				}
 				else {
 					memcpy ((void *)rgb, (void *)GMT_lut[ii].rgb_low, (size_t)(3 * sizeof (int)));
@@ -623,7 +626,7 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 				if (monochrome) rgb[0] = rgb[1] = rgb[2] = GMT_YIQ (rgb);
 				ps_polygon (xp, yp, (GMT_LONG)3, rgb, FALSE);
 			}
-			ps_polygon (xp, yp, (GMT_LONG)3, GMT_no_rgb, 1);
+			ps_polygon (xp, yp, (GMT_LONG)3, GMT_no_rgb, TRUE);
 		}
 		if (extend & (2 - reverse)) {	/* Add color triangle on right side */
 			xp[0] = xp[1] = xright + gap;	xp[2] = xp[0] + e_length;
@@ -636,7 +639,7 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 				if (monochrome) rgb[0] = rgb[1] = rgb[2] = GMT_YIQ (rgb);
 				ps_polygon (xp, yp, (GMT_LONG)3, rgb, FALSE);
 			}
-			ps_polygon (xp, yp, (GMT_LONG)3, GMT_no_rgb, 1);
+			ps_polygon (xp, yp, (GMT_LONG)3, GMT_no_rgb, TRUE);
 		}
 
 		if (gap == 0.0) {
@@ -704,8 +707,8 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 					if (!center) ps_plotr (0.0, -(len2 * dir), PSL_PEN_DRAW_AND_STROKE);
 				x1 += z_width[i];
 			}
-			xx = (reverse) ? xleft : xright;
 			if (!center && !use_labels) {
+				xx = (reverse) ? xleft : xright;
 				ps_plot (xx, 0.0, PSL_PEN_MOVE);
 				i = GMT_n_colors-1;
 				if (all || (GMT_lut[i].annot & 2)) {
@@ -761,6 +764,7 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 					}
 					GMT_color_image (x0 + gap, 0.0, z_width[ii] - 2*gap, width, tmp, 1, ny, depth);
 					GMT_free ((void *)tmp);
+					ps_rect (x0 + gap, 0.0, x1 - gap, width, GMT_no_rgb, center);
 				}
 				else {
 					memcpy ((void *)rgb, (void *)GMT_lut[ii].rgb_low, (size_t)(3 * sizeof (int)));
@@ -789,7 +793,7 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 		annot_off = -(((len > 0.0 && !center) ? len : 0.0) + gmtdefs.annot_offset[0] + off);
 		if (logscl) annot_off = -(((len > 0.0 && !center) ? len : 0.0) + gmtdefs.annot_offset[0]);
 		label_off = annot_off - 0.7 * gmtdefs.annot_font_size[0] * GMT_u2u[GMT_PT][GMT_INCH] - 1.5 * gmtdefs.annot_offset[0];
-		if (extend & (reverse + 1)) {	/* Add color triangles at bottom */
+		if (extend & (reverse + 1)) {	/* Add color triangle at bottom */
 			xp[0] = xp[1] = xleft - gap;	xp[2] = xp[0] - e_length;
 			yp[0] = width;	yp[1] = 0.0;	yp[2] = 0.5 * width;
 			id = (reverse) ? GMT_FGD : GMT_BGD;
@@ -800,9 +804,9 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 				if (monochrome) rgb[0] = rgb[1] = rgb[2] = GMT_YIQ (rgb);
 				ps_polygon (xp, yp, (GMT_LONG)3, rgb, FALSE);
 			}
-			ps_polygon (xp, yp, (GMT_LONG)3, GMT_no_rgb, 1);
+			ps_polygon (xp, yp, (GMT_LONG)3, GMT_no_rgb, TRUE);
 		}
-		if (extend & (2 - reverse)) {	/* Add color triangles at top */
+		if (extend & (2 - reverse)) {	/* Add color triangle at top */
 			xp[0] = xp[1] = xright + gap;	xp[2] = xp[0] + e_length;
 			yp[0] = width;	yp[1] = 0.0;	yp[2] = 0.5 * width;
 			id = (reverse) ? GMT_BGD : GMT_FGD;
@@ -813,7 +817,7 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 				if (monochrome) rgb[0] = rgb[1] = rgb[2] = GMT_YIQ (rgb);
 				ps_polygon (xp, yp, (GMT_LONG)3, rgb, FALSE);
 			}
-			ps_polygon (xp, yp, (GMT_LONG)3, GMT_no_rgb, 1);
+			ps_polygon (xp, yp, (GMT_LONG)3, GMT_no_rgb, TRUE);
 		}
 		if (gap == 0.0) {
 			ps_segment (xleft, 0.0, xleft + length, 0.0);
@@ -822,6 +826,7 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 			ps_segment (xright, 0.0, xright, width);
 		}
 		if (B_set) {	/* Used -B. Must kludge by copying x-axis and scaling to y since we must use GMT_xy_axis to draw a rotated x-axis... */
+			PFI tmp;
 			dx = GMT_get_map_interval (0, GMT_GRID_UPPER); 
 			if (dx > 0.0) GMT_linearx_grid (GMT_lut[0].z_low, GMT_lut[GMT_n_colors-1].z_high, 0.0, width, dx);
 			ps_transrotate (0.0, 0.0, -90.0);
@@ -829,6 +834,8 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 			frame_info.axis[1].label[0] = 0;
 			d_swap (project_info.x_scale, project_info.y_scale);
 			d_swap (project_info.x0, project_info.y0);
+			i_swap (project_info.xyz_projection[0], project_info.xyz_projection[1]);
+			tmp = GMT_x_forward; GMT_y_forward = GMT_x_forward; GMT_x_forward = tmp;
 			for (i = 0; i < 5; i++) frame_info.axis[1].item[i].parent = 1;
 			if (flip_anot)
 				GMT_xy_axis (-width, 0.0, length, start_val, stop_val, &frame_info.axis[1], TRUE, frame_info.side[0]-1);
