@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pstext.c,v 1.80 2008/05/01 03:00:39 guru Exp $
+ *	$Id: pstext.c,v 1.88 2009/01/09 04:02:34 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
  * Version:	3.1 based on old 3.0
  * Version:	3.3: PW: Introducing paragraph mode -M
  * Version:	3.3.4: PW: Input x,y can be in dd:mm[:ss] format
- * Version:	4.2.x: Now can hande @_, @:, @; everywhere and @;colorname; is OK
+ * Version:	4.2.x: Now can handle @_, @:, @; everywhere and @;colorname; is OK
  *
  */
 
@@ -78,6 +78,7 @@ struct PSTEXT_CTRL {
 	} W;
 	struct Z {	/* -Z<z_level> */
 		BOOLEAN active;
+		int mode;	/* 0 for common z_level, 1 for optional z-value in 3rd col for each record */
 		double level;
 	} Z;
 };
@@ -110,15 +111,15 @@ int main(int argc, char **argv)
 	
 	size_t n_alloc = 0;
 
-	double xy[2], west = 0., east = 0.0, south = 0.0, north = 0.0, plot_x = 0.0, plot_y = 0.0;
-	double z_level = 0.0, tmp, dx, dy, xx[2], yy[2];
+	double xy[2], west = 0.0, east = 0.0, south = 0.0, north = 0.0, plot_x = 0.0, plot_y = 0.0;
+	double z_level = 0.0, tmp, dx, dy, xx[2], yy[2], z_level_orig = 0.0;
 
 	BOOLEAN error = FALSE, nofile = TRUE, master_record = FALSE;
 	BOOLEAN do_paragraphs = FALSE, done = FALSE, old_GMT_world_map, add;
 	BOOLEAN skip_text_records = FALSE;
 
 	char text[BUFSIZ], line[BUFSIZ], this_font[GMT_LONG_TEXT], just_key[5], txt_a[GMT_LONG_TEXT], txt_b[GMT_LONG_TEXT];
-	char txt_x[GMT_LONG_TEXT], txt_y[GMT_LONG_TEXT], p[BUFSIZ];
+	char txt_x[GMT_LONG_TEXT], txt_y[GMT_LONG_TEXT], txt_z[GMT_LONG_TEXT], p[BUFSIZ];
 	char **word = (char **)NULL, pjust;
 
 	FILE *fp = NULL;
@@ -198,7 +199,7 @@ int main(int argc, char **argv)
 					break;
 				case 'E':
 					Ctrl->E.active = TRUE;
-					sscanf (&argv[i][2], "%lf/%lf", &Ctrl->E.azimuth, &Ctrl->E.elevation);
+					error += GMT_get_proj3D (&argv[i][2], &Ctrl->E.azimuth, &Ctrl->E.elevation);
 					break;
 				case 'G':
 					Ctrl->G.active = TRUE;
@@ -280,10 +281,11 @@ int main(int argc, char **argv)
 					}
 					break;
 				case 'Z':
-					if (argv[i][2]) {
+					Ctrl->Z.active = TRUE;
+					if (argv[i][2] == '+' && argv[i][3] == '\0') /* Read level for each item */
+						Ctrl->Z.mode = 1;
+					else /* Gave specific constant level */
 						Ctrl->Z.level = atof (&argv[i][2]);
-						Ctrl->Z.active = TRUE;
-					}
 					break;
 
 				/* Options not recognized */
@@ -301,10 +303,10 @@ int main(int argc, char **argv)
 	if (argc == 1 || Ctrl->L.active || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "pstext %s - To plot text on maps\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: pstext <txtfile> %s %s\n", GMT_J_OPT, GMT_Rgeoz_OPT);
-		fprintf (stderr, "\t[-A] [%s] [-C<dx>/<dy>] [-D[j]<dx>[/<dy>][v[<pen>]] [-Eaz/el] [-G<color>]\n", GMT_B_OPT);
+		fprintf (stderr, "\t[-A] [%s] [-C<dx>/<dy>] [-D[j]<dx>[/<dy>][v[<pen>]] [%s] [-G<color>]\n", GMT_B_OPT, GMT_E_OPT);
 		fprintf (stderr, "\t[%s] [-K] [-L] [%s] [-N] [-O] [-P] [-S<pen>] [%s]\n", GMT_Ho_OPT, GMT_Mo_OPT, GMT_U_OPT);
 		fprintf (stderr, "\t[-V] [-W[<fill>,][o|O|c|C[<pen>]]] [%s] [%s]\n", GMT_X_OPT, GMT_X_OPT);
-		fprintf (stderr, "\t[-Z<zlevel>] [%s] [%s]\n\n", GMT_t_OPT, GMT_c_OPT);
+		fprintf (stderr, "\t[-Z[<zlevel>|+]] [%s] [%s]\n\n", GMT_t_OPT, GMT_c_OPT);
 		fprintf (stderr, "\tReads (x,y,size,angle,fontno,justify,text) from <txtfile> [or stdin]\n");
 		fprintf (stderr, "\tOR (with -M) one or more text paragraphs with formatting info in the segment header.\n");
 		fprintf (stderr, "\tjustify is of the form [T|M|B][L|C|R] (top/middle/bottom/left/center/right)\n");
@@ -341,7 +343,7 @@ int main(int argc, char **argv)
 		fprintf (stderr, "\t-D adds <add_x>,<add_y> to the text origin AFTER projecting with -J. [0/0]\n");
 		fprintf (stderr, "\t   Use -Dj to move text origin away from point (direction determined by text's justification)\n");
 		fprintf (stderr, "\t   Append v[<pen>] to draw line from text to original point.  If <add_y> is not given it equal <add_x>\n");
-		fprintf (stderr, "\t-E set azimuth and elevation of viewpoint for 3-D perspective [180/90]\n");
+		GMT_explain_option ('E');
 		fprintf (stderr, "\t-G set the color (red/green/blue (0-255)) for solid text [%d/%d/%d]\n", gmtdefs.basemap_frame_rgb[0], gmtdefs.basemap_frame_rgb[1], gmtdefs.basemap_frame_rgb[2]);
 		GMT_explain_option ('H');
 		GMT_explain_option ('K');
@@ -363,7 +365,9 @@ int main(int argc, char **argv)
 		fprintf (stderr, "\t   Lower case c will draw concave rectangle (-M only)\n");
 		fprintf (stderr, "\t   Upper case C will draw convex rectangle (-M only)\n");
 		GMT_explain_option ('X');
-		fprintf (stderr, "\t-Z For 3-D plots: Set the z-level of map [0]\n");
+		fprintf (stderr, "\t-Z For 3-D plots: Set the z-level of map [0].  If -Z+ is given then we expect\n");
+		fprintf (stderr, "\t   records to have an optional z value in the 3rd column (i.e., x y z size ...)\n");
+		fprintf (stderr, "\t   Note that -Z+ also sets -N\n");
 		GMT_explain_option ('c');
 		GMT_explain_option (':');
 		GMT_explain_option ('.');
@@ -423,13 +427,14 @@ int main(int argc, char **argv)
 
 	if (project_info.three_D) ps_transrotate (-z_project.xmin, -z_project.ymin, 0.0);
 
+	if (Ctrl->Z.mode == 1) z_level_orig = project_info.z_level;
 	if (Ctrl->Z.active) {
 		project_info.z_level = Ctrl->Z.level;
 		GMT_z_to_zz (Ctrl->Z.level, &z_level);
 	}
 	GMT_setpen (&T.txtpen);
 
-	if (!Ctrl->N.active) GMT_map_clip_on (GMT_no_rgb, 3);
+	if (!(Ctrl->N.active || Ctrl->Z.mode == 1)) GMT_map_clip_on (GMT_no_rgb, 3);
 
 	last_font = 0;
 	ix = (gmtdefs.xy_toggle[0]);	iy = 1 - ix;
@@ -471,8 +476,6 @@ int main(int argc, char **argv)
 
 		while (GMT_fgets (line, BUFSIZ, fp)) {
 
-			if (GMT_is_a_blank_line (line)) continue;	/* Skip blank lines or # comments */
-
 			GMT_enforce_rgb_triplets (line, BUFSIZ);	/* If @; is used, make sure the color information passed on to ps_text is in r/b/g format */
 			
 			if (do_paragraphs) {	/* Paragraph mode */
@@ -484,14 +487,24 @@ int main(int argc, char **argv)
 						n_processed = n_words = 0;
 						n_paragraphs++;
 					}
-
-					nscan = sscanf (&line[2], "%s %s %lf %lf %s %s %s %s %c\n", txt_x, txt_y, &T.font_size, &T.paragraph_angle, this_font, just_key, txt_a, txt_b, &pjust);
+					
+					if (Ctrl->Z.mode == 1) {	/* Expect z in 3rd column */
+						nscan = sscanf (&line[2], "%s %s %s %lf %lf %s %s %s %s %c\n", txt_x, txt_y, txt_z, &T.font_size, &T.paragraph_angle, this_font, just_key, txt_a, txt_b, &pjust);
+						if ((GMT_scanf (txt_z, GMT_io.in_col_type[2], &Ctrl->Z.level) == GMT_IS_NAN)) {
+							fprintf (stderr, "%s: Record %ld had bad z coordinate, must exit)\n", GMT_program, n_read);
+							exit (EXIT_FAILURE);
+						}
+						project_info.z_level = Ctrl->Z.level;
+						GMT_z_to_zz (Ctrl->Z.level, &z_level);
+					}
+					else
+						nscan = sscanf (&line[2], "%s %s %lf %lf %s %s %s %s %c\n", txt_x, txt_y, &T.font_size, &T.paragraph_angle, this_font, just_key, txt_a, txt_b, &pjust);
 					if ((GMT_scanf (txt_x, GMT_io.in_col_type[0], &xy[ix]) == GMT_IS_NAN) || (GMT_scanf (txt_y, GMT_io.in_col_type[1], &xy[iy]) == GMT_IS_NAN)) {
 						fprintf (stderr, "%s: Record %ld had bad x and/or y coordinates, must exit)\n", GMT_program, n_read);
 						exit (EXIT_FAILURE);
 					}
 
-					if (nscan != 9) {
+					if (nscan != (9 + Ctrl->Z.mode)) {
 						fprintf (stderr, "%s: Record %ld had incomplete paragraph information, must exit)\n", GMT_program, n_read);
 						exit (EXIT_FAILURE);
 					}
@@ -532,14 +545,14 @@ int main(int argc, char **argv)
 				else {	/* Text block record */
 					if (skip_text_records) continue;	/* Skip all records for this paragraph */
 					if (!master_record) {
-						fprintf (stderr, "%s: Text record line %ld not preceeded by paragraph information, must exit)\n", GMT_program, n_read);
+						fprintf (stderr, "%s: Text record line %ld not preceded by paragraph information, must exit)\n", GMT_program, n_read);
 						exit (EXIT_FAILURE);
 					}
 
 					line[strlen(line)-1] = 0;
 
-					if (line[0] == 0) {	/* Blank line */
-						word[n_words] = (char *) GMT_memory (VNULL, (size_t)(1), sizeof (char), GMT_program);
+					if (line[0] == 0) {	/* Blank line marked by single NULL character */
+						word[n_words] = (char *) calloc ((size_t)(1), sizeof (char));
 						n_words++;
 						if ((size_t)n_words == n_alloc) {
 							n_alloc <<= 1;
@@ -548,8 +561,7 @@ int main(int argc, char **argv)
 					}
 					pos = 0;
 					while ((GMT_strtok (line, " ", &pos, p))) {
-						word[n_words] = (char *) GMT_memory (VNULL, (size_t)(strlen(p)+1), sizeof (char), GMT_program);
-						strcpy (word[n_words], p);
+						word[n_words] = strdup (p);
 						n_words++;
 						if ((size_t)n_words == n_alloc) {
 							n_alloc <<= 1;
@@ -562,12 +574,24 @@ int main(int argc, char **argv)
 				n_read++;
 			}
 			else {	/* Old-style pstext input */
-				nscan = sscanf (line, "%s %s %lf %lf %s %s %[^\n]\n", txt_x, txt_y, &T.font_size, &T.paragraph_angle, this_font, just_key, text);
+				if (GMT_is_a_blank_line (line)) continue;	/* Skip blank lines or # comments */
+
+				if (Ctrl->Z.mode == 1) {	/* Expect z in 3rd column */
+					nscan = sscanf (line, "%s %s %s %lf %lf %s %s %[^\n]\n", txt_x, txt_y, txt_z, &T.font_size, &T.paragraph_angle, this_font, just_key, text);
+					if ((GMT_scanf (txt_z, GMT_io.in_col_type[2], &Ctrl->Z.level) == GMT_IS_NAN)) {
+						fprintf (stderr, "%s: Record %ld had bad z coordinate, must exit)\n", GMT_program, n_read);
+						exit (EXIT_FAILURE);
+					}
+					project_info.z_level = Ctrl->Z.level;
+					GMT_z_to_zz (Ctrl->Z.level, &z_level);
+				}
+				else
+					nscan = sscanf (line, "%s %s %lf %lf %s %s %[^\n]\n", txt_x, txt_y, &T.font_size, &T.paragraph_angle, this_font, just_key, text);
 				if ((GMT_scanf (txt_x, GMT_io.in_col_type[0], &xy[ix]) == GMT_IS_NAN) || (GMT_scanf (txt_y, GMT_io.in_col_type[1], &xy[iy]) == GMT_IS_NAN)) {
 					fprintf (stderr, "%s: Record %ld had bad x and/or y coordinates, must exit)\n", GMT_program, n_read);
 					exit (EXIT_FAILURE);
 				}
-				if (nscan != 7) {
+				if (nscan != (7+Ctrl->Z.mode)) {
 					fprintf (stderr, "%s: Record %ld is incomplete (skipped)\n", GMT_program, n_read);
 					continue;
 				}
@@ -655,10 +679,12 @@ int main(int argc, char **argv)
 
  	if (do_paragraphs) GMT_free ((void *)word);
 
-	if (!Ctrl->N.active) GMT_map_clip_off (); 
+	if (!(Ctrl->N.active || Ctrl->Z.mode == 1)) GMT_map_clip_off (); 
 
 	GMT_world_map = old_GMT_world_map;
 
+	if (Ctrl->Z.mode == 1) project_info.z_level = z_level_orig;
+
 	GMT_map_basemap ();
 
 	if (project_info.three_D) ps_rotatetrans (z_project.xmin, z_project.ymin, 0.0);
@@ -708,9 +734,7 @@ void GMT_putwords (double x, double y, char **text, GMT_LONG n_words, struct PST
 	if (boxpen_texture) GMT_free ((void *)boxpen_texture);
 	if (vecpen_texture) GMT_free ((void *)vecpen_texture);
 
-	for (i = 0; i < n_words; i++) {
-		GMT_free ((void *)text[i]);
-	}
+	for (i = 0; i < n_words; i++) free ((void *)text[i]);
 }
 
 void load_parameters (struct PSTEXT_INFO *T, struct PSTEXT_CTRL *C) {
