@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pswiggle.c,v 1.54 2008/03/24 08:58:32 guru Exp $
+ *	$Id: pswiggle.c,v 1.56 2009/01/09 04:02:34 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -153,7 +153,7 @@ int main (int argc, char **argv)
 					break;
 				case 'E':
 					Ctrl->E.active = TRUE;
-					sscanf (&argv[i][2], "%lf/%lf", &Ctrl->E.azimuth, &Ctrl->E.elevation);
+					error += GMT_get_proj3D (&argv[i][2], &Ctrl->E.azimuth, &Ctrl->E.elevation);
 					break;
 				case 'G':
 					Ctrl->G.active = TRUE;
@@ -228,7 +228,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr,"pswiggle %s - Plot xyz-series along tracks\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: pswiggle <xyz-files> %s %s -Z<scale>\n", GMT_J_OPT, GMT_Rgeo_OPT);
-		fprintf (stderr, "\t[-A<azimuth>] [%s] [-C<center>] [-D<gap>] [-E<az/el>] [-G<fill>] [%s]\n", GMT_B_OPT, GMT_Ho_OPT);
+		fprintf (stderr, "\t[-A<azimuth>] [%s] [-C<center>] [-D<gap>] [%s] [-G<fill>] [%s]\n", GMT_B_OPT, GMT_E_OPT, GMT_Ho_OPT);
 		fprintf (stderr, "\t[-I<az>] -K] [%s] [-N] [-O] [-P] [-S[x]<lon0>/<lat0>/<length>/<units>] [-T<trackpen>]\n", GMT_Mo_OPT);
 		fprintf (stderr, "\t[%s] [-V] [-W<outlinepen>] [%s] [%s]\n\t[%s] [%s] [%s] [%s]\n", GMT_U_OPT, GMT_X_OPT, GMT_Y_OPT, GMT_c_OPT, GMT_t_OPT, GMT_bi_OPT, GMT_f_OPT);
 
@@ -243,7 +243,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-C sets center value to be removed from z before plotting. [0]\n");
 		fprintf (stderr, "\t-D means there is a datagap if 2 points are more than <gap> distance units apart\n");
 		fprintf (stderr, "\t   gap is in km for map projections, user-units otherwise\n");
-		fprintf (stderr, "\t-E set azimuth and elevation of viewpoint for 3-D perspective [180/90]\n");
+		GMT_explain_option ('E');
 		GMT_fill_syntax ('G', "Specify color/pattern for positive areas.");
 		GMT_explain_option ('H');
 		fprintf (stderr, "\t-I set fixed projection azimuths for wiggles\n");
