@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psxyz.c,v 1.131 2008/05/06 04:03:12 guru Exp $
+ *	$Id: psxyz.c,v 1.137 2009/01/11 18:09:20 remko Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -55,6 +55,10 @@ struct PSXYZ_CTRL {
 		BOOLEAN active;
 		struct GMT_FILL fill;
 	} G;
+	struct I {	/* -I<intensity> */
+		BOOLEAN active;
+		double value;
+	} I;
 	struct L {	/* -L */
 		BOOLEAN active;
 	} L;
@@ -200,7 +204,7 @@ int main (int argc, char **argv)
 					break;
 				case 'E':
 					Ctrl->E.active = TRUE;
-					sscanf (&argv[i][2], "%lf/%lf", &Ctrl->E.azimuth, &Ctrl->E.elevation);
+					error += GMT_get_proj3D (&argv[i][2], &Ctrl->E.azimuth, &Ctrl->E.elevation);
 					break;
 				case 'G':		/* Set color for symbol or polygon */
 					Ctrl->G.active = TRUE;
@@ -209,6 +213,10 @@ int main (int argc, char **argv)
 						error++;
 					}
 					break;
+				case 'I':	/* Adjust symbol color via intensity */
+					Ctrl->I.value = atof (&argv[i][2]);
+					Ctrl->I.active = TRUE;
+					break;
 				case 'L':		/* Force closed polygons */
 					Ctrl->L.active = TRUE;
 					break;
@@ -255,7 +263,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || GMT_give_synopsis_and_exit) {	/* Display usage */
 		fprintf (stderr,"psxyz %s - Plot lines, polygons, and symbols in 3-D\n\n", GMT_VERSION);
 		fprintf(stderr,"usage: psxyz <xyzfiles> %s %s [%s]\n", GMT_J_OPT, GMT_Rgeoz_OPT, GMT_B_OPT);
-		fprintf(stderr, "\t[%s] [-C<cpt>] [-D<dx>/<dy>[/<dz>]] [-E<az/el>] [-G<fill>] [%s] [-K] [-L] [%s] [-N] [-O]\n", GMT_Jz_OPT, GMT_Ho_OPT, GMT_Mo_OPT);
+		fprintf(stderr, "\t[%s] [-C<cpt>] [-D<dx>/<dy>[/<dz>]] [%s] [-G<fill>] [%s] [-I<intens>] [-K] [-L] [%s] [-N] [-O]\n", GMT_Jz_OPT, GMT_E_OPT, GMT_Ho_OPT, GMT_Mo_OPT);
 		fprintf(stderr, "\t[-P] [-Q] [-S<symbol><size>[/size_y]] [%s] [-V] [-W[+|-][<pen>]] [%s]\n", GMT_U_OPT, GMT_X_OPT);
 		fprintf(stderr, "\t[%s] [%s] [%s] [%s] [%s]\n", GMT_Y_OPT, GMT_c_OPT, GMT_t_OPT, GMT_bi_OPT, GMT_f_OPT);
 
@@ -263,17 +271,18 @@ int main (int argc, char **argv)
 
 		fprintf (stderr, "\t<xyzfiles> is one or more files.  If none, read standard input\n");
 		GMT_explain_option ('j');
+		GMT_explain_option ('Z');
 		GMT_explain_option ('r');
 		fprintf (stderr, "\n\tOPTIONS:\n");
 		GMT_explain_option ('b');
 		fprintf (stderr, "\t-C Use cpt-file to assign symbol colors based on t-value in 4th column (requires -S)\n");
 		fprintf (stderr, "\t   Without -S, psxyz expects -M lines/polygons and looks for -Z<tval> strings in each multiheader\n");
 		fprintf (stderr, "\t-D Offset symbol or line positions by <dx>/<dy>[/<dy>] [no offset].\n");
-		fprintf (stderr, "\t-E set user viewpoint azimuth and elevation [180/90].\n");
+		GMT_explain_option ('E');
 		GMT_fill_syntax ('G', "Specify color or pattern [Default is no fill].");
 		fprintf (stderr, "\t   If -G is specified but not -S, psxyz draws a filled polygon.\n");
 		GMT_explain_option ('H');
-		GMT_explain_option ('Z');
+		fprintf (stderr, "\t-I sets a constant intensity used to modulate the fill color (requires -C or -G)\n");
 		GMT_explain_option ('K');
 		fprintf (stderr, "\t-L Force closed polygons\n");
 		GMT_explain_option ('M');
@@ -282,7 +291,7 @@ int main (int argc, char **argv)
 		GMT_explain_option ('P');
 		fprintf (stderr, "\t-Q Do NOT sort symbols based on distance to viewer before plotting\n");
 		fprintf (stderr, "\t-S to select symbol type and symbol size (in %s).  Choose between\n", GMT_unit_names[gmtdefs.measure_unit]);
-		fprintf (stderr, "\t   -(xdash), st(a)r, (b|B)ar, (c)ircle, (d)iamond, (e)llipse, (f)ront, octa(g)on, (h)exagon\n");
+		fprintf (stderr, "\t   -(xdash), +(plus), st(a)r, (b|B)ar, (c)ircle, (d)iamond, (e)llipse, (f)ront, octa(g)on, (h)exagon\n");
 		fprintf (stderr, "\t   (i)nvtriangle, (j)rotated rectangle, (k)ustom, (%c)etter, pe(n)tagon, c(o)lumn, (p)oint, (q)uoted line,\n", 'l');
 		fprintf (stderr, "\t   (r)ect, (s)quare, (t)riangle, c(u)be, (v)ector, (w)edge, (x)cross, (y)dash, (z)dash\n");
 		fprintf (stderr, "\t   If no size is specified, psxyz expects the 4th column to have sizes.\n");
@@ -389,6 +398,10 @@ int main (int argc, char **argv)
 	default_pen = current_pen = Ctrl->W.pen;
 	default_fill = current_fill = Ctrl->G.fill;
 	default_outline = Ctrl->W.active;
+	if (Ctrl->I.active) {
+		GMT_illuminate (Ctrl->I.value, current_fill.rgb);
+		GMT_illuminate (Ctrl->I.value, default_fill.rgb);
+	}
 
 	if (get_rgb) n_cols_start++;
 
@@ -517,6 +530,10 @@ int main (int argc, char **argv)
 					if (gmtdefs.verbose) ps_comment (GMT_io.segment_header);
 					
 					change = GMT_parse_multisegment_header (GMT_io.segment_header, Ctrl->C.active, &fill_active, &current_fill, &default_fill, &outline_active, &current_pen, &default_pen, default_outline);
+					if (Ctrl->I.active) {
+						GMT_illuminate (Ctrl->I.value, current_fill.rgb);
+						GMT_illuminate (Ctrl->I.value, default_fill.rgb);
+					}
 					if (change & 4) GMT_setpen (&current_pen);
 
 					if (read_symbol) n_expected = BUFSIZ;
@@ -648,6 +665,7 @@ int main (int argc, char **argv)
 				if (get_rgb) {	/* Lookup z to get rgb */
 					data1[n].value = in[3];
 					GMT_get_rgb_from_z (data1[n].value, current_fill.rgb);
+					if (Ctrl->I.active) GMT_illuminate (Ctrl->I.value, current_fill.rgb);
 				}
 				if (S.symbol == GMT_SYMBOL_COLUMN) {
 					if (GMT_is_dnan (S.base))
@@ -670,10 +688,7 @@ int main (int argc, char **argv)
 						GMT_y_to_yy (S.base, &tmp);
 					data1[n].z_size = (float)tmp;
 				}
-				if (S.symbol == GMT_SYMBOL_TEXT) {
-					data1[n].string = (char *) GMT_memory (VNULL, (size_t) (strlen (S.string) + 1), sizeof (char), GMT_program);
-					strcpy (data1[n].string, S.string);
-				}
+				if (S.symbol == GMT_SYMBOL_TEXT) data1[n].string = strdup (S.string);
 				data1[n].symbol = S.symbol;
 				if (Ctrl->W.mode) {
 					memcpy ((void *)Ctrl->W.pen.rgb, (void *)current_fill.rgb, 3*sizeof (int));
@@ -758,9 +773,13 @@ int main (int argc, char **argv)
 						dim[0] = (double)data1[i].x_size;
 						GMT_cross (data1[i].x, data1[i].y, data1[i].z, dim, NULL, FALSE);
 						break;
+					case GMT_SYMBOL_PLUS:
+						dim[0] = (double)data1[i].x_size;
+						GMT_plus (data1[i].x, data1[i].y, data1[i].z, dim, NULL, FALSE);
+						break;
 					case GMT_SYMBOL_POINT:
 						dim[0] = GMT_POINT_SIZE;
-						GMT_cross (data1[i].x, data1[i].y, data1[i].z, dim, NULL, FALSE);
+						GMT_plus (data1[i].x, data1[i].y, data1[i].z, dim, NULL, FALSE);
 						break;
 					case GMT_SYMBOL_CIRCLE:
 						size = (double)data1[i].x_size;
@@ -825,7 +844,7 @@ int main (int argc, char **argv)
 							GMT_text3D (data1[i].x, data1[i].y, data1[i].z, font_size, S.font_no, data1[i].string, 0.0, 6, FALSE);
 						else
 							GMT_text3D (data1[i].x, data1[i].y, data1[i].z, font_size, S.font_no, data1[i].string, 0.0, 6, TRUE);
-						GMT_free ((void *)data1[i].string);
+						free ((void *)data1[i].string);
 						break;
 					case GMT_SYMBOL_VECTOR:
 						if (data1[i].flag & 2) {
@@ -938,6 +957,10 @@ int main (int argc, char **argv)
 					if (gmtdefs.verbose) ps_comment (GMT_io.segment_header);
 					
 					change = GMT_parse_multisegment_header (GMT_io.segment_header, Ctrl->C.active, &fill_active, &current_fill, &default_fill, &outline_active, &current_pen, &default_pen, default_outline);
+					if (Ctrl->I.active) {
+						GMT_illuminate (Ctrl->I.value, current_fill.rgb);
+						GMT_illuminate (Ctrl->I.value, default_fill.rgb);
+					}
 					if ((change & 4) && penset_OK) GMT_setpen (&current_pen);
 					if ((change & 1)) polygon = TRUE;
 					if ((change & 2) && !Ctrl->L.active) {
