@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: backtracker.c,v 1.36 2008/03/24 08:58:33 guru Exp $
+ *	$Id: backtracker.c,v 1.41 2009/01/09 04:02:35 guru Exp $
  *
- *   Copyright (c) 1999-2008 by P. Wessel
+ *   Copyright (c) 1999-2009 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -69,7 +69,7 @@ int main (int argc, char **argv)
 	GMT_LONG n_points;			/* Number of data points read */
 	GMT_LONG n_chunk;			/* Total length or array returned by libeuler functions */
 	GMT_LONG n_track;			/* Number of points in a track segment */
-	GMT_LONG n_stages;			/* Number of stage poles */
+	GMT_LONG n_stages = 0;			/* Number of stage poles */
 	GMT_LONG n_segments;			/* Number of path segments written out */
 	GMT_LONG n_skipped = 0;		/* Number of points skipped because t < 0 */
 	int track_limit = 0;		/* Flag for limiting the output track extent [no limit] */
@@ -94,6 +94,8 @@ int main (int argc, char **argv)
 	BOOLEAN nofile = TRUE;
 	BOOLEAN confidence = FALSE;
 	BOOLEAN finite_out = FALSE;	/* FALSE unless -W is set */
+	BOOLEAN single_rotation = FALSE;	/* FALSE unless -F is set */
+	BOOLEAN do_track = FALSE;	/* TRUE if -L is used */
 
 	double d_km = 0.0;		/* Step interval along calculated tracks */
 	double t_zero = 0.0;		/* Current age in Ma */
@@ -104,6 +106,9 @@ int main (int argc, char **argv)
 	double age;			/* Age of seamount, in Ma */
 	double *in, *out;		/* i/o arrays used by GMT */
 	double t_low, t_high;		/* upper/lower age/stage to ouput for track segments */
+	double rot_lon, rot_lat, rot_w;	/* A finite rotation */
+	double R[3][3];			/* Rotation matrix */
+	double x[3], y[3];		/* Two 3-D unit vectors */
 
 	char *euler_file = CNULL;	/* Name pointer for file with stage poles */
 	char *file_stem = CNULL;	/* Name pointer for file stem for individual track files */
@@ -111,11 +116,12 @@ int main (int argc, char **argv)
 	char type[50];			/* What kind of line (flowline or hotspot track) */
 	char dir[8];			/* From or To */
 	char conf_flag = 0;		/* t for time, a for angle, blank for nothing */
+	char txt_a[GMT_TEXT_LEN], txt_b[GMT_TEXT_LEN];
 
 	FILE *fp = NULL;		/* File pointer for input data */
 	FILE *fpo = NULL;		/* File pointer for output data */
 
-	PFI spot_func;			/* Pointer to the required forth/back track function */
+	PFI spot_func = NULL;			/* Pointer to the required forth/back track function */
 
 	out = (double *)NULL;
 
@@ -179,6 +185,7 @@ int main (int argc, char **argv)
 					break;
 
 				case 'L':	/* Specify what kind of track to project */
+					do_track = TRUE;
 					switch (argv[i][2]) {
 						case 'F':	/* Calculate flowlines */
 							stage_id = TRUE;
@@ -202,6 +209,13 @@ int main (int argc, char **argv)
 					euler_file  = &argv[i][2];
 					break;
 
+				case 'e':	/* Apply a fixed total reconstruction rotation to all input points  */
+					single_rotation  = TRUE;
+					sscanf (&argv[i][2], "%[^/]/%[^/]/%lg", txt_a, txt_b, &rot_w);
+					error += GMT_verify_expectations (GMT_io.in_col_type[0], GMT_scanf_arg (txt_a, GMT_io.in_col_type[0], &rot_lon), txt_a);
+					error += GMT_verify_expectations (GMT_io.in_col_type[1], GMT_scanf_arg (txt_b, GMT_io.in_col_type[1], &rot_lat), txt_b);
+					break;
+
 				case 'M':               /* Multiple line segments */
 					GMT_multisegment (&argv[i][2]);
 					break;
@@ -247,20 +261,21 @@ int main (int argc, char **argv)
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "%s %s - Forward and backward flowlines and hotspot tracks\n\n", GMT_program, SPOTTER_VERSION);
-		fprintf (stderr, "usage: %s [infile(s)] -E<euler.d> [-A[young/old]] [-C] [-Df|b] [%s] [-Lf|b<d_km>]\n", GMT_program, GMT_H_OPT);
+		fprintf (stderr, "usage: %s [infile(s)] -E<euler.d> OR -eplon/plat/prot [-A[young/old]] [-C] [-Df|b] [%s] [-Lf|b<d_km>]\n", GMT_program, GMT_H_OPT);
 		fprintf (stderr, "\t[%s] [-N<upper_age>] [-Q<t_fix>] [-S<stem>] [-T<t_zero>] [-V] [-W] [%s] [%s]\n\n", GMT_M_OPT, GMT_t_OPT, GMT_b_OPT);
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
 		fprintf (stderr, "\tinfiles (in ASCII or binary) has 3 or more columns.  If no file(s) is given, standard input is read.\n");
 		fprintf (stderr, "\tFirst 3 columns must have lon, lat (or lat, lon, see -:) and age (Ma)\n");
-		fprintf (stderr, "\t-E specifies the stage pole file to be used\n\n");
+		fprintf (stderr, "\t-E specifies the rotations to be used (see man page for format)\n\n");
+		fprintf (stderr, "\t-e Alternatively, specify a single finite rotation (in degrees) to be applied to all input points\n");
 		fprintf (stderr, "\tOPTIONS:\n\n");
 		fprintf (stderr, "\t-A Output tracks for ages (or stages, see -L) between young and old [Default is entire track]\n");
 		fprintf (stderr, "\t   If no limit is given, then each seamount should have their limits in columns 4 and 5 instead.\n");
 		fprintf (stderr, "\t   Only applicable in conjunction with the -L option.\n");
 		fprintf (stderr, "\t-C The file given with -E contains finite rotation poles [Default is stage poles]\n");
-		fprintf (stderr, "\t-Db move backward in time (from older to younger positions) [Default]\n");
-		fprintf (stderr, "\t-Df move foreward in time (from younger to older positions)\n");
+		fprintf (stderr, "\t-Db Backtrack mode: move forward in time (from older to younger positions) [Default]\n");
+		fprintf (stderr, "\t-Df Flowline mode: move backward in time (from younger to older positions)\n");
 		GMT_explain_option ('H');
 		fprintf (stderr, "\t-Lb Compute hotspot tracks sampled every <d_km> interval [Default projects single points].\n");
 		fprintf (stderr, "\t-Lf Compute flowline for seamounts of unknown but maximum age [Default projects single points]\n");
@@ -277,6 +292,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   Output record will be lon,lat,az,major,minor.\n");
 		fprintf (stderr, "\t   -Wt will output lon,lat,time,az,major,minor.\n");
 		fprintf (stderr, "\t   -Wa will output lon,lat,angle,az,major,minor.\n");
+		fprintf (stderr, "\t   Use -D to specify which direction to rotate [forward in time].\n");
 		GMT_explain_option (':');
 		GMT_explain_option ('i');
 		GMT_explain_option ('n');
@@ -287,8 +303,8 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	if (confidence && (forward || flowline)) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR.  -W cannot be set if -Lf or -Df are set\n", GMT_program);
+	if (confidence && do_track) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR.  -W cannot be set if -Lf or -Lb are set\n", GMT_program);
 		error++;
 	}
 	if (GMT_io.binary[GMT_IN] && GMT_io.io_header[GMT_IN]) {
@@ -303,25 +319,27 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	/* Load in the stage poles */
-
-	n_stages = spotter_init (euler_file, &p, flowline, finite, finite_out, &upper_age, gmtdefs.verbose);
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
 	}
 
-	spot_func = ((flowline + forward) == 1) ? spotter_forthtrack : spotter_backtrack;
-
-	if (fabs (d_km) > GMT_SMALL) {		/* User wants to interpolate tracks rather than project individual points */
-		make_path = TRUE;
-		(flowline) ? sprintf (type, "Flowline") : sprintf (type, "Hotspot track");
-		(forward) ? sprintf (dir, "from") : sprintf (dir, "to");
+	if (single_rotation) {	/* Get rotation matrix R */
+		spotter_make_rot_matrix (rot_lon, rot_lat, rot_w, R);
 	}
-	else if (track_limit > 0) {	/* Limits on track set but track option not selected */
-                fprintf (stderr, "%s: GMT SYNTAX ERROR.  -A requires -L\n", GMT_program);
-		exit (EXIT_FAILURE);
+	else {	/* Load in the stage poles */
+		n_stages = spotter_init (euler_file, &p, flowline, finite, finite_out, &upper_age, gmtdefs.verbose);
+		spot_func = ((flowline + forward) == 1) ? spotter_forthtrack : spotter_backtrack;
+
+		if (fabs (d_km) > GMT_SMALL) {		/* User wants to interpolate tracks rather than project individual points */
+			make_path = TRUE;
+			(flowline) ? sprintf (type, "Flowline") : sprintf (type, "Hotspot track");
+			(forward) ? sprintf (dir, "from") : sprintf (dir, "to");
+		}
+		else if (track_limit > 0) {	/* Limits on track set but track option not selected */
+	                fprintf (stderr, "%s: GMT SYNTAX ERROR.  -A requires -L\n", GMT_program);
+			exit (EXIT_FAILURE);
+		}
 	}
 
 	fpo = GMT_stdout;
@@ -340,6 +358,7 @@ int main (int argc, char **argv)
 	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : 3 + ((track_limit == 2) ? 2 : 0);
 	if (fix_all && !GMT_io.ncol[GMT_IN]) n_expected_fields = 2;	/* Lon, lat only; use fixed t */
 	if (confidence) n_out = 5 + !(conf_flag == 0);
+	if (single_rotation && !GMT_io.binary[GMT_IN]) n_expected_fields = BUFSIZ;	/* Allow any input for -F mode */
 
 	for (fno = 1; !done && fno < n_args; fno++) {	/* Loop over input files, if any */
 		if (!nofile && argv[fno][0] == '-') continue;
@@ -377,14 +396,24 @@ int main (int argc, char **argv)
 				fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
 				continue;
 			}
+			
+			if (!out) out = (double *) GMT_memory (VNULL, (size_t)MAX(n_out, n_expected_fields), sizeof (double), GMT_program);
+
+			if (single_rotation) {	/* Simple reconstruction, then exit */
+				GMT_geo_to_cart (&in[GMT_Y], &in[GMT_X], x, TRUE);	/* Get x-vector */
+				spotter_matrix_vect_mult (R, x, y);				/* Rotate the x-vector */
+				GMT_cart_to_geo (&out[GMT_Y], &out[GMT_X], y, TRUE);	/* Recover lon lat representation; TRUE to get degrees */
+				memcpy ((void *)&out[GMT_Z], (void *)&in[GMT_Z], (n_fields - 2) * sizeof (double));
+				GMT_output (fpo, n_fields, out);
+				continue;
+			}
+			
 			if (fix_all) in[2] = t_fix;
 			if (in[2] < 0.0) {	/* Negative ages are flags for points to be skipped */
 				n_skipped++;
 				continue;
 			}
 
-			if (!out) out = (double *) GMT_memory (VNULL, (size_t)MAX(n_out, n_expected_fields), sizeof (double), GMT_program);
-
 			lon = in[0] * D2R;
 			lat = in[1] * D2R;
 			if (track_limit) {
@@ -428,7 +457,7 @@ int main (int argc, char **argv)
 			}
 			else {	/* Just return the projected locations */
 				if (confidence) {	/* Asked for confidence ellipses on reconstructed points */
-					if (spotter_conf_ellipse (in[0], in[1], age, p, n_stages, conf_flag, out)) {
+					if (spotter_conf_ellipse (in[0], in[1], age, p, n_stages, conf_flag, forward, out)) {
 						fprintf (stderr, "%s: Confidence ellipses only for the age of rotations.  Point with age %g skipped\n", GMT_program, age);
 						continue;
 					}
@@ -458,7 +487,7 @@ int main (int argc, char **argv)
 
 	/* Clean up and exit */
 
-	GMT_free ((void *)p);
+	if (!single_rotation) GMT_free ((void *)p);
 	if (out) GMT_free ((void *)out);
 	
 	GMT_end (argc, argv);
