@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: hotspotter.c,v 1.35 2008/04/25 04:00:41 guru Exp $
+ *	$Id: hotspotter.c,v 1.41 2009/01/15 01:22:55 guru Exp $
  *
- *   Copyright (c) 1999-2008 by P. Wessel
+ *   Copyright (c) 1999-2009 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -99,7 +99,7 @@
  * -> Plate motion models (stage poles):
  *
  * Duncan, R.A., and D. Clague, 1985, Pacific plate motion recorded by linear
- *    volcanic chains, in: A.E.M. Nairn, F. G. stehli, S. Uyeda (eds.), The
+ *    volcanic chains, in: A.E.M. Nairn, F. G. Stehli, S. Uyeda (eds.), The
  *    Ocean Basins and Margins, Vol. 7A, Plenum, New York, pp. 89-121.
  * Wessel and Kroenke, 1997, (see above)
  *
@@ -123,7 +123,7 @@ int main (int argc, char **argv)
 	int n_fields, n_expected_fields;
 	GMT_LONG n_read = 0;		/* Number of records read */
 
-	size_t n_nodes;		/* Number of nodes in the output CVA grid */
+	GMT_LONG n_nodes;		/* Number of nodes in the output CVA grid */
 
 	/* Misc. counters */
 
@@ -251,6 +251,7 @@ int main (int argc, char **argv)
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
 		fprintf (stderr, "\t<files> is one or more seamount (x,y,z,r,t) files\n");
+		fprintf (stderr, "\t-E specifies the rotations to be used (see man page for format)\n\n");
 		fprintf (stderr, "\t-G Specify file name for output CVA grid.\n");
 		GMT_explain_option ('H');
 		fprintf (stderr, "\t-I specifies grid interval(s); Append m [or c] to <dx> and/or <dy> for minutes [or seconds].\n");
@@ -270,6 +271,8 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
+	GMT_check_lattice (&CVA_map.x_inc, &CVA_map.y_inc, &CVA_map.node_offset, NULL);
+
 	if (!project_info.region_supplied) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify -R option\n", GMT_program);
 		error++;
@@ -319,10 +322,10 @@ int main (int argc, char **argv)
 
 	CVA_map.nx = irint ((CVA_map.x_max - CVA_map.x_min) / CVA_map.x_inc) + one_or_zero;
 	CVA_map.ny = irint ((CVA_map.y_max - CVA_map.y_min) / CVA_map.y_inc) + one_or_zero;
-	n_nodes = CVA_map.nx * CVA_map.ny;
-	CVA = (float *) GMT_memory (VNULL, n_nodes, sizeof(float), GMT_program);
+	n_nodes = GMT_get_nm (CVA_map.nx, CVA_map.ny);
+	CVA = (float *) GMT_memory (VNULL, (size_t)n_nodes, sizeof(float), GMT_program);
 
-	/* Assing grid-region variables in radians to avoid conversions inside convolution loop */
+	/* Assign grid-region variables in radians to avoid conversions inside convolution loop */
 
 	west   = CVA_map.x_min * D2R;
 	east   = CVA_map.x_max * D2R;
@@ -518,14 +521,14 @@ int main (int argc, char **argv)
 		if (gmtdefs.verbose) fprintf (stderr, "%s: Normalize CVS grid to percentages of max CVA\n", GMT_program);
 		CVA_map.z_min = +DBL_MAX;
 		CVA_map.z_max = -DBL_MAX;
-		for (k = 0; k < n_nodes; k++) {
+		for (k = 0; k < (size_t)n_nodes; k++) {
 			if (GMT_is_fnan (CVA[k])) continue;
 			if (CVA[k] < CVA_map.z_min) CVA_map.z_min = CVA[k];
 			if (CVA[k] > CVA_map.z_max) CVA_map.z_max = CVA[k];
 		}
 		if (gmtdefs.verbose) fprintf (stderr, "%s: CVA min/max: %g %g -> ", GMT_program, CVA_map.z_min, CVA_map.z_max);
 		scale = 100.0 / CVA_map.z_max;
-		for (k = 0; k < n_nodes; k++) CVA[k] *= (float)scale;
+		for (k = 0; k < (size_t)n_nodes; k++) CVA[k] *= (float)scale;
 		CVA_map.z_min *= scale;
 		CVA_map.z_max *= scale;
 		if (gmtdefs.verbose) fprintf (stderr, "%g %g\n", CVA_map.z_min, CVA_map.z_max);
