@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: spotter.h,v 1.17 2008/03/24 08:58:33 guru Exp $
+ *	$Id: spotter.h,v 1.22 2009/01/09 04:02:36 guru Exp $
  *
- *   Copyright (c) 1999-2008 by P. Wessel
+ *   Copyright (c) 1999-2009 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -43,6 +43,9 @@ struct EULER {	/* Structure with info on each Euler (stage) pole */
 	double sin_lat, cos_lat;	/* Sine and Cosine of pole latitude */
 	double C[3][3];			/* Covariance matrix for this rotation */
 	double k_hat;			/* k_hat uncertainty scale */
+	double g;			/* g magnitude scale */
+	double df;			/* Degrees of freedom in the estimate of rotation */
+	BOOLEAN has_cov;		/* TRUE if there is a covariance matrix for this R */
 };
 
 struct FLOWLINE {			/* Structure with the nearest nodes for a single flowline */
@@ -52,15 +55,35 @@ struct FLOWLINE {			/* Structure with the nearest nodes for a single flowline */
 	unsigned short *PA;		/* Predicted Ages along flowline (t = PI/250, to nearest 0.004 My) */
 };
 
+struct HOTSPOT {	/* Structure holding all the information about a hotspot */
+	/* Record is lon lat abbrev id [radius toff t_on create fit plot name] */
+        double lon, lat;        /* Current location of hot spot (degrees)*/
+	char abbrev[4];         /* Max 3-char abbreviation of hotspot name */
+        int id;                 /* Hot spot id flag */
+	double radius;		/* Uncertainty radius (in km) for hotspot location */
+	double t_off, t_on;	/* Time interval hotspot was active */
+	BOOLEAN create, fit, plot;	/* TRUE if we want to create, fit, or plot hotspot */
+        char name[32];          /* Full name of hotspot */
+	/* Secondary (derived) quantities */
+        double lonr, latr;      /* Current location of hot spot in radians */
+        double x, y, z;         /* Cartesian Current location of hot spot */
+};
+
 /* ANSI-C Function prototypes (see libspotter.c for details): */
 
 EXTERN_MSC int spotter_init (char *file, struct EULER **p, int flowline, BOOLEAN finite_in, BOOLEAN finite_out, double *t_max, BOOLEAN verbose);
+EXTERN_MSC int spotter_hotspot_init (char *file, struct HOTSPOT **p);
 EXTERN_MSC int spotter_backtrack  (double xp[], double yp[], double tp[], GMT_LONG np, struct EULER p[], GMT_LONG ns, double d_km, double t_zero, BOOLEAN do_time, double wesn[], double **c);
 EXTERN_MSC int spotter_forthtrack (double xp[], double yp[], double tp[], GMT_LONG np, struct EULER p[], GMT_LONG ns, double d_km, double t_zero, BOOLEAN do_time, double wesn[], double **c);
 EXTERN_MSC void spotter_finite_to_stages (struct EULER p[], GMT_LONG n, BOOLEAN finite_rates, BOOLEAN stage_rates);
 EXTERN_MSC void spotter_stages_to_finite (struct EULER p[], GMT_LONG n, BOOLEAN finite_rates, BOOLEAN stage_rates);
 EXTERN_MSC void spotter_add_rotations (struct EULER a[], GMT_LONG n_a, struct EULER b[], GMT_LONG n_b, struct EULER *c[], GMT_LONG *n_c);
 EXTERN_MSC double spotter_t2w (struct EULER a[], GMT_LONG n, double t);
-EXTERN_MSC int spotter_conf_ellipse (double lon, double lat, double t, struct EULER *p, GMT_LONG np, char conf, double out[]);
-EXTERN_MSC void matrix_vect_mult (double a[3][3], double b[3], double c[3]);
-EXTERN_MSC void make_rot_matrix (double lonp, double latp, double w, double R[3][3]);
+EXTERN_MSC int spotter_conf_ellipse (double lon, double lat, double t, struct EULER *p, GMT_LONG np, char conf, BOOLEAN forward, double out[]);
+EXTERN_MSC void spotter_matrix_vect_mult (double a[3][3], double b[3], double c[3]);
+EXTERN_MSC void spotter_matrix_transpose (double At[3][3], double A[3][3]);
+EXTERN_MSC void spotter_matrix_add (double A[3][3], double B[3][3], double C[3][3]);
+EXTERN_MSC void spotter_matrix_mult (double A[3][3], double B[3][3], double C[3][3]);
+EXTERN_MSC void spotter_make_rot_matrix (double lonp, double latp, double w, double R[3][3]);
+EXTERN_MSC void spotter_covar_to_record (struct EULER *e, double K[]);
+EXTERN_MSC void spotter_cov_of_inverse (struct EULER *e, double Ct[3][3]);
