@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: triangulate.c,v 1.53 2008/03/27 07:28:38 guru Exp $
+ *	$Id: triangulate.c,v 1.57 2009/01/09 04:02:35 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -68,10 +68,10 @@ struct TRIANGULATE_EDGE {
 int main (int argc, char **argv)
 {
 	int *link, compare_edge(const void *p1, const void *p2);
-	GMT_LONG ij, ij1, ij2, ij3, np, n_alloc, n = 0;
-	int i, j, k, fno, n_files = 0, n_edge;
+	GMT_LONG ij, ij1, ij2, ij3, np, n_alloc, n = 0, i, j, k, n_edge;
+	GMT_LONG i_min, i_max, j_min, j_max, p, nm;
+	int fno, n_files = 0;
 	int n_expected_fields, n_args, n_fields;
-	int i_min, i_max, j_min, j_max, p;
 
 	BOOLEAN error = FALSE, map_them = FALSE;
 	BOOLEAN nofile = TRUE, done = FALSE, do_grid = FALSE;
@@ -201,6 +201,8 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
+	GMT_check_lattice (&Ctrl->I.xinc, &Ctrl->I.yinc, &Ctrl->F.active, &Ctrl->I.active);
+
 	if (GMT_io.binary[GMT_IN] && GMT_io.io_header[GMT_IN]) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data cannot have header -H\n", GMT_program);
 		error++;
@@ -349,9 +351,10 @@ int main (int argc, char **argv)
 		header.nx = GMT_get_n (header.x_min, header.x_max, header.x_inc, header.node_offset);
 		header.ny = GMT_get_n (header.y_min, header.y_max, header.y_inc, header.node_offset);
 		header.xy_off = 0.5 * header.node_offset;
-		grd = (float *) GMT_memory (VNULL, (size_t)(header.nx * header.ny), sizeof (float), GMT_program);
+		nm = GMT_get_nm (header.nx, header.ny);
+		grd = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 		if (!Ctrl->E.active) Ctrl->E.value = GMT_d_NaN;
-		for (i = 0; i < header.nx * header.ny; i++) grd[i] = (float)Ctrl->E.value;	/* initialize grid */
+		for (i = 0; i < nm; i++) grd[i] = (float)Ctrl->E.value;	/* initialize grid */
 
 		for (k = ij = 0; k < np; k++) {
 
@@ -428,7 +431,7 @@ int main (int argc, char **argv)
 		}
 		n_edge = j + 1;
 
-		if (gmtdefs.verbose) fprintf (stderr, "%s: %d unique triangle edges\n", GMT_program, n_edge);
+		if (gmtdefs.verbose) fprintf (stderr, "%s: %ld unique triangle edges\n", GMT_program, n_edge);
 
 		for (i = 0; i < n_edge; i++) {
 			fprintf (GMT_stdout, "%c Edge %d-%d\n", GMT_io.EOF_flag[GMT_OUT], edge[i].begin, edge[i].end);
@@ -448,7 +451,7 @@ int main (int argc, char **argv)
 	GMT_free ((void *) yy);
 #ifdef TRIANGLE_D
 #ifdef DEBUG
-	/* Shewchuck's function allocated the memory separately */
+	/* Shewchuk's function allocated the memory separately */
 	GMT_memtrack_off (GMT_mem_keeper);
 #endif
 #endif
