@@ -1,7 +1,7 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys.h,v 1.33 2008/04/12 01:38:49 guru Exp $
+ *	$Id: x2sys.h,v 1.47 2009/01/09 04:02:36 guru Exp $
  *
- *      Copyright (c) 1999-2008 by P. Wessel
+ *      Copyright (c) 1999-2009 by P. Wessel
  *      See COPYING file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -120,6 +120,7 @@ struct X2SYS_CORR {		/* Structure with the corrections for each leg */
 struct X2SYS_INFO {
 	/* Information of this datasets particular organization */
 
+	char *TAG;			/* The system TAG */
 	int n_fields;			/* Number of input columns */
 	int n_out_columns;		/* Number of output columns */
 	int n_data_cols;		/* Number of data columns (other than x,y,t) */
@@ -130,12 +131,15 @@ struct X2SYS_INFO {
 	int *out_order;			/* Array with column number in the order for output */
 	int *use_column;		/* Array of T/F for which columns to use */
 	int geodetic;			/* How longitudes should be stored: 0: (0-360), 1: (-360,0), 2 (-180/+180) */
+	int dist_flag;			/* How distances are calulated: (0 = Cartesian, 1 = Flat earth, 2 = great circle, 3 = geodesic) */
 	PFI read_file;			/* Pointer to function that reads this file */
-	BOOLEAN ascii_in;		/* TRUE if input is in ascii */
+	int file_type;			/* 0 = ASCII, 1 = native binary, 2 = netCDF */
 	BOOLEAN ascii_out;		/* TRUE if output should be in ascii */
 	BOOLEAN multi_segment;		/* TRUE if there are multiple segments in this file */
 	BOOLEAN geographic;		/* TRUE if x/y data are lon/lat */
 	BOOLEAN ms_next;		/* TRUE if we just read 1st record in a new segments in this file */
+	char unit[2][2];		/* Units for distance (c = Cartesian, e = meter, k = km, m = miles, n = nautical miles)
+	 				   and speed (c = Cartesian, e = m/s, k = km/hr, m = miles/hr, n = knots) */
 	char ms_flag;			/* Multi-segment header flag */
 	char suffix[16];		/* Suffix for these data files */
 	char fflags[BUFSIZ];		/* Text copy of selected columns */
@@ -205,6 +209,28 @@ struct X2SYS_BIX_TRACK_INFO {
 	struct X2SYS_BIX_TRACK_INFO *next_info;
 };
 
+#define COE_X	0	/* Position of crossover x in data array */
+#define COE_Y	1	/* Position of crossover y in data array */
+#define COE_T	2	/* Time at crossover in data array */
+#define COE_Z	3	/* Observed z value at crossover in data array */
+#define COE_D	4	/* Distance at crossover in data array */
+#define COE_H	5	/* Azimuth at crossover in data array */
+#define COE_V	6	/* Velocity at crossover in data array */
+
+struct X2SYS_COE {	/* Holds the information for a single crossover */
+	double data[2][7];
+};
+
+struct X2SYS_COE_PAIR {	/* Holds the information for COE between a pair of tracks */
+	char trk[2][GMT_TEXT_LEN];	/* Track names */
+	int id[2];			/* Internal ID track numbers */
+	int year[2];			/* Start year for each track */
+	double start[2];		/* Time of first point for each track */
+	double stop[2];			/* Time of last point for each track */
+	double dist[2];			/* Length of each track */
+	int nx;				/* Number of crossovers */
+	struct X2SYS_COE *COE;		/* Array of nx COE structures */
+};
 
 /* Global variables used by x2sys functions */
 
@@ -226,36 +252,46 @@ extern int x2sys_read_record (FILE *fp, double *data, struct X2SYS_INFO *s, stru
 extern int x2sys_read_file (char *fname, double ***data, struct X2SYS_INFO *s, struct X2SYS_FILE_INFO *p, struct GMT_IO *G, GMT_LONG *n_rec);
 extern int x2sys_read_gmtfile (char *fname, double ***data, struct X2SYS_INFO *s, struct X2SYS_FILE_INFO *p, struct GMT_IO *G, GMT_LONG *n_rec);
 extern int x2sys_read_mgd77file (char *fname, double ***data, struct X2SYS_INFO *s, struct X2SYS_FILE_INFO *p, struct GMT_IO *G, GMT_LONG *n_rec);
+extern int x2sys_read_mgd77ncfile (char *fname, double ***data, struct X2SYS_INFO *s, struct X2SYS_FILE_INFO *p, struct GMT_IO *G, GMT_LONG *n_rec);
 extern int x2sys_read_ncfile (char *fname, double ***data, struct X2SYS_INFO *s, struct X2SYS_FILE_INFO *p, struct GMT_IO *G, GMT_LONG *n_rec);
 extern int x2sys_xover_output (FILE *fp, int n, double out[]);
 extern int x2sys_n_data_cols (struct X2SYS_INFO *s);
 extern int x2sys_read_list (char *file, char ***list, int *n);
+extern int x2sys_find_track (char *name, char **list, int n);
+int x2sys_get_tracknames (int argc, char **argv, char ***tracklist, BOOLEAN *cmdline);
 
 extern double *x2sys_dummytimes (GMT_LONG n);
 
 extern void x2sys_skip_header (FILE *fp, struct X2SYS_INFO *s);
 extern int x2sys_fclose (char *fname, FILE *fp);
 extern void x2sys_free_info (struct X2SYS_INFO *s);
-extern void x2sys_free_data (double **data, int n);
+extern void x2sys_free_data (double **data, int n, struct X2SYS_FILE_INFO *p);
 extern int x2sys_pick_fields (char *string, struct X2SYS_INFO *s);
 
-extern int x2sys_initialize (char *fname, struct GMT_IO *G, struct X2SYS_INFO **I);
+extern int x2sys_initialize (char *TAG, char *fname, struct GMT_IO *G, struct X2SYS_INFO **I);
 extern void x2sys_end (struct X2SYS_INFO *X);
 
 extern int x2sys_set_system (char *TAG, struct X2SYS_INFO **s, struct X2SYS_BIX *B, struct GMT_IO *G);
 extern void x2sys_bix_init (struct X2SYS_BIX *B, BOOLEAN alloc);
 extern struct X2SYS_BIX_TRACK_INFO *x2sys_bix_make_entry (char *name, int id_no, int flag);
 extern struct X2SYS_BIX_TRACK *x2sys_bix_make_track (int id, int flag);
-extern int x2sys_bix_read_tracks (char *TAG, struct X2SYS_BIX *B, int mode, int *ID);
-extern int x2sys_bix_read_index (char *TAG, struct X2SYS_BIX *B, BOOLEAN swap);
+extern int x2sys_bix_read_tracks (struct X2SYS_INFO *s, struct X2SYS_BIX *B, int mode, int *ID);
+extern int x2sys_bix_read_index (struct X2SYS_INFO *s, struct X2SYS_BIX *B, BOOLEAN swap);
 extern int x2sys_bix_get_ij (double x, double y, int *i, int *j, struct X2SYS_BIX *B, int *ID);
 
-extern void x2sys_path_init (char *TAG);
+extern void x2sys_path_init (struct X2SYS_INFO *s);
 extern int x2sys_get_data_path (char *track_path, char *track, char *suffix);
 extern int x2sys_err_pass (int err, char *file);
 extern void x2sys_err_fail (int err, char *file);
 extern const char * x2sys_strerror (int err);
 
+extern GMT_LONG x2sys_read_coe_dbase (struct X2SYS_INFO *s, char *dbase, char *ignorefile, double *wesn, char *fflag, int coe_kind, char *one_trk, struct X2SYS_COE_PAIR **xpairs, GMT_LONG *nx, int *ntracks);
+extern void x2sys_free_coe_dbase (struct X2SYS_COE_PAIR *P, GMT_LONG np);
+extern void x2sys_get_corrtable (struct X2SYS_INFO *s, char *table, int ntracks, char **trk_name, char *column, struct MGD77_AUX_INFO *aux, struct MGD77_AUXLIST *auxlist, struct MGD77_CORRTABLE ***CORR);
+
+#define X2SYS_ASCII		0
+#define X2SYS_BINARY		1
+#define X2SYS_NETCDF		2
 
 #define X2SYS_NOERROR		0
 #define X2SYS_FCLOSE_ERR	-1
@@ -267,3 +303,6 @@ extern const char * x2sys_strerror (int err);
 #define X2SYS_BIX_BAD_J		-7
 #define X2SYS_BIX_BAD_I		-8
 #define X2SYS_BIX_BAD_IJ	-9
+
+#define X2SYS_DIST_SELECTION	0
+#define X2SYS_SPEED_SELECTION	1
