@@ -1,7 +1,7 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_binlist.c,v 1.40 2007/03/24 01:42:07 pwessel Exp $
+ *	$Id: x2sys_binlist.c,v 1.59 2009/02/13 21:13:02 guru Exp $
  *
- *      Copyright (c) 1999-2007 by P. Wessel
+ *      Copyright (c) 1999-2009 by P. Wessel
  *      See COPYING file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -28,15 +28,17 @@
 
 #include "x2sys.h"
 
+#define EA_LAT "37:04:17.1660757541775"
+
 struct BINCROSS {
 	double x, y, d;
 };
 
 int main (int argc, char **argv)
 {
-	char *TAG = CNULL, d_unit[2];
+	char *TAG = CNULL, **trk_name;
 
-	int i, j, k, k1, ij, ii, jj, nx, bi, bj, start_i, end_i, jump_180, jump_360, dist_flag = 0;
+	int i, j, k, n_tracks, k1, ij, ii, jj, nx, bi, bj, start_i, end_i, jump_180, jump_360;
 	int this_bin_i;	/* This i node for bin */
 	int this_bin_j;	/* This j node for bin */
 	int this_bin_ij;/* This bin */
@@ -46,9 +48,9 @@ int main (int argc, char **argv)
 	unsigned int nav_flag;
 	size_t n_alloc = 0, nx_alloc = GMT_SMALL_CHUNK;
 
-	BOOLEAN error = FALSE, trackline = FALSE, gap;
+	BOOLEAN error = FALSE, trackline = FALSE, gap, ea_mode = FALSE, cmdline_files;
 
-	double **data, *dist_km = NULL, *dist_bin = NULL, dist_scale, x, y, dx, del_x, del_y;
+	double **data, *dist_km = NULL, *dist_bin = NULL, dist_scale, x, y, dx, del_x, del_y, y_max = 90.0;
 
 	struct X2SYS_INFO *s;
 	struct X2SYS_FILE_INFO p;		/* File information */
@@ -63,7 +65,6 @@ int main (int argc, char **argv)
 	
 	for (i = strlen(argv[0]); i >= 0 && argv[0][i] != '/'; i--);
 	X2SYS_program = &argv[0][i+1];	/* Name without full path */
-	d_unit[0] = 'k';	d_unit[1] = '\0';	/* Default is -Ndk */
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -77,25 +78,11 @@ int main (int argc, char **argv)
 
 				/* Supplemental parameters */
 
-				case 'C':
-					if (argv[i][2] == 'c') dist_flag = 0;
-					if (argv[i][2] == 'f') dist_flag = 1;
-					if (argv[i][2] == 'g') dist_flag = 2;
-					if (argv[i][2] == 'e') dist_flag = 3;
-					if (dist_flag < 0 || dist_flag > 3) {
-						fprintf(stderr, "%s: ERROR -C: Flag must be c, f, g, or e\n", GMT_program);
-						error++;
-					}
-					break;
 				case 'D':
 					trackline = TRUE;
 					break;
-				case 'N':	/* Set distance units */
-					d_unit[0] = argv[i][2];
-					if (!strchr ("ekmn", (int)d_unit[0])) {
-						fprintf(stderr, "%s: ERROR -N: Unit must be e, k, m, or n\n", GMT_program);
-						error++;
-					}
+				case 'E':
+					ea_mode = TRUE;
 					break;
 				case 'T':
 					TAG = &argv[i][2];
@@ -109,31 +96,36 @@ int main (int argc, char **argv)
 
 	if (argc == 1 || error || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "x2sys_binlist %s - Create bin index listing from data files\n\n", X2SYS_VERSION);
-		fprintf (stderr, "usage: x2sys_binlist <files> -T<TAG> [-Cc|f|g|e] [-D] [-Ne|k|n|m] [-V]\n\n");
+		fprintf (stderr, "usage: x2sys_binlist <files> -T<TAG> [-D] [-E] [-V]\n\n");
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
-		fprintf (stderr, "\t<files> is one or more datafiles\n");
+		fprintf (stderr, "\t<files> is one or more datafiles, or give =<files.lis> for a file with a list of datafiles\n");
 		fprintf (stderr, "\t-T <TAG> is the system tag for this compilation\n");
 		fprintf (stderr, "\n\tOPTIONS:\n");
-		fprintf (stderr, "\t-C Append code for distance calculation procedure:\n");
-		fprintf (stderr, "\t   c Cartesian [Default]\n");
-		fprintf (stderr, "\t   f Flat Earth\n");
-		fprintf (stderr, "\t   g Great circle\n");
-		fprintf (stderr, "\t   e Ellipsoidal (geodesic) using current GMT ellipsoid\n");
-		fprintf (stderr, "\t   [Default is great-circle or geodesic, depending on ELLIPSOID]\n");
 		fprintf (stderr, "\t-D Calculate track-lengths per bin (see -C for method and -N for units)\n");
-		fprintf (stderr, "\t-N Append choice for distance unit (assumes -Df|g|e). Choose among:\n");
-		fprintf (stderr, "\t   e Metric units I (meters)\n");
-		fprintf (stderr, "\t   k Metric units II (km) [Default]\n");
-		fprintf (stderr, "\t   m British/US units (miles)\n");
-		fprintf (stderr, "\t   n Nautical units (nautical miles)\n");
+		fprintf (stderr, "\t-E Do binning using equal-area bins (with -D only)\n");
 		GMT_explain_option ('V');
 		exit (EXIT_FAILURE);
 	}
 
+	if (ea_mode && !trackline) {
+		fprintf (stderr, "%s: -E requires -D\n", GMT_program);
+		exit (EXIT_FAILURE);		
+	}
+	
+	if ((n_tracks = x2sys_get_tracknames (argc, argv, &trk_name, &cmdline_files)) == 0) {
+		fprintf (stderr, "%s: No datafiles given!\n", GMT_program);
+		exit (EXIT_FAILURE);		
+	}
+
 	x2sys_err_fail (x2sys_set_system (TAG, &s, &B, &GMT_io), TAG);
 
+	if (ea_mode && !s->geographic) {
+		fprintf (stderr, "%s: -E requires geographic data; your TAG implies Cartesian\n", GMT_program);
+		exit (EXIT_FAILURE);		
+	}
+
 	if (s->geographic) {
 		GMT_io.out_col_type[0] = GMT_IS_LON;
 		GMT_io.out_col_type[1] = GMT_IS_LAT;
@@ -143,8 +135,27 @@ int main (int argc, char **argv)
 		GMT_io.out_col_type[0] = GMT_io.out_col_type[1] = GMT_IS_FLOAT;
 	GMT_io.out_col_type[2] = GMT_IS_FLOAT;
 	
-	MGD77_Set_Unit (d_unit, &dist_scale, -1);	/* Gets scale which multiplies meters to chosen distance unit */
+	MGD77_Set_Unit (s->unit[X2SYS_DIST_SELECTION], &dist_scale, -1);	/* Gets scale which multiplies meters to chosen distance unit */
 
+	if (ea_mode) {
+		double mid;
+		char proj[80];
+		/* Do the equal area map projection so W = 360 and H = 180 */
+		if (!(GMT_IS_ZERO (B.x_max - B.x_min - 360.0) && GMT_IS_ZERO (B.y_max - B.y_min - 180.0))) {
+			if (gmtdefs.verbose) fprintf (stderr, "%s: -E requires a global region (-Rg or -Rd)", GMT_program);
+				exit (EXIT_FAILURE);
+		}
+		gmtdefs.ellipsoid = GMT_N_ELLIPSOIDS - 1;	/* Make sure we use a spherical projection */
+		mid = 0.5 * (B.x_max + B.x_min);	/* Central longitude to use */
+		if (gmtdefs.verbose) fprintf (stderr, "%s: To undo equal-area projection, use -R%g/%g/%g/%g -JY%g/%s/360i\n", GMT_program, B.x_min, B.x_max, B.y_min, B.y_max, mid, EA_LAT);
+		sprintf (proj, "Y%g/%s/360", mid, EA_LAT);
+		GMT_parse_J_option (proj);
+		GMT_err_fail (GMT_map_setup (B.x_min, B.x_max, B.y_min, B.y_max), "");
+		GMT_geo_to_xy (B.x_min, B.y_min, &B.x_min, &B.y_min);
+		GMT_geo_to_xy (B.x_max, B.y_max, &B.x_max, &B.y_max);
+		y_max = B.y_max;
+	}
+	
 	x2sys_bix_init (&B, TRUE);
 	nav_flag = (1 << s->x_col) + (1 << s->y_col);	/* For bins just cut by track but no points inside the bin */
 	jump_180 = irint (180.0 / B.bin_x);
@@ -154,31 +165,33 @@ int main (int argc, char **argv)
 	
 	if (trackline) {
 		n_alloc = GMT_CHUNK;
-		dist_bin = (double *)GMT_memory (VNULL, B.nm_bin, sizeof (double), GMT_program);
+		dist_bin = (double *)GMT_memory (VNULL, (size_t)B.nm_bin, sizeof (double), GMT_program);
 	}
 
 	fprintf (GMT_stdout, "# %s\n", TAG);
 
-	for (i = 1; i < argc; i++) {
+	for (i = 0; i < n_tracks; i++) {
 
-		if (argv[i][0] == '-') continue;
-
-		if (gmtdefs.verbose) fprintf (stderr, "x2sys_binlist: Reading file %s\n", argv[i]);
-
-		x2sys_err_fail ((s->read_file) (argv[i], &data, s, &p, &GMT_io, &j), argv[i]);
+		if (gmtdefs.verbose) fprintf (stderr, "x2sys_binlist: Reading file %s ", trk_name[i]);
 
+		x2sys_err_fail ((s->read_file) (trk_name[i], &data, s, &p, &GMT_io, &j), trk_name[i]);
+		if (gmtdefs.verbose) fprintf (stderr, "[%s]\n", s->path);
+		
+		if (ea_mode) {	/* Project coordinates */
+			for (j = 0; j < p.n_rows; j++) GMT_geo_to_xy (data[s->x_col][j], data[s->y_col][j], &data[s->x_col][j], &data[s->y_col][j]);
+		}
+		
 		/* Reset bin flags */
 
 		memset ((void *)B.binflag, 0, (size_t)(B.nm_bin * sizeof (unsigned int)));
 		if (trackline) {
 			memset ((void *)dist_bin, 0, (size_t)(B.nm_bin * sizeof (double)));
-			GMT_err_fail (GMT_distances (data[s->x_col], data[s->y_col], p.n_rows, dist_scale, -dist_flag, dist_km), "");	/* -ve gives increments */
+			GMT_err_fail (GMT_distances (data[s->x_col], data[s->y_col], p.n_rows, dist_scale, -s->dist_flag, &dist_km), "");	/* -ve gives increments */
 		}
 
 		last_bin_ij = last_bin_i = last_bin_j = -1;
 		for (j = 0; j < p.n_rows; j++) {
 			if (outside (data[s->x_col][j], data[s->y_col][j], &B, s->geographic)) continue;
-
 			 x2sys_err_fail (x2sys_bix_get_ij (data[s->x_col][j], data[s->y_col][j], &this_bin_i, &this_bin_j, &B, &this_bin_ij), "");
 
 			/* While this may be the same bin as the last bin, the data available may have changed so we keep
@@ -244,8 +257,8 @@ int main (int argc, char **argv)
 					X[nx].x = x;	X[nx].y = y;	X[nx].d = hypot (del_x , del_y);
 					nx++;
 					if (nx == (int)nx_alloc) {
-						nx_alloc += GMT_SMALL_CHUNK;
-						X = (struct BINCROSS *)GMT_memory (VNULL, nx_alloc, sizeof (struct BINCROSS), GMT_program);
+						nx_alloc <<= 1;
+						X = (struct BINCROSS *)GMT_memory ((void *)X, nx_alloc, sizeof (struct BINCROSS), GMT_program);
 					}
 				}
 				for (bi = start_i; bi <= end_i; bi++) {	/* If we go in here we think dx is non-zero (we do a last-ditch dx check just in case) */
@@ -255,15 +268,15 @@ int main (int argc, char **argv)
 					if (fabs (del_x) > 180.0) del_x = copysign (360.0 - fabs (del_x), -del_x);
 					del_y = (dx == 0.0) ? 0.5 * (data[s->y_col][j] - data[s->y_col][j-1]) : del_x * (data[s->y_col][j] - data[s->y_col][j-1]) / dx;
 					y = data[s->y_col][j-1] + del_y;
-					if (s->geographic && fabs (y) > 90.0) {
-						y = copysign (90, y);
+					if (s->geographic && fabs (y) > y_max) {
+						y = copysign (y_max, y);
 						del_y = y - data[s->y_col][j-1];
 					}
 					X[nx].x = x;	X[nx].y = y;	X[nx].d = hypot (del_x, del_y);
 					nx++;
 					if (nx == (int)nx_alloc) {
-						nx_alloc += GMT_SMALL_CHUNK;
-						X = (struct BINCROSS *)GMT_memory (VNULL, nx_alloc, sizeof (struct BINCROSS), GMT_program);
+						nx_alloc <<= 1;
+						X = (struct BINCROSS *)GMT_memory ((void *)X, nx_alloc, sizeof (struct BINCROSS), GMT_program);
 					}
 				}
 				
@@ -280,10 +293,10 @@ int main (int argc, char **argv)
 					else
 						x = 0.5 * (X[k].x + X[k1].x);
 					y = 0.5 * (X[k].y + X[k1].y);
-					if (s->geographic && fabs (y) > 90.0) y = copysign (90, y);
+					if (s->geographic && fabs (y) > y_max) y = copysign (y_max, y);
 					x2sys_err_fail (x2sys_bix_get_ij (x, y, &ii, &jj, &B, &ij), "");
 					dist_bin[ij] += (GMT_distance_func) (X[k].x, X[k].y, X[k1].x, X[k1].y);
-					B.binflag[ij] |= nav_flag;		/* Only update nav flags we havent been here already */
+					B.binflag[ij] |= nav_flag;		/* Only update nav flags we have not been here already */
 				}
 			}
 			last_bin_ij = this_bin_ij;
@@ -291,11 +304,11 @@ int main (int argc, char **argv)
 			last_bin_j = this_bin_j;
 		}
 
-		x2sys_free_data (data, s->n_fields);
+		x2sys_free_data (data, s->n_fields, &p);
 
 		/* Time for bin index output */
 
-		fprintf (GMT_stdout, "> %s\n", argv[i]);
+		fprintf (GMT_stdout, "> %s\n", trk_name[i]);
 		for (ij = 0; ij < B.nm_bin; ij++) {
 			if (B.binflag[ij] == 0) continue;
 			x = B.x_min + ((ij % B.nx_bin) + 0.5) * B.bin_x;
@@ -314,9 +327,9 @@ int main (int argc, char **argv)
 		if (trackline) GMT_free ((void *)dist_km);
 	}
 
-	x2sys_free_info (s);
-	GMT_free ((void *)B.binflag);
 	GMT_free ((void *)X);
+	x2sys_end (s);
+	GMT_free ((void *)B.binflag);
 	if (trackline) GMT_free ((void *)dist_bin);
 
 	GMT_end (argc, argv);
