@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: xyz2grd.c,v 1.79 2008/05/15 22:00:36 guru Exp $
+ *	$Id: xyz2grd.c,v 1.84 2009/01/09 04:02:35 guru Exp $
  *
- *	Copyright (c) 1991-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -229,7 +229,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   Append x if gridline-registered, periodic data in x without repeating column at xmax\n");
 		fprintf (stderr, "\t   Append y if gridline-registered, periodic data in y without repeating row at ymax\n");
 		fprintf (stderr, "\t   Specify one of the following data types (all binary except a):\n");
-		fprintf (stderr, "\t     a  Ascii\n");
+		fprintf (stderr, "\t     A  Ascii (multiple floating point values per record)\n");
+		fprintf (stderr, "\t     a  Ascii (one value per record)\n");
 		fprintf (stderr, "\t     c  signed 1-byte character\n");
 		fprintf (stderr, "\t     u  unsigned 1-byte character\n");
 		fprintf (stderr, "\t     h  signed short 2-byte integer\n");
@@ -250,6 +251,8 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
+	GMT_check_lattice (&Ctrl->I.xinc, &Ctrl->I.yinc, &Ctrl->F.active, &Ctrl->I.active);
+
 	if (Ctrl->S.active && !Ctrl->Z.active) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR option -S:  Must also specify -Z\n", GMT_program);
 		error++;
@@ -350,7 +353,7 @@ int main (int argc, char **argv)
 
 		if (gmtdefs.verbose) fprintf (stderr, "%s: nx = %d  ny = %d\n", GMT_program, grd.nx, grd.ny);
 
-		nm = grd.nx * grd.ny;
+		nm = GMT_get_nm (grd.nx, grd.ny);
 
 		a = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 		flag = (int *) GMT_memory (VNULL, (size_t)nm, sizeof (int), GMT_program);
@@ -380,6 +383,12 @@ int main (int argc, char **argv)
 			GMT_setmode (GMT_IN);
 #endif
 		}
+#ifdef WIN32
+		else if (Ctrl->E.active && (fp = fopen (argv[fno], GMT_io.r_mode)) == NULL) {
+			fprintf (stderr, "%s: Cannot open file %s\n", GMT_program, argv[fno]);
+			continue;
+		}
+#endif
 		else if ((fp = GMT_fopen (argv[fno], GMT_io.r_mode)) == NULL) {
 			fprintf (stderr, "%s: Cannot open file %s\n", GMT_program, argv[fno]);
 			continue;
@@ -442,35 +451,35 @@ int main (int argc, char **argv)
 			float value;
 			
 			grd.node_offset = 0;
-			GMT_fgets (line, BUFSIZ, fp);
+			fgets (line, BUFSIZ, fp);
 			if (sscanf (line, "%*s %d", &grd.nx) != 1) {
 				fprintf (stderr, "%s: Error decoding ncols record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
-			GMT_fgets (line, BUFSIZ, fp);
+			fgets (line, BUFSIZ, fp);
 			if (sscanf (line, "%*s %d", &grd.ny) != 1) {
 				fprintf (stderr, "%s: Error decoding ncols record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
-			GMT_fgets (line, BUFSIZ, fp);
+			fgets (line, BUFSIZ, fp);
 			if (sscanf (line, "%*s %lf", &grd.x_min) != 1) {
 				fprintf (stderr, "%s: Error decoding xll record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
 			if (!strncmp (line, "xllcorner", (size_t)9)) grd.node_offset = 1;	/* Pixel grid */
-			GMT_fgets (line, BUFSIZ, fp);
+			fgets (line, BUFSIZ, fp);
 			if (sscanf (line, "%*s %lf", &grd.y_min) != 1) {
 				fprintf (stderr, "%s: Error decoding yll record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
 			if (!strncmp (line, "yllcorner", (size_t)9)) grd.node_offset = 1;	/* Pixel grid */
-			GMT_fgets (line, BUFSIZ, fp);
+			fgets (line, BUFSIZ, fp);
 			if (sscanf (line, "%*s %lf", &grd.x_inc) != 1) {
 				fprintf (stderr, "%s: Error decoding cellsize record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
 			if (!Ctrl->E.set) {	/* Only read if not specified in -E */
-				GMT_fgets (line, BUFSIZ, fp);
+				fgets (line, BUFSIZ, fp);
 				if (sscanf (line, "%*s %lf", &Ctrl->E.nodata) != 1) {
 					fprintf (stderr, "%s: Error decoding nodata_value record\n", GMT_program);
 					exit (EXIT_FAILURE);
@@ -484,7 +493,7 @@ int main (int argc, char **argv)
 			GMT_err_fail (GMT_grd_RI_verify (&grd, 1), Ctrl->G.file);
 
 			if (gmtdefs.verbose) fprintf (stderr, "%s: nx = %d  ny = %d\n", GMT_program, grd.nx, grd.ny);
-			nm = n_left = grd.nx * grd.ny;
+			nm = n_left = GMT_get_nm (grd.nx, grd.ny);
 
 			a = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 			/* ESRI grids are scanline oriented (top to bottom) as are GMT grids */
@@ -539,7 +548,13 @@ int main (int argc, char **argv)
 				n_used++;
 			}
 		}
+#ifdef WIN32
+		if (fp != GMT_stdin) {
+			(Ctrl->E.active) ? fclose (fp) : GMT_fclose (fp);
+		}
+#else
 		if (fp != GMT_stdin) GMT_fclose (fp);
+#endif
 	}
 
 	if (!(Ctrl->Z.active || Ctrl->E.active)) {	/* xyz data could have resulted in duplicates */
